jQuery(document).ready(function($) {
    ({field, linkPlaceholder, shortCodePlaceholder} = panelMenus);

    function generateFieldNames() {
        $('.wpap-menu-item .wpap-popup-form-wrap').each(function (index) {
            $(this).find(`.wpap-menu-id`).attr('name', `menu[${index}][menu_id]`);
            $(this).find(`.wpap-menu-name`).attr('name', `menu[${index}][menu_name]`);
            $(this).find(`.wpap-menu-title`).attr('name', `menu[${index}][menu_title]`);
            $(this).find(`.wpap-menu-icon`).attr('name', `menu[${index}][menu_icon]`);
            $(this).find(`.wpap-menu-access`).attr('name', `menu[${index}][menu_access][]`);
            $(this).find(`.wpap-menu-display`).attr('name', `menu[${index}][menu_display]`);
            $(this).find(`.wpap-menu-type`).attr('name', `menu[${index}][menu_type]`);
            $(this).find(`.wpap-menu-content`).attr('name', `menu[${index}][menu_content]`);
            $(this).find(`.wpap-menu-page-select`).attr('name', `menu[${index}][menu_page]`);
            $(this).find(`.wpap-menu-parent`).attr('name', `menu[${index}][menu_parent]`);
        });
    }

    generateFieldNames();

    $(document).on('click', '#wpap-add-menu-btn', function () {
        let fieldsWrap = $('#wpap-menu-fields-wrap');
        fieldsWrap.append(field);
        let menu = $('#wpap-menu-fields-wrap > div');
        $(document).scrollTop(menu.last().offset().top);
        generateFieldNames();
    });

    $('#wpap-menu-fields-wrap, .wpap-child-menus').sortable({
        axis: 'y',
        placeholder: 'wpap-placeholder',
        update: function (event, ui) {
            generateFieldNames();
        }
    });

    $(document).on('click', '.wpap-show-menu-settings', function (e) {
        $(this).parent().next('.wpap-popup-form-wrap').fadeIn(200);
    });

    $(document).on('click', '.wpap-show-child-menus', function (e) {
        $(this).parent().siblings('.wpap-child-menus').slideToggle(200);
    });

    $(document).on('click', '.wpap-remove-menu', function (e) {
        const removeBTN = $(this);
        const childrenWrap = removeBTN.parent().siblings('.wpap-child-menus');
        let nonce = removeBTN.data('nonce');
        let menuId = removeBTN.data('id');

        if (!menuId) {
            removeBTN.parent().hide(0);
            removeBTN.parent().next().remove();
            childrenWrap.slideDown(200).css({paddingRight: '0', transition: 'all 200ms'});
            childrenWrap.find('select.wpap-menu-parent').val(0).change()
            generateFieldNames();
            return;
        }

        if (!confirm(panelMenus.deleteMenuConfirm)) {
            return;
        }

        removeBTN.parent().css('opacity', '0.4');

        $.ajax({
            type : "post",
            url : panelMenus.ajaxurl,
            data : {
                action: "wpap_delete_menu",
                nonce: nonce,
                id: menuId
            },
            success: function(response) {
                if(response === 'success') {
                    removeBTN.parent().hide(0);
                    removeBTN.parent().next().remove();
                    childrenWrap.slideDown(200).css({paddingRight: '0', transition: 'all 200ms'});
                    childrenWrap.find('select.wpap-menu-parent').val(0).change()
                    generateFieldNames();
                }

                if(response === 'error') {
                    removeBTN.parent().css('opacity', '1');
                }
            },
            error: function(response) {
                removeBTN.parent().css('opacity', '1');
            }
        })
    });

    $(document).on('change', '.wpap-menu-type', function () {
        const parent = $(this).parent().parent();

        switch ($(this).val()) {
            case 'parent':
                parent.find('.wpap-menu-page-field-wrap').hide(0);
                parent.find('.wpap-menu-parent').val(0).attr('hidden', 'hidden').prev().hide(0);
                parent.find('.wpap-menu-content').attr('hidden', 'hidden').prev().hide(0);
                break;
            case 'page':
                parent.find('.wpap-menu-page-field-wrap').show(0);
                parent.find('.wpap-menu-content').attr('hidden', 'hidden').prev().hide(0);
                break;
            default:
                parent.find('.wpap-menu-page-field-wrap').hide(0);
                parent.find('.wpap-menu-parent').removeAttr('hidden').prev().show(0);
                parent.find('.wpap-menu-content').removeAttr('hidden').prev().show(0);
        }

        let placeholder;
        let type;

        if ($(this).val() === 'link') {
            type = 'url';
            placeholder = linkPlaceholder;
        } else {
            type = 'text';
            placeholder = shortCodePlaceholder;
        }

        $(this).parent().parent().find('.wpap-menu-content').attr('placeholder', placeholder);
        $(this).parent().parent().find('.wpap-menu-content').attr('type', type);
    });

    $(document).on('click', '.wpap-menu-settings-done', function (e) {
        e.preventDefault();
        $('.wpap-popup-form-wrap').fadeOut(200);
    });
});