<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

if ( isset( $_POST['register_fields'] ) ) {
    $errors = [];

    if ( ! isset( $_POST['register_field_nonce'] ) or ! wp_verify_nonce( $_POST['register_field_nonce'], 'register_field' ) ) {
        $errors[] = __( 'Invalid Request.', 'arvand-panel' );
    } else {
        $ids = WPAPField::fieldIds();

        foreach ( $ids as $id ) {
            if ( ! isset( $_POST['field_id'] ) or ! in_array( $id, $_POST['field_id'] ) ) {
                $del = wp_delete_post( $id, true );
            }
        }

        $settings = [];
        $saved_fields = WPAPField::savedFields();

        foreach ( WPAPField::supported_fields( 'single' ) as $field ) {
            if ( isset( $_POST[ $field ] ) ) {
                if ( isset( $_POST[ $field . '_placeholder' ] ) )
                    $settings['placeholder'] = sanitize_text_field( $_POST[ $field . '_placeholder' ] );
                if ( isset( $_POST[ $field . '_required' ] ) )
                    $settings['required'] = $_POST[ $field . '_required' ] === 'required' ? 'required' : 'optional';
                if ( isset( $_POST[ $field . '_min' ] ) )
                    $settings['min'] = intval( $_POST[ $field . '_min' ] );
                if ( isset( $_POST[ $field . '_max' ] ) )
                    $settings['max'] = intval( $_POST[ $field . '_max' ] );
                if ( $field === 'user_pass' and isset( $_POST[ 'conf_user_pass_placeholder' ] ) )
                    $settings['conf_placeholder'] = sanitize_text_field( $_POST[ 'conf_user_pass_placeholder' ] );
                if ( isset( $_POST[ $field . '_info' ] ) )
                    $settings['info'] = sanitize_text_field( $_POST[ $field . '_info' ] );
                if ( isset( $_POST[ $field . '_meta_key' ] ) )
                    $settings['meta_key'] = sanitize_textarea_field( $_POST[ $field . '_meta_key' ] );
                if ( isset( $_POST[ $field . '_user_edit_display' ] ) )
                    $settings['user_edit_display'] = $_POST[ $field . '_user_edit_display' ] !== 'show' ? 'hide' : 'show';

                $field_data = [
                    'post_title' => $field,
                    'post_type' => 'wpap_reg_field',
                    'post_content' => maybe_serialize( $settings ),
                    'menu_order' => intval( $_POST[ $field ] ),
                    'post_status' => 'publish',
                ];

                if ( in_array( $field, $saved_fields ) ) {
                    $field_data['ID'] = intval( $_POST[ $field . '_id' ] );
                }

                $save = wp_insert_post( $field_data );

                if ( is_wp_error( $save ) ) {
                    $replace = str_replace( '_', ' ', $field );
                    $errors[] =  sprintf( __( 'error in saving.', 'arvand-panel' ), $replace );
                }
            }
        }

        foreach ( WPAPField::supported_fields( 'multi' ) as $field ) {
            if ( isset( $_POST[ $field ] ) and is_array( $_POST[ $field ] ) ) {
                for ( $i = 0; $i < count( $_POST[ $field ] ); $i++ ) {
                    if ( ( $field === 'radio' or $field === 'drop_down' or $field === 'checkbox' ) and in_array('', $_POST[ $field . '_options'][$i] ) ) {
                        return;
                    }

                    $settings = [
                        'name' => $field . '_' . $i,
                        'info' => sanitize_text_field( $_POST[ $field . '_info' ][$i] ),
                        'num' => $i,
                    ];

                    if ( isset( $_POST[ $field . '_placeholder'][$i] ) )
                        $settings['placeholder'] = sanitize_text_field( $_POST[ $field . '_placeholder' ][$i] );
                    if ( isset( $_POST[ $field . '_meta_key'][$i] ) )
                        $settings['meta_key'] =  ! empty( $_POST[ $field . '_meta_key' ][$i] ) ? sanitize_text_field( $_POST[ $field . '_meta_key' ][$i] ) : $field. '_meta_key_' . ( $i + 1 );
                    if ( isset( $_POST[ $field . '_required'][$i] ) )
                        $settings['required'] = ( $_POST[ $field . '_required'][$i] === 'required' ) ? 'required' : 'optional';
                    if ( isset( $_POST[ $field . '_min'][$i] ) )
                        $settings['min'] = intval( $_POST[ $field . '_min' ][$i] );
                    if ( isset( $_POST[ $field . '_min_attr'][$i] ) )
                        $settings['min_attr'] = intval( $_POST[ $field . '_min_attr' ][$i] );
                    if ( isset( $_POST[ $field . '_max_attr'][$i] ) )
                        $settings['max_attr'] = intval( $_POST[ $field . '_max_attr' ][$i] );
                    if ( isset( $_POST[ $field . '_label' ][$i] ) )
                        $settings['label'] = sanitize_text_field( $_POST[ $field . '_label' ][$i] );
                    if ( isset( $_POST[ $field . '_options' ][$i] ) )
                        $settings['options'] = wpap_sanitize_array_fields( $_POST[ $field . '_options' ][$i] );
                    if ( isset( $_POST[ $field . '_select_text' ][$i] ) )
                        $settings['select_text'] = sanitize_text_field( $_POST[ $field . '_select_text' ][$i] );
                    if ( isset( $_POST[ $field . '_user_edit_display' ] ) )
                        $settings['user_edit_display'] = $_POST[ $field . '_user_edit_display' ][$i] !== 'show' ? 'hide' : 'show';

                    $field_data = [
                        'post_title' => $field,
                        'post_type' => 'wpap_reg_field',
                        'post_content' => maybe_serialize( $settings ),
                        'menu_order' => intval( $_POST[ $field ][$i] ),
                        'post_status' => 'publish',
                    ];

                    if ( isset( $_POST[ $field . '_id' ][$i] ) and is_numeric( $_POST[ $field . '_id' ][$i] ) ) {
                        $field_data['ID'] = intval( $_POST[ $field . '_id' ][$i] );
                    }

                    $save = wp_insert_post( $field_data );

                    if ( is_wp_error( $save ) ) {
                        $replace = str_replace( '_', ' ', $field );
                        $errors[] = sprintf( __( 'error in saving.', 'arvand-panel' ), $replace );
                    }
                }
            }
        }
    }
}
?>

<div class="wpap-wrap wrap">
    <h1><?php _e( 'Register Fields', 'arvand-panel' ); ?></h1>

    <?php if ( isset( $errors ) and ! count( $errors ) > 0 ): ?>
        <div class="notice notice-success is-dismissible">
            <p><strong><?php _e( 'Settings Changed.', 'arvand-panel' ); ?></strong></p>
        </div>
    <?php endif; ?>

    <?php if ( ! WPAPField::field_exist('user_login') or ! WPAPField::field_exist('user_email') or ! WPAPField::field_exist('user_pass') ): ?>
        <div class="notice notice-error">
            <p>
                <strong>
                    <?php _e( 'The three fields of username, email and password are required.', 'arvand-panel' ); ?>
                </strong>
            </p>
        </div>
    <?php endif; ?>

    <div id="wpap-register-fields">
        <div id="wpap-buttons-wrap">
            <div>
                <button class="wpap-buttons" data-type="first_name">
                    <i class='bx bx-user'></i>
                    <?php _e( 'Firstname', 'arvand-panel' ); ?>
                </button>
            </div>

            <div>
                <button class="wpap-buttons" data-type="last_name">
                    <i class='bx bx-user-pin'></i>
                    <?php _e( 'Lastname', 'arvand-panel' ); ?>
                </button>
            </div>

            <div>
                <button class="wpap-buttons" data-type="display_name">
                    <i class='bx bx-show-alt'></i>
                    <?php _e( 'Display Name', 'arvand-panel' ); ?>
                </button>
            </div>

            <div>
                <button class="wpap-buttons" data-type="user_login">
                    <i class='bx bx-user-circle'></i>
                    <?php _e( 'Username', 'arvand-panel' ); ?>
                </button>
            </div>

            <div>
                <button class="wpap-buttons" data-type="user_email">
                    <i class='bx bx-envelope'></i>
                    <?php _e( 'Email', 'arvand-panel' ); ?>
                </button>
            </div>

            <div>
                <button class="wpap-buttons" data-type="user_pass">
                    <i class='bx bx-lock-alt'></i>
                    <?php _e( 'Password', 'arvand-panel' ); ?>
                </button>
            </div>

            <div>
                <button class="wpap-buttons" data-type="user_url">
                    <i class='bx bx-link-external'></i>
                    <?php _e( 'Website', 'arvand-panel' ); ?>
                </button>
            </div>

            <div>
                <button class="wpap-buttons" data-type="text_field">
                    <i class='bx bx-text'></i>
                    <?php _e( 'Text Field', 'arvand-panel' ); ?>
                </button>
            </div>

            <div>
                <button class="wpap-buttons" data-type="radio">
                    <i class='bx bx-radio-circle-marked' ></i>
                    <?php _e( 'Radio Button', 'arvand-panel' ); ?>
                </button>
            </div>

            <div>
                <button class="wpap-buttons" data-type="checkbox">
                    <i class='bx bx-check-square' ></i>
                    <?php _e( 'Checkbox', 'arvand-panel' ); ?>
                </button>
            </div>

            <div>
                <button class="wpap-buttons" data-type="drop_down">
                    <i class='bx bx-collection' ></i>
                    <?php _e( 'Dropdown', 'arvand-panel' ); ?>
                </button>
            </div>

            <div>
                <button class="wpap-buttons" data-type="number_field">
                    <i class='bx bx-dice-6'></i>
                    <?php _e( 'Number Field', 'arvand-panel' ); ?>
                </button>
            </div>

            <div>
                <button class="wpap-buttons" data-type="mobile">
                    <i class='bx bx-mobile-vibration'></i>
                    <?php _e( 'Mobile Field', 'arvand-panel' ); ?>
                </button>
            </div>
        </div>

        <form id="wpap-reg-fields-form" method="post" enctype="multipart/form-data">
            <?php wp_nonce_field( 'register_field', 'register_field_nonce' ); ?>
            <input class="wpap-btn-1" type="submit" name="register_fields" value="<?php esc_attr_e( 'Save Settings', 'arvand-panel' ); ?>"/>

            <div id="wpap-reg-fields-wrap">
                <?php
                $posts = get_posts([
                    'post_type' => 'wpap_reg_field',
                    'order' => 'ASC',
                    'orderby' => 'menu_order',
                    'numberposts' => -1,
                ]);

                $settings_fields = new WPAPFieldSettingsHtml();

                foreach ( $posts as $post ) {
                    if ( in_array( $post->post_title, WPAPField::supported_fields() ) ) {
                        $field = esc_html( $post->post_title );
                        echo $settings_fields->field_settings( $field, $post->post_content, $post->ID );
                    }
                }
                ?>
            </div>
        </form>
    </div>
</div>