<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

if ( isset( $_POST['submit'] ) ) {
	$i = 0;
	$menus = new WPAPPanelMenusDB();
	$ids = $menus->menu_ids();
	$error = 0;

	foreach ( $_POST['menu'] as $menu ) {
        $i++;

	    $data = [
            sanitize_text_field( $menu['menu_name'] ),
	        $i,
	        ! empty( $menu['menu_icon'] ) ? sanitize_text_field( $menu['menu_icon'] ) : 'bx bx-menu',
	        ! empty( $menu['menu_title'] ) ? sanitize_text_field( $menu['menu_title'] ) : __( 'Menu Title', 'arvand-panel' ),
	        stripslashes( sanitize_text_field( $menu['menu_content'] ) ),
	        wpap_sanitize_array_fields( $menu['menu_access'] ),
	        in_array( $menu['menu_type'], [ 'default', 'shortcode', 'link', 'page', 'parent' ] ) ? sanitize_text_field( $menu['menu_type'] ) : 'shortcode',
	        $menu['menu_display'] === 'show' ? 'show' : 'hide',
	        is_numeric( $menu['menu_page'] ) ? intval( $menu['menu_page'] ) : 0,
		    in_array( $menu['menu_parent'], $ids ) ? intval( $menu['menu_parent'] ) : 0
        ];

	    $res = $menu['menu_id'] === 'new_menu' ? $menus->insert_menu( $data ) : $menus->update_menu( $data, intval( $menu['menu_id'] ) );
	    $error = ! $res ? $error++ : 0;
    }
}
?>

<div id="wpap-panel-menus-manager" class="wpap-wrap wrap">
    <h1><?php _e( 'Panel Menus', 'arvand-panel' ); ?></h1>

    <?php if ( isset( $error ) and $error > 0 ): ?>
        <div class="notice notice-error is-dismissible">
            <p><strong><?php esc_html_e( 'Error in saving.', 'arvand-panel' ); ?></strong></p>
        </div>
    <?php endif; ?>

    <?php if ( isset( $error ) and ! $error > 0 ): ?>
        <div class="notice notice-success is-dismissible">
            <p><strong><?php _e( 'Settings Changed.', 'arvand-panel' ); ?></strong></p>
        </div>
    <?php endif; ?>

    <?php wp_nonce_field( 'panel_menus', 'panel_menus_nonce' ); ?>

    <div id="wpap-panel-menus">
        <form id="wpap-panel-menus-form" method="post" enctype="multipart/form-data">
            <button id="wpap-add-menu-btn" class="wpap-btn-3" type="button">
                <?php _e( 'Add Menu', 'arvand-panel' ); ?>
            </button>

            <button class="wpap-btn-1" type="submit" name="submit">
                <?php _e( 'Save Settings', 'arvand-panel' ); ?>
            </button>

            <div id="wpap-menu-fields-wrap">
                <?php WPAPPanelMenus::menu_settings(); ?>
            </div>
        </form>

        <div id="wpap-panel-menus-info">
            <h3>
                <i class='bx bx-info-circle'></i>
                <span><?php _e( 'Add menu icon', 'arvand-panel' ); ?></span>
            </h3>

            <p>
                <?php _e( 'You can use boxicons classes as menu icon in ', 'arvand-panel' ); ?>

                <strong>
                    <a href="https://boxicons.com" target="_blank">
                        <?php _e( 'this address ', 'arvand-panel' ); ?>
                    </a>
                </strong>

                <?php _e( '(eg: bx bx-support) Also, if your theme uses font awesome icons, you can use fontawesome css classes (eg: far fa-user)', 'arvand-panel' ); ?>
            </p>

            <h3>
                <i class='bx bx-info-circle'></i>
                <span><?php _e( 'Crate submenu', 'arvand-panel' ); ?></span>
            </h3>

            <p>
                <?php _e( 'To create a menu with submenu, add a custom menu and first change it to "Parent" via the "Menu Type" option and then save it. After saving you can add submenu to this perent menu. Submenus must first be saved to become a submenu via "Menu Parent" option.', 'arvand-panel' ); ?>
            </p>
        </div>
    </div>
</div>