<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

if ( isset( $_GET['del-all-msg'] ) and ! empty( $_GET['del-all-msg'] ) ) {
    if ( wp_verify_nonce( $_GET['del-all-msg'], 'wpap_del_all_msg_nonce' ) and WPAPPrivateMessage::msg_count() ) {
        WPAPPrivateMessage::delete_messages( 0, get_current_user_id() );
    }
}

if ( isset( $_GET['del-all-user-msg'] ) and ! empty( $_GET['del-all-user-msg'] ) and is_numeric( $_GET['del-all-user-msg'] ) and intval( $_GET['del-all-user-msg'] ) ) {
    $nonce = wp_verify_nonce( $_GET['del-all-user-msg'], 'wpap_del_all_user_msg_nonce' );

    if ( $nonce and isset( $_GET['user'] ) and ! empty( $_GET['user'] ) and is_numeric( $_GET['user'] ) and intval( $_GET['user'] ) ) {
        WPAPPrivateMessage::delete_messages( intval( $_GET['user'] ), get_current_user_id() );
    }
}
?>

<h1><?php _e( 'Pravate Massage', 'arvand-panel' ); ?></h1>

<div id="wpap-user-list-actions">
    <form id="wpap-user-search-form" method="post">
        <?php wp_nonce_field( 'search_user_nonce', 'search_user_nonce' ); ?>
        <input type="text" name="s" placeholder="<?php esc_attr_e( 'Enter a word.', 'arvand-panel' );?>"/>

        <button type="submit" name="search_user">
            <i class='bx bx-search-alt-2'></i>
        </button>
    </form>

    <a id="wpap-delete-all-messages"
        class="wpap-btn-3"
        href="<?php echo esc_url( add_query_arg( [ 'del-all-msg' => wp_create_nonce( 'wpap_del_all_msg_nonce' ) ], remove_query_arg( $remove_args ) ) ) ?>"
        onclick="return confirm('<?php _e( 'Are you sure to delete all your messages?', 'arvand-panel' ); ?>')">
        <i class="bx bx-trash"></i>
        <?php _e( 'Delete All Messages', 'arvand-panel' ); ?>
    </a>
</div>

<div class="wpap-table-wrap">
    <table id="wpap-user-list">
        <thead>
            <th><?php _e( 'Profile Image', 'arvand-panel' ); ?></th>
            <th><?php _e( 'Username', 'arvand-panel' ); ?></th>
            <th><?php _e( 'Email', 'arvand-panel' ); ?></th>
            <th><?php _e( 'Messages Count', 'arvand-panel' ); ?></th>
            <th><?php _e( 'Actions', 'arvand-panel' ); ?></th>
        </thead>

        <tbody>
            <?php
            $page_num = isset( $_GET['page-num'] ) ? absint( $_GET['page-num'] ) : 1;
            $limit = 20;

            $args = [
                'offset' => ( $page_num - 1 ) * $limit,
                'number' => $limit,
                'search_columns' => [ 'user_login', 'user_nicename', 'user_email', 'user_url' ],
            ];

            if ( isset( $_POST['search_user'] ) and ! empty( $_POST['s'] ) ) {
                if ( wp_verify_nonce( $_POST['search_user_nonce'], 'search_user_nonce' ) ) {
                    $args['search'] = '*' . esc_attr( $_POST['s'] ) . '*';
                }
            }

            $users = get_users( $args );
            ?>

            <?php if ( count( $users ) ): ?>
                <?php foreach ( $users as $user ): ?>
                    <?php
                    if ( $user->ID === get_current_user_id() ) {
                        continue;
                    }
                    ?>

                    <tr>
                        <td><?php echo get_avatar( $user->ID ); ?></td>
                        <td><?php esc_html_e( $user->user_login ); ?></td>
                        <td><?php echo ! empty( $user->user_email ) ? esc_html( $user->user_email ) : '---'; ?></td>

                        <td>
                            <?php
                            $msg_count =  WPAPPrivateMessage::msg_count( $user->ID, get_current_user_id() );
                            esc_html_e( $msg_count );
                            $replies_count =  WPAPPrivateMessage::msg_admin_unread_count( get_current_user_id(), 0, $user->ID );
                            ?>

                            <?php if ( $replies_count ): ?>
                                <span class="wpap-badge-error">
                                    <?php echo sprintf( __( '%d unread', 'arvand-panel' ), $replies_count ); ?>
                                </span>
                            <?php endif; ?>
                        </td>

                        <td class="wpap-user-list-actions">
                            <a
                                href="<?php echo esc_url( add_query_arg( [ 'section' => 'new-message', 'user' => $user->ID ], remove_query_arg( $remove_args ) ) ); ?>"
                                title="<?php _e( 'Send Message', 'arvand-panel' ); ?>">
                                <i class="bx bx-send"></i>
                            </a>

                            <?php if ( $msg_count > 0 ): ?>
                                <a
                                    href="<?php echo esc_url( add_query_arg( [ 'section' => 'user-messages', 'user' => $user->ID ], remove_query_arg( $remove_args ) ) ); ?>"
                                    title="<?php _e( 'Messages', 'arvand-panel' ); ?>">
                                    <i class="bx bx-chat"></i>
                                </a>

                                <?php $args = add_query_arg( [ 'del-all-user-msg' => wp_create_nonce( 'wpap_del_all_user_msg_nonce' ), 'user' => $user->ID ] ); ?>

                                <a class="wpap-delete-all-msg"
                                   href="<?php echo esc_url( $args, remove_query_arg( [ 'del-all-user-msg' ], remove_query_arg( $remove_args ) ) ); ?>"
                                   onclick="return confirm('<?php _e( 'Are you sure to delete?', 'arvand-panel' ); ?>')"
                                   title="<?php _e( 'Delete All', 'arvand-panel' ); ?>">
                                    <i class="bx bx-trash"></i>
                                </a>
                            <?php endif; ?>
                        </td>
                    </tr>
                <?php endforeach; ?>
            <?php else: ?>
                <td colspan="5">
                    <?php _e( 'Not fount user.', 'arvand-panel' ); ?>
                </td>
            <?php endif; ?>
        </tbody>
    </table>
</div>

<?php
$total_users = count_users();
$total_users = $total_users['total_users'];
$num_of_pages = ceil( $total_users / $limit );

$pl_args = array(
    'base' => add_query_arg( 'page-num', '%#%' ),
    'total' => $num_of_pages,
    'current' => $page_num,
);

echo paginate_links( $pl_args );
?>

