<?php
if ( ! defined('ABSPATH' ) ) {
    exit;
}

$general = wpap_general_options();

if ( isset( $_POST['private_message_reply'] ) ) {
    $allowed_ext = [ 'image/jpeg', 'image/jpg', 'image/png', 'application/zip', 'application/x-zip-compressed', 'application/pdf' ];

    if ( ! isset( $_POST['private_msg_nonce'] ) or ! wp_verify_nonce( $_POST['private_msg_nonce'], 'private_msg_nonce' ) ) {
        $error = __( 'Invalid request.', 'arvand-panel' );
    } elseif ( ! empty( $_FILES['wpap_attachment']['name'] ) and ! in_array( $_FILES['wpap_attachment']['type'], $allowed_ext ) ) {
        $error = __( 'Attachment file format is not allowed.', 'arvand-panel' );
    } elseif ( ! empty( $_FILES['wpap_attachment']['name'] ) and $_FILES['wpap_attachment']['size'] > ( 1204 * $general['private_msg_attachment_size'] ) ) {
        $error = sprintf( __( 'Maximum attachment size is %d KB.', 'arvand-panel' ), $general['private_msg_attachment_size'] );
    } elseif ( empty( $_POST['private_message_content'] ) ) {
        $error = __( 'Message content must not be empty.', 'arvand-panel' );
    } else {
        $insert = wp_insert_post([
            'post_content' => wpautop( wp_kses( $_POST['private_message_content'], 'post' ) ),
            'post_type' => 'wpap_private_message',
            'meta_input' => [ 'wpap_private_msg_recipient' => $user->ID, 'wpap_read' => 'unread' ],
            'post_status' => 'publish',
            'post_parent' => $post->ID
        ]);

        if ( ! is_wp_error( $insert ) ) {
            if ( ! empty( $_FILES['wpap_attachment']['name'] ) ) {
                WPAPPrivateMessage::upload_msg_attachment( $_FILES['wpap_attachment'], $insert );
            }

            $success = __( 'Message sent.', 'arvand-panel' );
        }
    }
}
?>

<?php if ( isset( $error ) ): ?>
    <div class="notice notice-error is-dismissible">
        <p><strong><?php esc_html_e( $error ); ?></strong></p>
    </div>
<?php endif; ?>

<?php if ( isset( $success ) ): ?>
    <div class="notice notice-success is-dismissible">
        <p><strong><?php esc_html_e( $success ); ?></strong></p>
    </div>
<?php endif; ?>

<div id="wpap-single-private-message">
    <article class="wpap-private-message wpap-message-card">
        <div class="wpap-message-card-content">
            <?php
            if ( ! empty( get_the_title( $post->ID ) ) ) {
                echo '<h3>' . get_the_title( $post->ID ) . '</h3>';
            }

            echo get_the_content( '', '', $post->ID );
            ?>
        </div>

        <footer>
            <?php
            echo get_avatar( $post->post_author );
            echo '<span>' . get_the_author_meta( 'display_name', $post->post_author ) . '</span>';
            ?>

            <time><?php echo get_the_date( '', $post->ID ) . ' ' . get_the_time( '', $post->ID ); ?></time>
            <?php $attachment = get_post_meta(  $post->ID, 'wpap_msg_attachment', true ); ?>

            <?php if ( $attachment ): ?>
                <a class="wpap-attachment-file wpap-btn-3" href="<?php echo esc_url( $attachment ); ?>" download>
                    <i class="bx bx-paperclip"></i>
                    <?php _e( 'Attachment', 'arvand-panel' ); ?>
                </a>
            <?php endif; ?>
        </footer>
    </article>

    <div id="wpap-msg-replies">
        <?php
        $query = new WP_Query([
            'post_type' => 'wpap_private_message',
            'post_parent' => $post->ID,
            'post_status' => 'publish',
            'posts_per_page' => 20
        ]);
        ?>

        <?php if ( $query->have_posts() ): ?>
            <?php while ( $query->have_posts() ): $query->the_post(); ?>
                <?php
                $author = get_the_author_meta( 'ID' );
                $class = ( $post->post_author != $author ) ? 'wpap-user-reply' : '';
                ?>

                <article class="wpap-private-message-reply wpap-message-card <?php esc_attr_e( $class ); ?>">
                    <?php
                    $unread = get_post_meta( get_the_ID(), 'wpap_admin_msg_read', true );

                    if ( $unread ) {
                        delete_post_meta( get_the_ID(), 'wpap_admin_msg_read', 'unread' );
                    }
                    ?>

                    <div class="wpap-message-card-content"><?php the_content(); ?></div>

                    <footer>
                        <?php echo get_avatar( $author ); ?>
                        <span><?php echo get_the_author_meta( 'display_name', $author ); ?></span>

                        <time>
                            <i class="bx bx-clock"></i>
                            <?php echo get_the_date( '', get_the_ID() ) . ' ' . get_the_time( '', get_the_ID() ); ?>
                        </time>

                        <?php $attachment = get_post_meta( get_the_ID(), 'wpap_msg_attachment', true ); ?>

                        <?php if ( $attachment ): ?>
                            <a class="wpap-attachment-file wpap-btn-3" href="<?php echo esc_url( $attachment ); ?>" download>
                                <i class="bx bx-paperclip"></i>
                                <?php _e( 'Attachment', 'arvand-panel' ); ?>
                            </a>
                        <?php endif; ?>
                    </footer>
                </article>
            <?php endwhile; ?>
        <?php endif; ?>
    </div>

    <form id="wpap-reply-form" method="post" enctype="multipart/form-data">
        <?php
        wp_nonce_field( 'private_msg_nonce', 'private_msg_nonce' );

        $args = [
            'media_buttons' => false,
            'textarea_name' => 'private_message_content',
            'textarea_rows' => 5,
            'quicktags' => false,
            'tinymce' => [
                'toolbar1' => 'bold,italic,underline,separator,alignleft,aligncenter,alignright,separator,link,unlink,undo,redo',
                'toolbar2' => '',
                'toolbar3' => '',
            ],
        ];

        wp_editor( __( 'Your Message', 'arvand-panel' ), 'wpap-private-message-content', $args );
        ?>

        <p>
            <input id="wpap-attachment" type="file" name="wpap_attachment" hidden/>

            <label for="wpap-attachment" class="wpap-btn-3">
                <i class="bx bx-upload"></i>
                <?php _e( 'Upload Attachment', 'arvand-panel' ); ?>
            </label>

            <span class="wpap-input-info">
                <?php echo sprintf( __( 'Maximum size is %d and allowed extensions: jpg - jpeg - png - pdf - zip', 'arvand-panel' ), $general['private_msg_attachment_size'] ); ?>
            </span>

            <span id="wpap-attachment-file-name"></span>
        </p>

        <button class="wpap-btn-1" type="submit" name="private_message_reply">
            <?php _e( 'Send Message', 'arvand-panel' ); ?>
        </button>
    </form>
</div>
