<?php
if ( ! defined('ABSPATH' ) ) {
    exit;
}

if ( isset( $_GET['del-msg'] ) and ! empty( $_GET['del-msg'] ) and is_numeric( $_GET['del-msg'] ) and intval( $_GET['del-msg'] ) ) {
    if ( wp_verify_nonce( $_GET['del-msg-nonce'], 'wpap_del_msg_nonce' ) ) {
        $childs = get_posts( [ 'post_type' => 'wpap_private_message', 'post_parent' => $_GET['del-msg'] ] );

        if ( count( $childs ) ) {
            foreach ( $childs as $child ) {
                wp_delete_post( $child->ID, true );
            }
        }

        wp_delete_post( intval( $_GET['del-msg'] ), true );
    }
}
?>

<h1><?php _e( 'Message list', 'arvand-panel' ); ?></h1>

<div class="wpap-table-wrap">
    <table id="wpap-user-messages-list">
        <thead>
            <th><?php _e( 'Sender', 'arvand-panel' ); ?></th>
            <th><?php _e( 'Title', 'arvand-panel' ); ?></th>
            <th><?php _e( 'Message', 'arvand-panel' ); ?></th>
            <th><?php _e( 'Replies', 'arvand-panel' ); ?></th>
            <th colspan="2"><?php _e( 'Actions', 'arvand-panel' ); ?></th>
        </thead>

        <tbody>
            <?php
            $args = [
                'post_type' => 'wpap_private_message',
                'meta_key' => 'wpap_private_msg_recipient',
                'meta_value' => $user->ID,
                'author' => get_current_user_id(),
                'post_parent' => 0,
            ];

            $query = new WP_Query( $args );
            ?>

            <?php if ( $query->have_posts() ): ?>
                <?php while ( $query->have_posts() ): $query->the_post(); ?>
                    <tr>
                        <td>
                            <?php
                            $first_name = get_the_author_meta( 'first_name' );
                            $last_name = get_the_author_meta( 'last_name' );
                            $display_name = get_the_author_meta( 'display_name' );

                            if ( ! empty( $first_name ) and ! empty( $last_name ) ) {
                                echo $first_name . ' ' . $last_name;
                            } else {
                                echo $display_name;
                            }
                            ?>
                        </td>

                        <td><?php echo ! empty( get_the_title() ) ? get_the_title() : '---'; ?></td>
                        <td><?php echo wp_trim_words( get_the_excerpt(), 7 ) ?></td>

                        <td>
                            <?php
                            $replies = WPAPPrivateMessage::msg_count( 0, 0, get_the_ID() );
                            esc_html_e( $replies );
                            $unread = WPAPPrivateMessage::msg_admin_unread_count( get_current_user_id(), get_the_ID() );
                            ?>

                            <?php if ( $unread ): ?>
                                <span class="wpap-badge-error">
                                    <?php echo sprintf( __( '%d unread', 'arvand-panel' ), $unread ); ?>
                                </span>
                            <?php endif; ?>
                        </td>

                        <td>
                            <a class="wpap-view-msg" href="<?php echo esc_url( add_query_arg( [ 'section' => 'single-user-message', 'msg' => get_the_ID() ], remove_query_arg( $remove_args ) ) ); ?>">
                                <i class="bx bx-show"></i>
                            </a>

                            <a class="wpap-delete-msg"
                               href="<?php echo esc_url( add_query_arg( [ 'del-msg' => get_the_ID(), 'del-msg-nonce' => wp_create_nonce( 'wpap_del_msg_nonce' ) ], remove_query_arg( $remove_args ) ) ); ?>"
                               onclick="return confirm('<?php _e( 'Are you sure to delete?', 'arvand-panel' ); ?>')">
                                <i class="bx bx-trash"></i>
                            </a>
                        </td>
                    </tr>
                <?php endwhile; ?>
            <?php else: ?>
                <td colspan="4"><?php _e( 'There is no message.', 'arvand-panel' ); ?></td>
            <?php endif; ?>
        </tbody>
    </table>
</div>