<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

$post_id = intval( $_GET['single-ticket'] );
$post = get_post( $post_id );

if ( is_null( $post ) or $post->post_type !== 'wpap_ticket' ) { ?>
    <script>window.location.href = '<?php echo admin_url(); ?>admin.php?page=wpap-tickets';</script>
    <?php exit;
}

$ticket_dep_opt = wpap_ticket_department_options();
$user_dep = WPAPTicket::userDepartment( get_current_user_id() );
$department = get_post_meta( $post->ID, 'wpap_ticket_department', true );

if ( $ticket_dep_opt['enable_department'] and $user_dep and $department and ! in_array( $department, $user_dep ) ) { ?>
    <script>window.location.href = '<?php echo admin_url(); ?>admin.php?page=wpap-tickets';</script>
    <?php exit;
}

$ticket = new WPAPTicket();

// delete ticket
if ( isset( $_GET['del-ticket'] ) and wp_verify_nonce( $_GET['del-ticket'], 'del_ticket' ) ) {
    $ticket->delete( $post->ID ); ?>
    <script>window.location.href = '<?php echo admin_url(); ?>admin.php?page=wpap-tickets';</script>
    <?php exit;
}

$errors = [];
$ticket_opt = wpap_ticket_options();

// insert ticket reply
if ( isset( $_POST['ticket_reply'] ) and isset( $_POST['ticket_reply_nonce'] ) ) {
    if ( ! wp_verify_nonce( $_POST['ticket_reply_nonce'], 'ticket_reply') ) {
        $errors[] = __( 'Invalid Request.', 'arvand-panel' );
    }

    if ( ! empty( $_FILES['wpap_attachment']['name'] ) ) {
        $allowed_ext = [ 'image/jpeg', 'image/jpg', 'image/png', 'application/zip', 'application/x-zip-compressed', 'application/pdf' ];

        if ( ! in_array( $_FILES['wpap_attachment']['type'], $allowed_ext ) ) {
            $errors[] = __( 'Attachment file format is not allowed.', 'arvand-panel' );
        }

        if ( $_FILES['wpap_attachment']['size'] > ( 1204 * $ticket_opt['ticket_attachment_size'] ) ) {
            $errors[] = sprintf( __( 'Maximum attachment size is %d KB.', 'arvand-panel' ), $ticket_opt['ticket_attachment_size'] );
        }
    }

    if ( empty( $_POST['ticket_content'] ) ) {
        $errors[] = __( 'Reply must not be empty.', 'arvand-panel' );
    }

    $recipient = get_post_meta( $post->ID, 'wpap_ticket_recipient', true );

    if ( ! count( $errors ) ) {
        $from_admin = get_post_meta( $post->ID, 'wpap_from_admin', true );
        $user_id = $post->post_author;

        if ( $from_admin and $post->post_author == get_current_user_id() ) {
            $user_id = $recipient;
        }

        $meta_data = [
            'wpap_ticket_creator' => $post->post_author,
            'wpap_ticket_recipient' => $user_id
        ];

        $insert = wp_insert_post([
            'post_type' => 'wpap_ticket',
            'post_content' =>  wpautop( wp_kses( $_POST['ticket_content'], 'post' ) ),
            'post_parent' => $post_id,
            'post_status' => 'publish',
            'meta_input' => $meta_data
        ]);

        if ( ! is_wp_error( $insert ) ) {
            if ( ! empty( $_FILES['wpap_attachment']['name'] ) ) {
                $ticket->upload_attachment( $_FILES['wpap_attachment'], $insert );
            }

            $time = current_time( 'mysql' );

            wp_update_post([
                'ID' => $post->ID,
                'post_modified' => $time,
                'post_modified_gmt' => get_gmt_from_date( $time ),
            ]);

            $success = __( 'Reply sent.', 'arvand-panel' );
            $user_email = get_the_author_meta( 'email', $user_id );
            $headers = [ 'Content-Type: text/html; charset=UTF-8' ];
            $search = [ '[site_name]', '[site_url]', '[ticket_title]' ];
            $replace = [ get_bloginfo('name'), site_url(), $post->post_title ];
            $email_opt = wpap_email_options();
            $email_content = str_replace( $search, $replace, $email_opt['ticket_email_content'] );
            wp_mail( $user_email, sanitize_text_field( $email_opt['ticket_email_subject'] ), wpap_email_template( $email_content ), $headers );

            if ( $ticket_opt['enable_ticket_sms'] ) {
                $sms = new WPAPSMSDB();
                $user_mobile = get_user_meta( $user_id , 'wpap_user_phone_number', true );

                if ( $user_mobile ) {
                    $sms_text = str_replace( $search, $replace, $ticket_opt['ticket_sms_text'] );
                    WPAPSendMessage::send( $user_mobile, $sms_text );
                }
            }
        }
    }
}
?>

<div class="wpap-wrap wrap">
    <?php if ( count( $errors ) > 0 ): ?>
        <div class="notice notice-error is-dismissible">
            <ul>
                <?php foreach ( $errors as $error ): ?>
                    <li><strong>- <?php esc_html_e( $error ); ?></strong></li>
                <?php endforeach; ?>
            </ul>
        </div>
    <?php endif; ?>

    <?php if ( isset( $success ) ): ?>
        <div class="notice notice-success is-dismissible">
            <p><strong><?php esc_html_e( $success ); ?></strong></p>
        </div>
    <?php endif; ?>

    <div id="wpap-single-ticket">
        <div id="wpap-ticket-actions">
            <select id="wpap-ticket-status-select" data-post="<?php echo esc_attr( $post->ID ); ?>">
                <option hidden><?php _e( 'Change status', 'arvand-panel' ); ?></option>
                <?php $status = get_post_meta( $post_id, 'wpap_ticket_status', true ); ?>

                <?php if ( $status !== 'closed' ): ?>
                    <option value="closed"><?php _e( 'Closed', 'arvand-panel' ); ?></option>
                <?php endif; ?>

                <?php if ( $status !== 'open' ): ?>
                    <option value="open"><?php _e( 'Open', 'arvand-panel' ); ?></option>
                <?php endif; ?>

                <?php if ( $status !== 'solved' ): ?>
                    <option value="solved"><?php _e( 'Solved', 'arvand-panel' ); ?></option>
                <?php endif; ?>

                <?php if ( count( $ticket_opt['ticket_status']['name'] ) ): ?>
                    <?php for ( $i = 0; $i < count( $ticket_opt['ticket_status']['name'] ); $i++ ): ?>
                        <option value="<?php echo esc_attr( $ticket_opt['ticket_status']['name'][$i] ); ?>">
                            <?php echo esc_html( $ticket_opt['ticket_status']['name'][$i] ); ?>
                        </option>
                    <?php endfor; ?>
                <?php endif; ?>
            </select>

            <select id="wpap-ticket-dep-select" data-post="<?php echo esc_attr( $post->ID ); ?>">
                <option value="-1" hidden><?php _e( 'Change department', 'arvand-panel' ); ?></option>

                <?php
                foreach ( $ticket_dep_opt['departments'] as $dep ) {
                    echo "<option value='$dep'>$dep</option>";
                }
                ?>
            </select>

            <?php
            $args = [ 'del-ticket' => wp_create_nonce( 'del_ticket' ) ];
            $remove_args = [ 'close-ticket', 'open-ticket', 'ticket-status', 'ticket-status-color', 'ticket-status-text-color', 'ticket-status-nonce', 'del-ticket' ];
            ?>

            <a id="wpap-delete-ticket-btn" class="wpap-btn-3"
               href="<?php echo esc_url( add_query_arg( $args, remove_query_arg( $remove_args ) ) ); ?>"
               onclick="return confirm('<?php _e( 'Are you sure you want to delete this ticket?', 'arvand-panel' ); ?>')">
                <i class="bx bx-trash"></i>
                <?php _e( 'Delete Ticket', 'arvand-panel' ); ?>
            </a>
        </div>

        <article class="wpap-ticket wpap-message-card">
            <header>
                <div>
                    <?php
                    if ( $status ) {
                        if ( $status === 'closed' ) {
                            echo '<span id="wpap-ticket-status-name" class="wpap-badge-success">' . __( 'Closed', 'arvand-panel' ) . '</span>';
                        } elseif ( $status === 'solved' ) {
                            echo '<span id="wpap-ticket-status-name" class="wpap-badge-success">' . __( 'Solved', 'arvand-panel' ) . '</span>';
                        } elseif ( $status === 'open' ) {
                            echo '<span id="wpap-ticket-status-name" class="wpap-badge-error">' . __( 'Open', 'arvand-panel' ) . '</span>';
                        } else {
                            $status_color = get_post_meta( $post_id, 'wpap_ticket_status_color', true );
                            $status_text_color = get_post_meta( $post_id, 'wpap_ticket_status_text_color', true );
                            echo "<span id='wpap-ticket-status-name' class='wpap-badge' style='background-color: $status_color; color: $status_text_color;'>$status</span>";
                        }
                    }
                    ?>

                    <span class="wpap-badge">
                        <?php
                        $ticket_priority = get_post_meta( $post->ID, 'wpap_ticket_priority', true );

                        if ( $ticket_priority === 'low' ) {
                            echo __( 'Low priority', 'arvand-panel' );
                        } elseif ( $ticket_priority === 'normal' ) {
                            echo __( 'Normal priority', 'arvand-panel' );
                        } else {
                            echo __( 'High priority', 'arvand-panel' );
                        }
                        ?>
                    </span>

                    <span class="wpap-badge">
                        <?php
                        $attachment = get_post_meta( $post->ID, 'wpap_ticket_attachment', true );
                        echo $attachment ? __( 'Has attachment', 'arvand-panel' ) : __( 'No attachment', 'arvand-panel' );
                        ?>
                    </span>

                    <span id="wpap-ticket-dep-name" class="wpap-badge">
                        <?php
                        $department = get_post_meta( $post->ID, 'wpap_ticket_department', true );
                        echo sprintf( __( '%s department', 'arvand-panel' ), $department );
                        ?>
                    </span>
                </div>
            </header>

            <div class="wpap-message-card-content">
                <h3><?php echo $post->post_title; ?></h3>
                <?php echo get_the_content( '', '', $post->ID ); ?>
            </div>

            <footer>
                <?php echo get_avatar( $post->post_author, 70 ); ?>
                <span><?php echo get_the_author_meta( 'display_name', $post->post_author ); ?></span>
                <time><?php echo get_the_date( '', $post->ID ) . ' ' . get_the_time( '', $post->ID ); ?></time>

                <?php if ( $attachment ): ?>
                    <a class="wpap-attachment-file wpap-btn-3" href="<?php echo esc_url( $attachment ); ?>" download>
                        <i class="bx bx-paperclip"></i>
                        <?php _e( 'Attachment', 'arvand-panel' ); ?>
                    </a>
                <?php endif; ?>
            </footer>
        </article>

        <div id="wpap-ticket-replies">
            <?php
            $query = new WP_Query([
                'post_type' => 'wpap_ticket',
                'post_parent' => $post_id,
                'posts_per_page' => 20,
            ]);
            ?>

            <?php if ( $query->have_posts() ): ?>
                <?php while ( $query->have_posts() ): $query->the_post(); ?>
                    <?php
                    $author = get_the_author_meta( 'ID' );
                    $class = ( $post->post_author != $author ) ? 'wpap-user-reply' : '';
                    ?>

                    <article class="wpap-ticket wpap-message-card <?php esc_attr_e( $class ); ?>">
                        <div class="wpap-message-card-content"><?php the_content(); ?></div>

                        <footer>
                            <?php echo get_avatar( get_the_author_meta( 'ID' ), 50 ); ?>
                            <span><?php echo get_the_author_meta( 'login' ); ?></span>
                            <time><?php echo get_the_date() . ' ' . get_the_time(); ?></time>
                            <?php $attachment = get_post_meta( get_the_ID(), 'wpap_ticket_attachment', true ); ?>

                            <?php if ( $attachment ): ?>
                                <a class="wpap-attachment-file wpap-btn-3" href="<?php echo esc_url( $attachment ); ?>" download>
                                    <i class="bx bx-paperclip"></i>
                                    <?php _e( 'Attachment', 'arvand-panel' ); ?>
                                </a>
                            <?php endif; ?>
                        </footer>
                    </article>
                <?php endwhile; ?>
            <?php endif; ?>
        </div>

        <form id="wpap-reply-form" class="" method="post" enctype="multipart/form-data">
            <?php
            wp_nonce_field( 'ticket_reply', 'ticket_reply_nonce' );

            $args = [
                'media_buttons' => false,
                'textarea_name' => 'ticket_content',
                'textarea_rows' => 8,
                'quicktags' => false,
                'tinymce' => [
                    'toolbar1' => 'bold,italic,underline,separator,alignleft,aligncenter,alignright,separator,link,unlink,undo,redo',
                    'toolbar2' => '',
                    'toolbar3' => '',
                ],
            ];

            wp_editor( __( 'Your Message', 'arvand-panel' ), 'wpap-ticket-content', $args );
            ?>

            <p>
                <input id="wpap-attachment" type="file" name="wpap_attachment" hidden/>

                <label for="wpap-attachment" class="wpap-btn-3">
                    <i class="bx bx-upload"></i>
                    <?php _e( 'Upload Attachment', 'arvand-panel' ); ?>
                </label>

                <span class="wpap-input-info">
                    <?php echo sprintf( __( 'Maximum size is %d and allowed extensions: jpg - jpeg - png - pdf - zip', 'arvand-panel' ), $ticket_opt['ticket_attachment_size'] ); ?>
                </span>

                <span id="wpap-attachment-file-name"></span>
            </p>

            <input class="wpap-btn-1" type="submit" name="ticket_reply" value="<?php esc_attr_e('Send Reply', 'arvand-panel'); ?>"/>
        </form>
    </div>
</div>