<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}
?>

<div id="wpap-ticket-list" class="wpap-wrap wrap">
    <a id="wpap-new-ticket-btn" class="wpap-btn-1" href="<?php echo esc_url( add_query_arg( [ 'section' => 'users' ], remove_query_arg( $remove_args ) ) ); ?>">
        <i class='bx bx-plus'></i>
        <?php _e( 'New Ticket', 'arvand-panel' ); ?>
    </a>

    <div id="wpap-ticket-status-wrap">
        <a href="<?php echo esc_url( add_query_arg( [ 'ticket-status' => 'open' ], remove_query_arg( $remove_args ) ) ); ?>">
            <div id="wpap-open-tickets">
                <i class="bx bx-support"></i>
                <span><?php _e( 'Open', 'arvand-panel' ); ?></span>
                <?php $user_dep = WPAPTicket::userDepartment( get_current_user_id() ); ?>
                <span><?php esc_html_e( WPAPTicket::count( 'open', $user_dep ) ); ?></span>
            </div>
        </a>

        <?php
        $ticket_opt = wpap_ticket_options();
        $ticket_status = $ticket_opt['ticket_status'];
        ?>

        <?php if ( count( $ticket_status['name'] ) ): ?>
            <?php for ( $i = 0; $i < count( $ticket_status['name'] ); $i++ ): ?>
                <a href="<?php echo esc_url( add_query_arg( [ 'ticket-status' => $ticket_status['name'][$i] ], remove_query_arg( $remove_args ) ) ); ?>">
                    <div>
                        <i class="bx bx-support" style="color: <?php esc_attr_e( $ticket_status['color'][$i] ); ?>"></i>
                        <span><?php esc_html_e( $ticket_status['name'][$i] ); ?></span>
                        <span><?php esc_html_e( WPAPTicket::count( $ticket_status['name'][$i], $user_dep ) ); ?></span>
                    </div>
                </a>
            <?php endfor; ?>
        <?php endif; ?>

        <a href="<?php echo esc_url( add_query_arg( [ 'ticket-status' => 'solved' ], remove_query_arg( $remove_args ) ) ); ?>">
            <div id="wpap-solved-tickets">
                <i class="bx bx-support"></i>
                <span><?php _e( 'Solved', 'arvand-panel' ); ?></span>
                <span><?php esc_html_e( WPAPTicket::count( 'solved', $user_dep ) ); ?></span>
            </div>
        </a>

        <a href="<?php echo esc_url( add_query_arg( [ 'ticket-status' => 'closed' ], remove_query_arg( $remove_args ) ) ); ?>">
            <div id="wpap-closed-tickets">
                <i class="bx bx-support"></i>
                <span><?php _e( 'Closed', 'arvand-panel' ); ?></span>
                <span><?php esc_html_e( WPAPTicket::count( 'closed', $user_dep ) ); ?></span>
            </div>
        </a>

        <a href="<?php echo esc_url( add_query_arg( [], remove_query_arg( $remove_args ) ) ); ?>">
            <div id="wpap-all-tickets">
                <i class="bx bx-support"></i>
                <span><?php _e( 'All', 'arvand-panel' ); ?></span>
                <span><?php esc_html_e( WPAPTicket::count( '', $user_dep ) ); ?></span>
            </div>
        </a>
    </div>

    <div class="wpap-table-wrap">
        <table id="wpap-ticket-list-table">
            <thead>
                <th><?php _e( 'Number', 'arvand-panel' ); ?></th>
                <th><?php _e( 'Title', 'arvand-panel' ); ?></th>
                <th><?php _e( 'Creator', 'arvand-panel' ); ?></th>

                <?php
                $ticket_department_opt = wpap_ticket_department_options();

                if ( $ticket_department_opt['enable_department'] ) {
                    echo '<th>' . __( 'Department', 'arvand-panel' ) . '</th>';
                }
                ?>

                <th><?php _e( 'Status', 'arvand-panel' ); ?></th>
                <th><?php _e( 'Date', 'arvand-panel' ); ?></th>
                <th colspan="2"><?php _e('Actions', 'arvand-panel' ); ?></th>
            </thead>

            <tbody>
                <?php
                $args = [
                    'post_type' => 'wpap_ticket',
                    'post_parent' => 0,
                    'posts_per_page' => 20,
                    'orderby' => 'post_modified'
                ];

                if ( $ticket_department_opt['enable_department'] ) {
                    $args['meta_query'] = [
                        [
                            'relation' => 'OR',
                            [ 'key' => 'wpap_ticket_recipient', 'value' => get_current_user_id() ],
                            [ 'key' => 'wpap_ticket_creator', 'value' => get_current_user_id() ],
                            [ 'key' => 'wpap_ticket_department', 'value' => $user_dep, 'compare' => 'IN' ]
                        ]
                    ];
                }

                if ( isset( $_GET['ticket-status'] ) and ! empty( $_GET['ticket-status'] ) ) {
	                $status = sanitize_text_field( $_GET['ticket-status'] );

	                $args['meta_query'][] = [
		                [ 'key' => 'wpap_ticket_status', 'value' => $status ]
	                ];
                }

                $query = new WP_Query( $args );
                ?>

                <?php if ( $query->have_posts() ): ?>
                    <?php while ( $query->have_posts() ): $query->the_post(); ?>
                        <tr>
                            <td class="wpap-ticket-number">
                                <a href="<?php echo esc_url( add_query_arg( [ 'single-ticket' => get_the_ID() ], remove_query_arg( $remove_args ) ) ); ?>">
                                    <?php echo get_the_ID() . '#'; ?>
                                </a>
                            </td>

                            <td>
                                <a href="<?php echo esc_url( add_query_arg( [ 'single-ticket' => get_the_ID() ], remove_query_arg( $remove_args ) ) ); ?>">
                                    <strong><?php echo wp_trim_words( get_the_title(), 7 ); ?></strong>
                                </a>
                            </td>

                            <td><?php the_author(); ?></td>

                            <?php if ( $ticket_department_opt['enable_department'] ): ?>
                                <td>
                                    <?php
                                    $department = get_post_meta( get_the_ID(), 'wpap_ticket_department', true );
                                    echo $department ? esc_html( $department ) : '---';
                                    ?>
                                </td>
                            <?php endif; ?>

                            <td>
                                <?php
                                $status = get_post_meta( get_the_ID(), 'wpap_ticket_status', true );

                                if ( $status ) {
                                    if ( $status === 'closed' ) {
                                        echo '<span class="wpap-badge-success">' . __( 'Closed', 'arvand-panel' ) . '</span>';
                                    } elseif ( $status === 'solved' ) {
                                        echo '<span class="wpap-badge-success">' . __( 'Solved', 'arvand-panel' ) . '</span>';
                                    } elseif ( $status === 'open' ) {
                                        echo '<span class="wpap-badge-error">' . __( 'Open', 'arvand-panel' ) . '</span>';
                                    } else {
                                        $status_color = get_post_meta( get_the_ID(), 'wpap_ticket_status_color', true );
                                        $status_text_color = get_post_meta( get_the_ID(), 'wpap_ticket_status_text_color', true );
                                        echo "<span class='wpap-badge' style='background-color:$status_color; color: $status_text_color;'>$status</span>";
                                    }
                                } else {
                                    echo '___';
                                }
                                ?>
                            </td>

                            <td><?php echo get_the_date(); ?></td>

                            <td>
                                <a class="wpap-view-ticket" href="<?php echo esc_url( add_query_arg( [ 'single-ticket' => get_the_ID() ], remove_query_arg( $remove_args ) ) ); ?>">
                                    <i class="bx bx-show"></i>
                                </a>

                                <a class="wpap-delete-ticket" href="" data-ticket="<?php the_ID(); ?>">
                                    <i class="bx bx-trash"></i>
                                </a>
                            </td>
                        </tr>
                    <?php endwhile; ?>
                <?php else: ?>
                    <tr><td colspan="7"><?php _e( 'There is no ticket.', 'arvand-panel' ); ?></td></tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>
</div>