<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class WPAPPanel {
    public static function panel_url()
    {
        $redirect_url = '';
        $pages_opt = wpap_pages_options();
        $panel_url = get_permalink( $pages_opt['panel_page_id'] );

        if ( $panel_url ) {
            $redirect_url = $panel_url;
        } else {
            $panel = get_page_by_path('wpap-panel', OBJECT );

            if ( $panel ) {
                $redirect_url = esc_url( home_url( 'wpap-panel' ) );
            }
        }

        return $redirect_url;
    }

    public static function allowed_sections()
    {
        $sections = [];
        $role = array_values( wp_get_current_user()->roles );
        $login = wpap_login_options();

        foreach ( WPAPPanelMenusDB::get_all_menus() as $menu ) {
            $access = unserialize( $menu['menu_access'] );

            if ( $menu['menu_display'] === 'show' and is_array( $access ) and count( array_intersect( $role, $access ) ) ) {
                if ( $menu['menu_name'] === 'mobile' and ! $login['enable_sms_register_login'] ) {
                    continue;
                }

                if ( $menu['menu_name'] === 'tickets' ) {
                    $sections[] = 'single-ticket';
                }

                if ( $menu['menu_name'] === 'private_msg' ) {
                    $sections[] = 'single-msg';
                }

                $sections[] = str_replace( '_', '-', $menu['menu_name'] );
            }
        }

        return $sections;
    }

    public static function dash_box_settings_html()
    {
        ob_start(); ?>

        <div class="wpap-box-settings">
            <input class="wpap-box-name" type="hidden" name="box_id[]"/>

            <p>
                <label><?php _e( 'Box icon', 'arvand-panel' ); ?></label>
                <input type="text" name="icon[]" value="bx bxs-star"/>
            </p>

            <p>
                <label><?php _e( 'Box icon color', 'arvand-panel' ); ?></label>
                <input type="text" name="icon_color[]" value="#ffffff"/>
            </p>

            <p>
                <label><?php _e( 'Box icon background color', 'arvand-panel' ); ?></label>
                <input type="text" name="icon_bg[]" value="#0078ff"/>
            </p>

            <p>
                <label><?php _e( 'Box title', 'arvand-panel' ); ?></label>
                <input type="text" name="title[]" value="<?php _e( 'Box title', 'arvand-panel' ); ?>"/>
            </p>

            <p>
                <label><?php _e( 'Box content', 'arvand-panel' ); ?></label>
                <input type="text" name="content[]" value="<?php _e( 'Box content', 'arvand-panel' ); ?>"/>
            </p>

            <input type="hidden" name="box_type[]" value="custom"/>
        </div>

        <?php return ob_get_clean();
    }

    public static function dash_box_html()
    {
        ob_start();
        require_once WPAP_ADMIN_PATH . 'parts/dash-box.php';
        return ob_get_clean();
    }

    public static function notice_count() {
        $user_id = get_current_user_id();
        $last_read = get_user_meta( $user_id, 'wpap_notice_read', true );
        $count = 0;

        $posts = get_posts([
            'post_type' => 'wpap_notifications',
            'publish' => true,
            'numberposts' => -1
        ]);

        foreach ( $posts as $post ) {
            if ( ! $last_read or get_post_timestamp( $post->ID ) > $last_read ) $count++;
        }

        return $count;
    }

    public static function set_last_notice_time() {
        $posts = get_posts( [ 'post_type' => 'wpap_notifications' ] );
        $count = 0;

        if ( count( $posts ) > 0 ) {
            foreach ( $posts as $post ) {
                $count++;

                if ( $count == 1 ) {
                    update_user_meta( get_current_user_id(), 'wpap_notice_read', get_post_timestamp( $post->ID ) );
                }
            }
        }
    }

    public static function important_notices( $place = 'dashboard' ) {
        $posts = get_posts([
            'post_type' => 'wpap_notifications',
            'numberposts' => -1,
            'post_status' => 'publish',
            'meta_query' => [
                [ 'key' => 'wpap_important_notice', 'value' => 1 ],
                [ 'key' => 'wpap_important_notice_place', 'value' => $place ],
            ]
        ]);

        ob_start(); ?>

        <?php if ( count( $posts ) ): ?>
            <?php $class = ( ! isset( $_GET['section'] ) or ( isset( $_GET['section'] ) and $_GET['section'] === 'dash' ) ) ? 'class=wpap-dashboard-important-notice' : ''; ?>

            <div id="wpap-important-notice" <?php esc_attr_e( $class ); ?>>
                <?php foreach ( $posts as $post ): ?>
                    <?php $type = get_post_meta( $post->ID, 'wpap_important_notice_type', true );?>
                    <div class="wpap-msg wpap-<?php esc_attr_e( $type ); ?>-msg">
                        <?php
                        $icon = 'bx bx-info-circle';

                        switch ( $type ) {
                            case 'error';
                                $icon = 'bx bx-x-circle';
                                break;
                            case 'success';
                                $icon = 'bx bx-check-circle';
                                break;
                            case 'warning';
                                $icon = 'bx bx-error';
                                break;
                        }
                        ?>

                        <i class="<?php esc_attr_e( $icon ); ?>"></i>

                        <?php if ( empty( $post->post_title ) ): ?>
                            <span class="wpap-msg-text"><?php echo wp_strip_all_tags( $post->post_content ); ?></span>
                        <?php else: ?>
                            <div>
                                <h3><?php echo wp_strip_all_tags( $post->post_title ); ?></h3>
                                <span><?php echo wp_strip_all_tags( $post->post_content ); ?></span>
                            </div>
                        <?php endif; ?>

                        <i class="bx bx-x wpap-dismiss-msg"></i>
                    </div>
                <?php endforeach; ?>
            </div>
        <?php endif; ?>

        <?php echo ob_get_clean();
    }
}