<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class WPAPPanelMenus extends WPAPPanelMenusDB
{
	static function init()
	{
        add_action( 'wp_ajax_wpap_delete_menu', [ __CLASS__, 'deleteMenu' ] );
    }

    static function default_menus()
    {
        return [
            'dash',
            'home',
            'user_edit',
            'change_email',
            'change_password',
            'notifications',
            'comments',
            'new_ticket',
            'tickets',
            'private_msg',
            'logout'
        ];
    }

    static function menu_field()
    {
        ob_start();
        require_once WPAP_ADMIN_PATH . 'parts/menu-item.php';
        return ob_get_clean();
    }

    static function menu_settings( $parent = 0 )
    {
        ob_start();
        $panel_menus = new WPAPPanelMenusDB();
        $menus = $panel_menus->get_menus( $parent );
        ?>

        <?php foreach ( $menus as $menu ): ?>
            <div class="wpap-menu-item">
                <div class="wpap-menu" data-id="<?php esc_attr_e( $menu['menu_id'] ); ?>">
                    <h3>
                        <i class="<?php esc_attr_e( $menu['menu_icon'] ); ?>"></i>
                        <span><?php esc_html_e( $menu['menu_title'] ); ?></span>
                    </h3>

                    <i class="wpap-show-menu-settings bx bx-cog"></i>

                    <?php if ( $menu['menu_type'] === 'parent' ): ?>
                        <i class="wpap-show-child-menus bx bx-plus"></i>
                    <?php endif; ?>

                    <i class="bx bx-<?php echo $menu['menu_display'] === 'show' ? 'show' : 'hide'; ?>"></i>

                    <?php if ( $menu['menu_type'] !== 'default' ): ?>
                        <i class="wpap-remove-menu bx bx-trash"
                           data-nonce="<?php echo wp_create_nonce( 'delete_menu' ); ?>"
                           data-id="<?php echo esc_attr( $menu['menu_id'] ); ?>">
                        </i>
                    <?php endif; ?>
                </div>

                <?php include WPAP_ADMIN_PATH . 'parts/menu-setting-fields.php'; ?>

                <?php if ( $menu['menu_type'] !== 'default' and ! $menu['menu_parent'] ): ?>
                    <div class="wpap-child-menus"><?php self::menu_settings( $menu['menu_id'] ); ?></div>
                <?php endif; ?>
            </div>
        <?php endforeach; ?>

        <?php echo ob_get_clean();
    }

    static function show_menus( $parent, $data )
    {
        ob_start();
        $panel_menus = $data['panel_menus'];
        $menus = $panel_menus->get_menus( $parent );
        ?>

        <?php foreach ( $menus as $menu ): ?>
            <?php
            $slug = str_replace( '_', '-', $menu['menu_name'] );

            if ( ! in_array( $slug, $data['sections'] ) ) {
                continue;
            }

            $logout_id = $menu['menu_name'] === 'logout' ? 'id=wpap-logout' : '';
            $active_class = self::active_section( $slug ) ? 'wpap-active' : '';
            $url = esc_url( add_query_arg( [ 'section' => $slug ], remove_query_arg( $data['remove_args'] ) ) );
            $blank = ( $menu['menu_name'] === 'home' or $menu['menu_type'] === 'link' ) ? 'target="_blank"' : '';
            $is_parent = $menu['menu_type'] === 'parent';
            $parent_class = $is_parent ? 'wpap-parent' : '';

            if ( $menu['menu_name'] === 'home' ) {
                $url = home_url();
            }

            if ( $menu['menu_name'] === 'logout' ) {
                $url = $data['after_logout'];
            }

            if ( $menu['menu_type'] === 'link' ) {
                $url = esc_url( $menu['menu_content'] );
            }

            if ( ( ! isset( $_GET['section'] ) or ! in_array( $_GET['section'], $data['sections'] ) ) and $menu['menu_name'] === 'dash' ) {
                $active_class = 'wpap-active';
            }
            ?>

            <a <?php echo "$logout_id href='$url' class='wpap-menu-link $active_class $parent_class' $blank"; ?>>
                <i class="<?php echo esc_attr( $menu['menu_icon'] ); ?>"></i>
                <span><?php echo esc_attr( $menu['menu_title'] ); ?></span>

                <?php
                if ( $menu['menu_name'] === 'notifications' and $data['notice_count'] ) {
                    echo '<i class="wpap-menu-unread bx bxs-bell"></i>';
                }

                if ( $menu['menu_name'] === 'private_msg' and $data['msg_count'] ) {
                    echo '<i class="wpap-menu-unread bx bxs-bell"></i>';
                }

                echo $is_parent ? '<i class="bx bx-plus"></i>' : '';
                ?>
            </a>

            <?php if ( $is_parent ): ?>
                <?php $open = ( isset( $_GET['section'] ) and in_array( $_GET['section'], $panel_menus->child_names( $menu['menu_id'] ) ) ); ?>

                <div class="wpap-children <?php echo $open ? 'wpap-open' : ''; ?>">
                    <a href="#" class="wpap-hide-children">
                        <i class='bx bx-rotate-right'></i>
                        <span><?php _e( 'Back', 'arvand-panel' ); ?></span>
                    </a>

                    <?php self::show_menus( $menu['menu_id'], $data ); ?>
                </div>
            <?php endif; ?>
        <?php endforeach; ?>

        <?php echo ob_get_clean();
    }

    static function active_section( $section ) {
        $active = false;

        if ( isset( $_GET['section'] ) and is_array( $section ) and in_array( $_GET['section'], $section ) ) {
            $active = true;
        } elseif ( isset( $_GET['section'] ) and ! empty( $_GET['section'] ) and $_GET['section'] === $section ) {
            $active = true;
        }

        return $active;
    }

    static function childrenDisplay( $section, $panel_menus ) {
        $name = explode( '-', $section )[0] !== 'section' ? str_replace( '-', '_', $section ) : $section;
        $menu = $panel_menus->getMenuByName( $name );
        return ( $menu and $menu['menu_parent'] ) ? 'style="transform: translateX(100%)"' : null;
    }

    static function menu_content( $name )
    {
        $menu = new WPAPPanelMenusDB();
        $res = $menu->getMenuByName( $name );

        if ( $res ) {
            if ( 'shortcode' === $res['menu_type'] ) {
                return do_shortcode( wp_kses( $res['menu_content'], 'post' ) );
            }

            if ( 'page' === $res['menu_type'] ) {
                $post = get_post( intval( $res['menu_post_id'] ) ); ?>

                <?php if ( $post ): ?>
                    <?php ob_start(); ?>

                    <div id="wpap-post">
                        <h2 id="wpap-post-title">
                            <?php echo get_the_title( $post->ID ); ?>
                        </h2>

                        <div id="wpap-post-content">
                            <?php echo do_shortcode( get_the_content( '', '', $post->ID ) ); ?>
                        </div>
                    </div>

                    <?php return ob_get_clean();
                endif;
            }
        }

        return false;
    }

    static function deleteMenu()
    {
        if ( ! isset( $_POST['nonce'] ) or ! wp_verify_nonce( $_POST['nonce'], 'delete_menu' ) ) {
	        wp_send_json( 'error' );
        }

	    if ( empty( $_POST['id'] ) or ! is_numeric( $_POST['id'] ) ) {
		    wp_send_json( 'error' );
	    }

        $id = intval( $_POST['id'] );
        $db = new WPAPPanelMenusDB;
        $children = $db->get_childs( $id );

        if ( $children ) {
	        global $wpdb;

            foreach ( $children as $child ) {
	            $wpdb->update( "{$wpdb->prefix}wpap_menus", [ 'menu_parent' => 0 ], [ 'menu_id' => $child['menu_id'] ], null, [ '%d' ] );
            }
        }

        $delete = $db->delete_menu( $id );
        wp_send_json( $delete ? 'success' : 'error' );
    }
}

WPAPPanelMenus::init();