<?php


class WPAPPanelMenusDB
{
    public function create_table()
    {
        global $wpdb;
        $table = $wpdb->prefix . 'wpap_menus';
        $charset_collate = $wpdb->get_charset_collate();
        $sql = "CREATE TABLE IF NOT EXISTS $table ( menu_id INT NOT NULL AUTO_INCREMENT, menu_name VARCHAR(50) NOT NULL UNIQUE, menu_order INT NOT NULL, menu_icon TEXT NOT NULL, menu_title VARCHAR(50) NOT NULL, menu_content TEXT NOT NULL, menu_access TEXT NOT NULL, menu_type VARCHAR(20) NOT NULL, menu_display VARCHAR(10) NOT NULL, menu_parent INT NOT NULL DEFAULT 0, menu_post_id INT NOT NULL DEFAULT 0, PRIMARY KEY  (menu_id) ) $charset_collate;";

        require_once ABSPATH . 'wp-admin/includes/upgrade.php';

        dbDelta( $sql );
    }

    public function menu_exist( $val )
    {
        global $wpdb;
        $res = $wpdb->get_row( $wpdb->prepare( "SELECT menu_name FROM {$wpdb->prefix}wpap_menus WHERE menu_name = %s", $val ) );
        return ( bool ) $res;
    }

    public function insert_menu( $data )
    {
        global $wpdb;
        $table = $wpdb->prefix . 'wpap_menus';

        if ( $this->menu_exist( $data[0] ) ) {
            return false;
        }

        $data = [
            'menu_name' => $data[0],
            'menu_order' => $data[1],
            'menu_icon' => $data[2],
            'menu_title' => $data[3],
            'menu_content' => $data[4],
            'menu_access' => maybe_serialize( $data[5] ),
            'menu_type' => $data[6],
            'menu_display' => $data[7],
            'menu_post_id' => $data[8],
            'menu_parent' => $data[9],
        ];

        $format = [ '%s', '%d', '%s', '%s', '%s', '%s', '%s', '%s', '%d', '%d' ];
        $insert = $wpdb->insert( $table, $data, $format );
        $res = true;

        if ( $insert and $data['menu_name'] === 'section' ) {
            $update = $wpdb->update( $table, [ 'menu_name' => "section-$wpdb->insert_id" ], [ 'menu_id' => $wpdb->insert_id ], '%s' );
            $res = ( bool ) $update;
        }

        return $res;
    }

    public function update_menu( $data, $id )
    {
        global $wpdb;
        $table = $wpdb->prefix . 'wpap_menus';

        $data = [
            'menu_name' => $data[0],
            'menu_order' => $data[1],
            'menu_icon' => $data[2],
            'menu_title' => $data[3],
            'menu_content' => $data[4],
            'menu_access' => maybe_serialize( $data[5] ),
            'menu_type' => $data[6],
            'menu_display' => $data[7],
            'menu_post_id' => $data[8],
            'menu_parent' => $data[9],
        ];

        $format = [ '%s', '%d', '%s', '%s', '%s', '%s', '%s', '%s', '%d', '%d' ];

        return $wpdb->update( $table, $data, [ 'menu_id' => $id ], $format );
    }

    public function get_menus( $parent = 0 )
    {
        global $wpdb;
        $table = $wpdb->prefix . 'wpap_menus';
        return $wpdb->get_results( "SELECT * FROM $table WHERE menu_parent = $parent ORDER BY menu_order ASC", ARRAY_A );
    }

    static function get_all_menus()
    {
        global $wpdb;
        $table = $wpdb->prefix . 'wpap_menus';
        return $wpdb->get_results( "SELECT * FROM $table", ARRAY_A );
    }

    public function get_menu_by_id( $id )
    {
        global $wpdb;
        $table = $wpdb->prefix . 'wpap_menus';
        return $wpdb->get_row( $wpdb->prepare( "SELECT * FROM $table WHERE menu_id = %d", $id ), ARRAY_A );
    }

    public function menu_ids()
    {
        global $wpdb;
        $table = $wpdb->prefix . 'wpap_menus';
        $res = $wpdb->get_results( "SELECT menu_id FROM $table" );
        $ids = [];

        foreach ( $res as $id ) $ids[] = $id->menu_id;

        return $ids;
    }

    public function get_parents() {
        global $wpdb;
        $table = $wpdb->prefix . 'wpap_menus';
        return $wpdb->get_results( "SELECT * FROM $table WHERE menu_type = 'parent' ORDER BY menu_order ASC", ARRAY_A );
    }

    public function get_childs( $id )
    {
        global $wpdb;
        $table = $wpdb->prefix . 'wpap_menus';
        return $wpdb->get_results( $wpdb->prepare( "SELECT * FROM $table WHERE menu_parent = %d ORDER BY menu_order ASC", $id ), ARRAY_A );
    }

    public function getMenuByName( $name )
    {
        global $wpdb;
        return $wpdb->get_row( $wpdb->prepare( "SELECT * FROM {$wpdb->prefix}wpap_menus WHERE menu_name = %s", $name ), ARRAY_A );
    }

    public function child_names( $id )
    {
        global $wpdb;
        $table = $wpdb->prefix . 'wpap_menus';
        $res = $wpdb->get_results( $wpdb->prepare( "SELECT menu_name FROM $table WHERE menu_parent = %d", $id ) );
        $names = [];

        foreach ( $res as $name ) {
            $names[] = str_replace( '_', '-', $name->menu_name );
        }

        return $names;
    }

    public function delete_menu( $id )
    {
        global $wpdb;
        return $wpdb->delete( "{$wpdb->prefix}wpap_menus", [ 'menu_id' => $id ], [ '%d' ]  );
    }
}