<?php


class WPAPPluginActivation
{
    static function init()
    {
        register_activation_hook( WPAP_DIR_PATH . 'arvand-panel.php', [ __CLASS__, 'wpapPluginActivate' ] );
    }

    static function wpapPluginActivate() {
        if ( ! current_user_can( 'activate_plugins' ) ) {
            return;
        }

        self::createSMSVerificationTable();
        self::generateRequiredRegFields();
        self::generateMenus();

		if ( ! get_option( 'wpap_ plugin_is_installed' ) ) {
			self::generatePages();
			add_option( 'wpap_plugin_is_installed', 'yes' );
		}
    }

    static function createSMSVerificationTable()
    {
        global $wpdb;
        $table = $wpdb->prefix . 'wpap_sms_verification';
        $charset_collate = $wpdb->get_charset_collate();
        $sql = "CREATE TABLE IF NOT EXISTS $table ( id INT NOT NULL AUTO_INCREMENT, user_id INT NOT NULL, mobile VARCHAR(12) NOT NULL, code INT NOT NULL, status VARCHAR(20) NOT NULL, PRIMARY KEY  (id) ) $charset_collate;";
        require_once ABSPATH . 'wp-admin/includes/upgrade.php';
        dbDelta( $sql );
    }

    static function generatePages() {
        global $wpdb;
        $q = "SELECT post_name FROM {$wpdb->prefix}posts WHERE post_name = 'wpap-panel'";
	    $data = wpap_pages_options();

        if ( null === $wpdb->get_row( $q, 'ARRAY_A' ) ) {
            $page = array(
                'post_title' => __( 'User Panel - mega Panel', 'arvand-panel' ),
                'post_name' => 'wpap-panel',
                'post_content' => '[wpap_user_panel]',
                'post_status' => 'publish',
                'post_author' => get_current_user_id(),
                'post_type' => 'page',
            );

	        $insert = wp_insert_post( $page );
	        $data['panel_page_id'] = $insert;
	        $data['after_login_page_id'] = $insert;
        }

        $q = "SELECT post_name FROM {$wpdb->prefix}posts WHERE post_name = 'wpap-register'";

        if ( null === $wpdb->get_row( $q, 'ARRAY_A' ) ) {
            $page = array(
                'post_title' => __( 'Register - mega Panel', 'arvand-panel' ),
                'post_name' => 'wpap-register',
                'post_content' => '[wpap_register_form]',
                'post_status' => 'publish',
                'post_author' => get_current_user_id(),
                'post_type' => 'page',
            );

	        $data['register_page_id'] = wp_insert_post( $page );
        }

        $q = "SELECT post_name FROM {$wpdb->prefix}posts WHERE post_name = 'wpap-login'";

        if ( null === $wpdb->get_row( $q, 'ARRAY_A' ) ) {
            $page = array(
                'post_title' => __( 'Login - mega Panel', 'arvand-panel' ),
                'post_name' => 'wpap-login',
                'post_content' => '[wpap_login_form]',
                'post_status' => 'publish',
                'post_author' => get_current_user_id(),
                'post_type' => 'page',
            );

	        $insert = wp_insert_post( $page );
            $data['login_page_id'] = $insert;
	        $data['after_logout_page_id'] = $insert;
	        $data['after_register_page_id'] = $insert;
	        $data['after_sms_register_login_page_id'] = $insert;
        }

	    $q = "SELECT post_name FROM {$wpdb->prefix}posts WHERE post_name = 'wpap-register-login'";

	    if ( null === $wpdb->get_row( $q, 'ARRAY_A' ) ) {
		    $page = array(
			    'post_title' => __( 'SMS Register or login - mega Panel', 'arvand-panel' ),
			    'post_name' => 'wpap-register-login',
			    'post_content' => '[wpap_sms_register_login]',
			    'post_status' => 'publish',
			    'post_author' => get_current_user_id(),
			    'post_type' => 'page',
		    );

		    $insert = wp_insert_post( $page );
		    $data['sms_register_login_page_id'] = $insert;
	    }

        $q = "SELECT post_name FROM {$wpdb->prefix}posts WHERE post_name = 'wpap-lost-password'";

        if ( null === $wpdb->get_row( $q, 'ARRAY_A' ) ) {
            $page = array(
                'post_title'  => __( 'Lost Password - mega Panel', 'arvand-panel' ),
                'post_name' => 'wpap-lost-password',
                'post_content' => '[wpap_lost_password_form]',
                'post_status' => 'publish',
                'post_author' => get_current_user_id(),
                'post_type' => 'page',
            );

            $data['lost_pass_page_id'] = wp_insert_post( $page );
        }

        $q = "SELECT post_name FROM {$wpdb->prefix}posts WHERE post_name = 'wpap-reset-password'";

        if ( null === $wpdb->get_row( $q, 'ARRAY_A' ) ) {
            $page = array(
                'post_title'  => __( 'Reset Password - mega Panel', 'arvand-panel' ),
                'post_name' => 'wpap-reset-password',
                'post_content' => '[wpap_reset_password_form]',
                'post_status' => 'publish',
                'post_author' => get_current_user_id(),
                'post_type' => 'page',
            );

            $data['reset_pass_page_id'] = wp_insert_post( $page );
        }

		update_option( 'wpap_plugin_pages', $data );
    }

    static function generateRequiredRegFields() {
        if ( ! WPAPField::field_exist( 'first_name' ) ) {
            $settings = [
                'placeholder' => __( 'Firstname', 'arvand-panel' ),
                'required' => false,
                'min' => 0,
                'info' => '',
                'user_edit_display' => 'show',
            ];

            $field_data = [
                'post_title' => 'first_name',
                'post_type' => 'wpap_reg_field',
                'post_content' => maybe_serialize( $settings ),
                'menu_order' => 0,
                'post_status' => 'publish',
            ];

            wp_insert_post( $field_data );
        }

        if ( ! WPAPField::field_exist( 'last_name' ) ) {
            $settings = [
                'placeholder' => __( 'Lastname', 'arvand-panel' ),
                'required' => false,
                'min' => 0,
                'info' => '',
                'user_edit_display' => 'show',
            ];

            $field_data = [
                'post_title' => 'last_name',
                'post_type' => 'wpap_reg_field',
                'post_content' => maybe_serialize( $settings ),
                'menu_order' => 1,
                'post_status' => 'publish',
            ];

            wp_insert_post( $field_data );
        }

        if ( ! WPAPField::field_exist( 'user_login' ) ) {
            $settings = [
                'placeholder' => __( 'Username', 'arvand-panel' ),
                'min' => 5,
                'info' => '',
                'user_edit_display' => 'hide',
            ];

            $field_data = [
                'post_title' => 'user_login',
                'post_type' => 'wpap_reg_field',
                'post_content' => maybe_serialize( $settings ),
                'menu_order' => 2,
                'post_status' => 'publish',
            ];

            wp_insert_post( $field_data );
        }

        if ( ! WPAPField::field_exist( 'user_email' ) ) {
            $settings = [
                'placeholder' => __( 'Email', 'arvand-panel' ),
                'info' => '',
                'user_edit_display' => 'show',
            ];

            $field_data = [
                'post_title' => 'user_email',
                'post_type' => 'wpap_reg_field',
                'post_content' => maybe_serialize( $settings ),
                'menu_order' => 3,
                'post_status' => 'publish',
            ];

            wp_insert_post( $field_data );
        }

        if ( ! WPAPField::field_exist( 'user_pass' ) ) {
            $settings = [
                'placeholder' => __( 'Password', 'arvand-panel' ),
                'conf_placeholder' => __( 'Confirm Pasword', 'arvand-panel' ),
                'info' => '',
                'min' => 8,
                'user_edit_display' => 'hide',
            ];

            $field_data = [
                'post_title' => 'user_pass',
                'post_type' => 'wpap_reg_field',
                'post_content' => maybe_serialize( $settings ),
                'menu_order' => 4,
                'post_status' => 'publish',
            ];

            wp_insert_post( $field_data );
        }
    }

    static function generateMenus() {
        $menus = new WPAPPanelMenusDB();
        $roles = get_editable_roles();
        $access = array_keys( $roles );

        $menus->create_table();
        $menus->insert_menu( [ 'dash', 0, 'bx bx-tachometer', __( 'Dashboard', 'arvand-panel' ), 'default', $access, 'default', 'show', 0, 0 ] );
        $menus->insert_menu( [ 'home', 1, 'bx bx-home', __( 'Home', 'arvand-panel' ), 'default', $access, 'default', 'hide', 0, 0 ] );
        $menus->insert_menu( [ 'user_edit', 2, 'bx bx-edit', __( 'Edit Profile', 'arvand-panel' ), 'default', $access, 'default', 'show', 0, 0 ] );
        $menus->insert_menu( [ 'change_email', 3, 'bx bx-envelope', __( 'Change Email', 'arvand-panel' ), 'default', $access, 'default', 'show', 0, 0 ] );
        $menus->insert_menu( [ 'change_password', 3, 'bx bx-key', __( 'Change Password', 'arvand-panel' ), 'default', $access, 'default', 'show', 0, 0 ] );
        $menus->insert_menu( [ 'mobile', 4, 'bx bx-mobile-vibration', __( 'add mobile', 'arvand-panel' ), 'default', $access, 'default', 'show', 0, 0 ] );
        $menus->insert_menu( [ 'notifications', 5, 'bx bx-bell', __( 'Notifications', 'arvand-panel' ), 'default', $access, 'default', 'show', 0, 0 ] );
        $menus->insert_menu( [ 'comments', 6, 'bx bx-comment-dots', __( 'Comments', 'arvand-panel' ), 'default', $access, 'default', 'show', 0, 0 ] );
        $menus->insert_menu( [ 'new_ticket', 7, 'bx bx-edit-alt', __( 'New Ticket', 'arvand-panel' ), 'default', $access, 'default', 'show', 0, 0 ] );
        $menus->insert_menu( [ 'tickets', 8, 'bx bx-support', __( 'Tickets', 'arvand-panel' ), 'default', $access, 'default', 'show', 0, 0 ] );
        $menus->insert_menu( [ 'private_msg', 9, 'bx bx-message-square-detail', __( 'Private Message', 'arvand-panel' ), 'default', $access, 'default', 'show', 0, 0 ] );
        $menus->insert_menu( [ 'section-orders', 10, 'bx bx-spreadsheet', __( 'Orders', 'arvand-panel' ), '[wpap_woo_orders]', $access, 'shortcode', 'show', 0, 0 ] );
        $menus->insert_menu( [ 'section-downloads', 11, 'bx bx-download', __( 'Downloads', 'arvand-panel' ), '[wpap_woo_downloads]', $access, 'shortcode', 'show', 0, 0 ] );
        $menus->insert_menu( [ 'section-address', 12, 'bx bx-map', __( 'Addresses', 'arvand-panel' ), '[wpap_woo_address]', $access, 'shortcode', 'show', 0, 0 ] );
        $menus->insert_menu( [ 'logout', 13, 'bx bx-power-off', __( 'Logout', 'arvand-panel' ), 'default', $access, 'default', 'hide', 0, 0 ] );
    }
}

WPAPPluginActivation::init();