<?php


class WPAPPrivateMessage
{
    public static function init()
    {
        add_action( 'delete_user', [ __CLASS__, 'delete_message_by_delete_user' ] );
    }

    public static function upload_msg_attachment( $file, $post_id ) {
        if ( ! function_exists( 'wp_handle_upload' ) ) {
            require_once( ABSPATH . 'wp-admin/includes/file.php' );
        }

        $upload = wp_handle_upload( $file, [ 'test_form' => false ] );

        if ( $upload and ! isset( $upload['error'] ) ) {
            add_post_meta( $post_id, 'wpap_msg_attachment', $upload['url'] );
        }
    }

    public static function msg_count( $user_id = 0, $author_id = 0, $parent = 0 ) {
        $args = [
            'post_type' => 'wpap_private_message',
            'numberposts' => -1,
            'post_parent' => $parent,
        ];

        if ( $user_id > 0 ) {
            $args['meta_key'] = 'wpap_private_msg_recipient';
            $args['meta_value'] = intval( $user_id );
        }

        if ( $author_id > 0 ) {
            $args['author'] = intval( $author_id );
        }

        return count( get_posts( $args ) );
    }

    public static function msg_unread_count( $user_id, $parent = 0 ) {
        $args = [
            'post_type' => 'wpap_private_message',
            'publish' => true,
            'meta_query' => [
                [ 'key' => 'wpap_read', 'value' => 'unread' ],
                [ 'key' => 'wpap_private_msg_recipient', 'value' => $user_id ],
            ],
            'numberposts' => -1,
        ];

        if ( $parent > 1 ) {
            $args['post_parent'] = $parent;
        }

        return count( get_posts( $args ) );
    }

    public static function msg_admin_unread_count( $user_id, $parent = 0, $author = 0 ) {
        $args = [
            'post_type' => 'wpap_private_message',
            'publish' => true,
            'meta_query' => [
                [ 'key' => 'wpap_admin_msg_read', 'value' => 'unread' ],
                [ 'key' => 'wpap_private_msg_recipient', 'value' => $user_id ],
            ],
            'numberposts' => -1,
        ];

        if ( $parent > 1 ) {
            $args['post_parent'] = $parent;
        }

        if ( $author > 1 ) {
            $args['author'] = $author;
        }

        return count( get_posts( $args ) );
    }

    public static function msg_read_count( $user_id ) {
        $posts = get_posts([
            'post_type' => 'wpap_private_message',
            'publish' => true,
            'meta_query' => [
                [ 'key' => 'wpap_private_msg_recipient', 'value' => $user_id ],
                [ 'key' => 'wpap_msg_read', 'compare' => 'NOT EXISTS']
            ],
            'numberposts' => -1,
        ]);

        $count = 0;

        while ( $count < count( $posts ) ) $count++;

        return $count;
    }

    public static function delete_messages( $user_id = 0, $author_id = 0 ) {
        $args = [ 'post_type' => 'wpap_private_message', 'numberposts' => -1 ];

        if ( $user_id > 0 ) {
            $args['meta_key'] = 'wpap_private_msg_recipient';
            $args['meta_value'] = intval( $user_id );
        }

        if ( $author_id > 0 ) {
            $args['author'] = intval( $author_id );
        }

        $posts = get_posts( $args );

        foreach ( $posts as $post ) {
            $childs = get_posts( [ 'post_type' => 'wpap_private_message', 'post_parent' => $post->ID ] );

            if ( count( $childs ) ) {
                foreach ( $childs as $child ) {
                    wp_delete_post( $child->ID, true );
                }
            }

            wp_delete_post( $post->ID, true );
        }
    }

    public static function delete_message_by_delete_user( $user_id ) {
        $posts = get_posts( [ 'post_type' => 'wpap_private_message', 'author' => $user_id, 'numberposts' => -1 ] );

        if ( count( $posts ) ) {
            foreach ( $posts as $post ) {
                wp_delete_post( $post->ID, true );
            }
        }
    }
}