<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class WPAPShortCode {
    static function init()
    {
        foreach ( self::pluginShortcodes() as $shortcode ) {
            add_shortcode( "wpap_$shortcode", [ __CLASS__, $shortcode ] );
        }
    }

    static function pluginShortcodes()
    {
        return [
            'register_form',
            'login_form',
            'sms_register_login',
            'lost_password_form',
            'reset_password_form',
            'user_panel',
            'woo_orders',
            'woo_downloads',
            'woo_address',
            'profile_menu',
        ];
    }

    static function register_form()
    {
	    $register = wpap_register_options();
	    $pages_opt = wpap_pages_options();

	    if ( $register['pass_strength'] ) {
		    wp_enqueue_script( 'wpap_password_strength' );
	    }

        if ( ! is_admin_bar_showing() ) {
            wp_enqueue_style('dashicons');
        }

        wp_enqueue_script( 'password-strength-meter' );
        ob_start();

        require WPAP_USER_PATH . 'styles/styles.php'; ?>

	    <div id="wpap-register">
            <?php
            if ( ! get_option( 'users_can_register' ) or ! $register['enable_def_reg'] ) {
                wpap_show_message( __( 'Registration is disabled.', 'arvand-panel' ), 'info', false );
            } elseif ( ! is_user_logged_in() ) {
                if ( ! WPAPField::field_exist( 'user_login' ) or ! WPAPField::field_exist( 'user_email' ) or ! WPAPField::field_exist( 'user_pass' ) ) {
                    wpap_show_message( __( 'The registration form is not ready.', 'arvand-panel' ), 'error', false );
                } else {
                    require WPAP_USER_PATH . 'auth/register.php';
                }
            } else {
	            wpap_show_message( __( 'You are logged in to your account.', 'arvand-panel' ), 'info', false );
            }
            ?>
        </div>

        <?php return ob_get_clean();
    }

    static function login_form()
    {
        if ( ! is_admin_bar_showing() ) {
            wp_enqueue_style('dashicons');
        }

        $login = wpap_login_options();

        if ( $login['enable_g_login'] ) {
            wp_enqueue_script( 'wpap_google_login' );
        }

        ob_start();

        require WPAP_USER_PATH . 'styles/styles.php';
        ?>

        <div id="wpap-login">
            <?php
            if ( ! is_user_logged_in() ) {
                require WPAP_USER_PATH . 'auth/login.php';
            } else {
                wpap_show_message( __( 'You are logged in to your account.', 'arvand-panel' ), 'info', false );
            }
            ?>
        </div>

        <?php return ob_get_clean();
    }

    static function sms_register_login( $attributes )
    {
	    $attributes = shortcode_atts( [ 'redirect_url' => '', 'redirect_page_id' => -1 ], $attributes );
	    $redirect_page_id = is_numeric( $attributes['redirect_page_id'] ) ? ( int ) $attributes['redirect_page_id'] : -1;
	    $register = wpap_register_options();
        $login = wpap_login_options();
	    $pages_opt = wpap_pages_options();

	    if ( ! is_admin_bar_showing() ) {
		    wp_enqueue_style('dashicons');
	    }

        ob_start();

	    require WPAP_USER_PATH . 'styles/styles.php'; ?>

        <?php if ( ! is_user_logged_in() ): ?>
            <div id="wpap-sms-register-login">
                <?php if ( ! $login['enable_sms_register_login'] ):
                    wpap_show_message( __( 'Login and register with sms disabled.', 'arvand-panel' ), 'info', false );
                else:
                    require WPAP_USER_PATH . 'auth/sms-send.php';
                    require WPAP_USER_PATH . 'auth/sms-register.php';
                    require WPAP_USER_PATH . 'auth/sms-login.php';
                endif; ?>
            </div>
        <?php else:
            wpap_show_message( __( 'You are logged in to your account.', 'arvand-panel' ), 'info', false );
        endif;

        return ob_get_clean();
    }

    static function lost_password_form()
    {
        ob_start();

        require WPAP_USER_PATH . 'styles/styles.php'; ?>

        <?php if ( ! is_user_logged_in() ): ?>
            <div id="wpap-lost-password">
                <?php $login = wpap_login_options(); ?>

                <?php if ( $login['reset_pass_method'] === 'email' or $login['reset_pass_method'] === 'both' ): ?>
                    <form id="wpap-lost-password-form" action="<?php echo wp_lostpassword_url(); ?>" method="post">
                        <?php wp_nonce_field( 'lost_pass_nonce', 'lost_pass_nonce' ); ?>

                        <p>
                            <input type="text" name="user_login" placeholder="<?php _e( 'Email', 'arvand-panel' );?>">
                        </p>

                        <button class="wpap-btn-1" type="submit">
                            <span class="wpap-btn-text"><?php esc_attr_e( 'Recovery Password', 'arvand-panel' ); ?></span>
                            <div class="wpap-loading"></div>
                        </button>
                    </form>
                <?php endif; ?>

                <?php if ( $login['reset_pass_method'] === 'mobile' or $login['reset_pass_method'] === 'both' ): ?>
                    <?php $by_mobile = $login['reset_pass_method'] === 'mobile'; ?>

                    <form id="wpap-sms-lost-pass-form" method="post" <?php echo $by_mobile ? 'style="display: block"' : ''; ?>>
                        <?php wp_nonce_field( 'sms_reset_pass_nonce', 'sms_reset_pass_nonce' ); ?>

                        <p>
                            <input type="text" name="phone" placeholder="<?php _e( 'Mobile Number', 'arvand-panel' ); ?>">
                        </p>

                        <button class="wpap-btn-1" type="submit" name="sms_reset_pass">
                            <span class="wpap-btn-text"><?php esc_attr_e( 'Send Code', 'arvand-panel' ); ?></span>
                            <div class="wpap-loading"></div>
                        </button>
                    </form>

                    <form id="wpap-sms-reset-pass-verify-form" method="post">
                        <?php wp_nonce_field( 'sms_reset_pass_verify_nonce', 'sms_reset_pass_verify_nonce' ); ?>

                        <p>
                            <input type="text" name="verification_code" placeholder="<?php _e( 'Verification Code', 'arvand-panel' ); ?>">
                        </p>

                        <p>
                            <input type="password" name="new_password" placeholder="<?php _e( 'New Password', 'arvand-panel' ); ?>">

                            <span class="wpap-input-info">
                                <?php
                                $pass_set = WPAPFiledSettings::user_pass_settings( WPAPField::user_pass_setting() );
                                echo sprintf( __( 'At least %d letters. For more security, use a combination of letters and numbers.', 'arvand-panel' ), esc_html( $pass_set['min'] ) );
                                ?>
                            </span>
                        </p>

                        <button class="wpap-btn-1" type="submit" name="sms_reset_pass_verify">
                            <span class="wpap-btn-text"><?php esc_attr_e( 'Reset Password', 'arvand-panel' ); ?></span>
                            <div class="wpap-loading"></div>
                        </button>
                    </form>

                    <div id="wpap-form-buttons" <?php echo $by_mobile ? 'style="display: none"' : ''; ?>>
                        <div id="wpap-sms-pass-lost-btn">
                            <i class="bx bx-mobile-vibration"></i>
                            <span><?php _e( 'Reset password by mobile', 'arvand-panel' ); ?></span>
                        </div>
                    </div>
                <?php endif; ?>

                <?php
                $page = 'lost-pass';
                require WPAP_USER_PATH . 'parts/form-links.php';
                ?>
            </div>
        <?php else:
            wpap_show_message( __( 'You are logged in to your account.', 'arvand-panel' ), 'info', false );
        endif;

        return ob_get_clean();
    }

    static function reset_password_form()
    {
        ob_start();

        require WPAP_USER_PATH . 'styles/styles.php'; ?>

        <?php if ( ! is_user_logged_in() ): ?>
            <?php if ( ! empty( $_REQUEST['login'] ) and ! empty( $_REQUEST['key'] ) ): ?>
                <div id="wpap-reset-password">
                    <form id="wpap-reset-password-form" action="<?php echo site_url( 'wp-login.php?action=resetpass' ); ?>" method="post">
                        <?php
                        wpap_show_message( __( 'Enter your new password.', 'arvand-panel' ), 'success' );
                        wp_nonce_field( 'reset_pass_nonce', 'reset_pass_nonce' );
                        ?>

                        <input type="hidden" name="rp_login" value="<?php esc_attr_e( $_REQUEST['login'] ); ?>" autocomplete="off" />
                        <input type="hidden" name="rp_key" value="<?php esc_attr_e( $_REQUEST['key'] ); ?>"/>

                        <p>
                            <input type="password" name="pass1" placeholder="<?php esc_attr_e( 'New Password', 'arvand-panel' ); ?>" autocomplete="off"/>

                            <span class="wpap-input-info">
                                <?php
                                $pass_settings = WPAPFiledSettings::user_pass_settings( WPAPField::user_pass_setting() );
                                echo sprintf( __( 'At least %d letters. For more security, use a combination of letters and numbers.', 'arvand-panel' ), esc_html( $pass_settings['min'] ) );
                                ?>
                            </span>
                        </p>

                        <p>
                            <input type="password" name="pass2" placeholder="<?php esc_attr_e( 'Confirm Password', 'arvand-panel' ); ?>" autocomplete="off"/>
                        </p>

                        <button class="wpap-btn-1" type="submit">
                            <span class="wpap-btn-text"><?php esc_attr_e( 'Reset Password', 'arvand-panel' ); ?></span>
                            <div class="wpap-loading"></div>
                        </button>

	                    <?php
	                    $pages_opt = wpap_pages_options();
	                    $login_page_url = get_permalink( $pages_opt['login_page_id'] );
	                    $register_page_url = get_permalink( $pages_opt['register_page_id'] );
	                    ?>

                        <div id="wpap-form-links">
                            <a href="<?php echo $login_page_url; ?>">
			                    <?php _e( 'Login', 'arvand-panel' ); ?>
                            </a>

                            <a href="<?php echo $register_page_url; ?>">
			                    <?php _e( 'Register', 'arvand-panel' ); ?>
                            </a>
                        </div>
                    </form>
                </div>
            <?php else:
                wpap_show_message( __( 'Invalid Request.', 'arvand-panel' ), 'error' );
            endif;
        else:
            wpap_show_message( __( 'You are logged in to your account.', 'arvand-panel' ), 'info', false );
        endif;

        return ob_get_clean();
    }

    static function user_panel()
    {
	    wp_enqueue_script( 'wpap_panel_form_handler');
        ob_start();

        if ( is_user_logged_in() ):
            require WPAP_USER_PATH . 'user-panel.php';
        else: ?>
            <div id="wpap-non-logged-in">
                <?php echo do_shortcode( '[wpap_login_form]' ); ?>
            </div>
        <?php endif;

        return ob_get_clean();
    }

    static function woo_orders()
    {
        ob_start();

        if ( class_exists( 'woocommerce' ) ) {
            $user_id = get_current_user_id();

            if ( $user_id == 0 ) {
                echo do_shortcode( '[woocommerce_my_account]' );
            } elseif ( isset( $_GET['order_details'] ) and isset( $_GET['order'] ) ) {
                $order_id = intval( $_GET['order'] );
                $order = wc_get_order( $order_id );

                if ( ! $order or ! current_user_can( 'view_order', $order_id ) ) {
                    wpap_show_message( __( 'Invalid order.', 'woocommerce' ), 'error', false );
                } else {
                    $my_account = new WC_Shortcode_My_Account();
                    $my_account->view_order( $order_id );
                }
            } else {
                wc_get_template('myaccount/my-orders.php', [
                    'current_user' => get_user_by( 'id',  $user_id ),
                    'order_count' => '-1'
                ]);
            }
        } else {
            wpap_show_message( __( 'Woocommerce plugin is not active.', 'arvand-panel' ), 'info', false );
        }

        return ob_get_clean();
    }

    static function woo_downloads()
    {
        ob_start();

        if ( class_exists( 'woocommerce' ) ) {
            wc_get_template( 'myaccount/downloads.php' );
        } else {
            wpap_show_message( __( 'Woocommerce plugin is not active.', 'arvand-panel' ), 'info', false );
        }

        return ob_get_clean();
    }

    static function woo_address()
    {
        if ( ! class_exists( 'woocommerce' ) ) {
            wpap_show_message( __( 'Woocommerce plugin is not active.', 'arvand-panel' ), 'info', false );
            return false;
        }

        ob_start();

        $address_type = '';

        if ( ! empty( $_GET['edit-address'] ) ) {
            $slugs = apply_filters(
                'woocommerce_edit_address_slugs',
                array(
                    'billing' => sanitize_title( _x( 'billing', 'edit-address-slug', 'woocommerce' ) ),
                    'shipping' => sanitize_title( _x( 'shipping', 'edit-address-slug', 'woocommerce' ) )
                )
            );

            foreach ( $slugs as $key => $value ) {
                if ( ! empty( $key ) and urldecode( $key ) === $_GET['edit-address'] ) {
                    $address_type = $key;
                }
            }
        }

        if ( function_exists( 'wc_print_notices' ) ) {
            wc_print_notices();
        }

        if ( class_exists( 'WC_Shortcode_My_Account' ) ) {
            WC_Shortcode_My_Account::edit_address( $address_type );
        }

        return ob_get_clean();
    }

    static function profile_menu()
    {
        ob_start();
        include WPAP_USER_PATH . 'account-menu.php';
        return ob_get_clean();
    }
}

WPAPShortCode::init();