<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class WPAPTicket {
    public static function init()
    {
        add_action( 'wp_ajax_wpap_delete_ticket', [ __CLASS__, 'deleteTicket' ] );
        add_action( 'wp_ajax_wpap_delete_supporter', [ __CLASS__, 'deleteSupporter' ] );
        add_action( 'wp_ajax_wpap_change_status', [ __CLASS__, 'changeStatus' ] );
        add_action( 'wp_ajax_wpap_change_dep', [ __CLASS__, 'changeDepartment' ] );
    }

    function upload_attachment( $file, $post_id )
    {
        if ( ! function_exists( 'wp_handle_upload' ) ) {
            require_once( ABSPATH . 'wp-admin/includes/file.php' );
        }

        $upload = wp_handle_upload( $file, [ 'test_form' => false ] );

        if ( $upload and ! isset( $upload['error'] ) ) {
            add_post_meta( $post_id, 'wpap_ticket_attachment', $upload['url'] );
        }
    }

    static function count( $status = '', $department = [], $user_tickets = false )
    {
        $args = [
            'post_type' => 'wpap_ticket',
            'publish' => true,
            'post_parent' => 0,
            'numberposts' => -1,
        ];

        $meta_query = [];

        if ( ! empty( $status ) ) {
            $meta_query[] = [ 'key' => 'wpap_ticket_status', 'value' => $status ];
        }

        $user_query = [];
        $user_query['relation'] = 'OR';
        $user_query[] = [ 'key' => 'wpap_ticket_recipient', 'value' => get_current_user_id() ];
        $user_query[] = [ 'key' => 'wpap_ticket_creator', 'value' => get_current_user_id() ];

        if ( is_array( $department ) and count( $department ) ) {
            $user_query[] = [ 'key' => 'wpap_ticket_department', 'value' => $department, 'compare' => 'IN' ];
        }

		$meta_query[] = $user_query;

        if ( count( $meta_query ) ) {
            $args['meta_query'] = [ $meta_query ];
        }

        return count( get_posts( $args ) );
    }

    function delete( $post_id )
    {
        $posts = get_posts([
            'post_type' => 'wpap_ticket',
            'post_parent' => $post_id,
            'numberposts' => -1,
        ]);

        if ( is_array( $posts ) and count( $posts ) ) {
            foreach ( $posts as $post ) {
                $previous_url = get_post_meta( $post->ID, 'wpap_ticket_attachment', true );

                if ( $previous_url ) {
                    $file_path = wp_get_upload_dir()['basedir'] . wp_get_upload_dir()['subdir'] . '/' . basename( $previous_url );
                    wp_delete_file( $file_path );
                }

                wp_delete_post( $post->ID, true );
            }
        }

        $previous_url = get_post_meta( $post_id, 'wpap_ticket_attachment', true );

        if ( $previous_url ) {
            $file_path = wp_get_upload_dir()['basedir'] . wp_get_upload_dir()['subdir'] . '/' . basename( $previous_url );
            wp_delete_file( $file_path );
        }

        wp_delete_post( $post_id, true );
    }

    static function deleteTicket()
    {
        if ( is_numeric( $_POST['ticket'] ) and intval( $_POST['ticket'] ) ) {
            $ticket = new WPAPTicket();
            $ticket->delete( $_POST['ticket'] );
            wp_send_json( 'success' );
        }

        wp_send_json( 'error' );
    }

    static function userDepartment( $user_id )
	{
		$user = get_user_by( 'email', get_bloginfo( 'admin_email' ) );

		if ( $user and $user->ID == $user_id ) {
			$dep_opt = wpap_ticket_department_options();
			return count( $dep_opt['departments'] ) ? $dep_opt['departments'] : false;
		}

		return unserialize( get_user_meta( $user_id, 'wpap_user_ticket_department', true ) );
	}

    static function deleteSupporter()
    {
        if ( ! isset( $_POST['nonce'] ) or ! wp_verify_nonce( $_POST['nonce'], 'del_supporter_nonce' ) ) {
            wp_send_json( 'error' );
        }

        if ( is_numeric( $_POST['user'] ) ) {
            delete_user_meta( intval( $_POST['user'] ), 'wpap_user_ticket_department' );
            wp_send_json( 'success' );
        }

        wp_send_json( 'error' );
    }

    static function changeStatus()
    {
        if ( ! isset( $_POST['post'] ) or ! is_numeric( $_POST['post'] ) ) {
            return;
        }

        $post_id = intval( $_POST['post'] );
        $post = get_post( $post_id );

        if ( ! $post ) {
            return;
        }

        if ( $_POST['status'] === 'open' ) {
            update_post_meta( $post->ID, 'wpap_ticket_status', 'open' );
            wp_send_json( [ 'text' => __( 'Open', 'arvand-panel' ), 'bg_color' => '#ff006c', 'color' => '#ffffff' ] );
        }

        if ( $_POST['status'] === 'closed' ) {
            update_post_meta( $post->ID, 'wpap_ticket_status', 'closed' );
            wp_send_json( [ 'text' => __( 'Closed', 'arvand-panel' ), 'bg_color' => '#4eceaa', 'color' => '#ffffff' ] );
        }

        if ( $_POST['status'] === 'solved' ) {
            update_post_meta( $post->ID, 'wpap_ticket_status', 'solved' );
            wp_send_json( [ 'text' => __( 'Solved', 'arvand-panel' ), 'bg_color' => '#4eceaa', 'color' => '#ffffff' ] );
        }

        $opt = wpap_ticket_options();

        if ( in_array( $_POST['status'], $opt['ticket_status']['name'] ) ) {
            $key = array_search( $_POST['status'], $opt['ticket_status']['name'] );

            update_post_meta( $post->ID, 'wpap_ticket_status', $opt['ticket_status']['name'][ $key ] );
            update_post_meta( $post->ID, 'wpap_ticket_status_color', $opt['ticket_status']['color'][ $key ] );
            update_post_meta( $post->ID, 'wpap_ticket_status_text_color', $opt['ticket_status']['text_color'][ $key ] );

            wp_send_json([
                'text' => $opt['ticket_status']['name'][ $key ],
                'bg_color' => $opt['ticket_status']['color'][ $key ],
                'color' => $opt['ticket_status']['text_color'][ $key ]
            ]);
        }
    }

    static function changeDepartment()
    {
        if ( ! isset( $_POST['post'] ) or ! is_numeric( $_POST['post'] ) ) {
            return;
        }

        $post_id = intval( $_POST['post'] );
        $post = get_post( $post_id );

        if ( ! $post ) {
            return;
        }

        $opt = wpap_ticket_department_options();

        if ( in_array( $_POST['dep'], $opt['departments'] ) ) {
            $key = array_search( $_POST['dep'], $opt['departments'] );
            update_post_meta( $post->ID, 'wpap_ticket_department', $opt['departments'][ $key ] );
            wp_send_json( [ 'text' => sprintf( __( '%s department', 'arvand-panel' ), $opt['departments'][ $key ] ) ] );
        }
    }
}

WPAPTicket::init();