<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class WPAPUser {
    static function init() {
        add_action( 'show_user_profile', [ __class__, 'userStatusField' ] );
        add_action( 'edit_user_profile', [ __class__, 'userStatusField' ] );
        add_action( 'personal_options_update', [ __class__, 'saveUserStatusField' ] );
        add_action( 'edit_user_profile_update', [ __class__, 'saveUserStatusField' ] );
        add_action( 'show_user_profile', [ __class__, 'customRegisterFields' ] );
        add_action( 'edit_user_profile', [ __class__, 'customRegisterFields' ] );
        add_action( 'personal_options_update', [ __class__, 'saveCustomRegisterFields' ] );
        add_action( 'edit_user_profile_update', [ __class__, 'saveCustomRegisterFields' ] );
        add_action( 'wp_ajax_wpap_delete_role', [ __class__, 'wpap_delete_role' ] );
	    add_action( 'delete_user', [ __CLASS__, 'deleteAvatarDataByDeleteUser' ] );
	    add_action( 'wp_ajax_wpap_delete_avatar', [ __CLASS__, 'deleteProPic' ] );
	    add_filter( 'get_avatar', [ __class__, 'displayProfilePic' ], 10, 6 );
    }

    static function userStatusField( $user ) {
        if ( $user->ID !== get_current_user_id() ): ?>
            <table class="form-table">
                <?php wp_nonce_field( 'wpap_user_status_field_nonce', 'wpap_user_status_field_nonce' ); ?>

                <tr>
                    <th><label for="wpap-user-status"><?php _e( 'Activate user panel', 'arvand-panel' ); ?></label></th>

                    <td>
                        <?php $status = get_user_meta( $user->ID, 'wpap_user_status', true ); ?>
                        <input id="wpap-user-status" type="checkbox" name="wpap_user_status" <?php checked( $status ); ?>/>
                        <?php $register = wpap_register_options(); ?>

                        <?php if ( $register['enable_admin_approval'] ): ?>
                            <p class="description">
                                <?php _e( "If you enable this option, an account confirmation notification email will be sent to the user's email.", 'arvand-panel' ); ?>
                            </p>
                        <?php endif; ?>
                    </td>
                </tr>
            </table>
        <?php endif;
    }

    static function saveUserStatusField( $user_id ) {
        if ( empty( $_POST['wpap_user_status_field_nonce'] ) or ! wp_verify_nonce( $_POST['wpap_user_status_field_nonce'], 'wpap_user_status_field_nonce' ) ) {
            return false;
        }

        if ( empty( $_POST['wpap_user_status'] ) ) {
	        return false;
        }

        if ( ! current_user_can( 'edit_user', $user_id ) ) {
            return false;
        }

	    update_user_meta( $user_id, 'wpap_user_status', 1 );
        $register = wpap_register_options();

        if ( $register['enable_admin_approval'] ) {
            $user = get_user_by( 'ID', $user_id );
	        $headers = [ 'Content-Type: text/html; charset=UTF-8' ];
	        $search = [ '[first_name]', '[last_name]', '[user_login]', '[user_email]', '[site_name]', '[site_url]' ];
	        $replace = [ $user->first_name, $user->last_name, $user->user_login, $user->user_email, get_bloginfo( 'name' ), '<a href="' . esc_url( site_url() ) . '">' . site_url() . '</a>', ];
	        $email_opt = wpap_email_options();
            $email_subject = sanitize_text_field( $email_opt['admin_approval_email_subject'] );
	        $change = str_replace( $search, $replace, $email_opt['admin_approval_email'] );
            wp_mail( $user->user_email, $email_subject, wpap_email_template( $change ), $headers );
        }
    }

    static function customRegisterFields( $user ) { ?>
        <table class="form-table">
            <?php
            wp_nonce_field( 'wpap_reg_custom_fields_nonce', 'wpap_reg_custom_fields_nonce' );
            $fields = WPAPField::supported_fields( 'multi' );
            array_push( $fields, 'mobile' );

            $posts = get_posts([
                'post_type' => 'wpap_reg_field',
                'order' => 'ASC',
                'orderby' => 'menu_order',
                'numberposts' => -1,
            ]);

            foreach ( $posts as $post ) {
                if ( $post->post_title !== 'user_pass' and in_array( $post->post_title, $fields ) ) {
                    $method_name = $post->post_title;
                    WPAPFieldHtml::$method_name( $post->post_content, $user->ID );
                }
            }

            $register = wpap_register_options();
            ?>

            <?php if ( $register['enable_agree'] ): ?>
                <?php $agree = get_user_meta( $user->ID, 'wpap_agree_to_terms', true ); ?>

                <tr>
                    <th><label for="wpap-agree"><?php _e( 'Agree to terms', 'arvand-panel' ) ?></label></th>

                    <td>
                        <input id="wpap-agree" type="checkbox" name="wpap_agree" <?php checked( $agree ); ?>/>
                        <?php echo wp_kses( $register['agree_text'], 'post' ); ?>
                    </td>
                </tr>
            <?php endif; ?>
        </table>
    <?php }

    static function saveCustomRegisterFields( $user_id ) {
        if ( empty( $_POST['wpap_reg_custom_fields_nonce'] ) || ! wp_verify_nonce( $_POST['wpap_reg_custom_fields_nonce'], 'wpap_reg_custom_fields_nonce' ) ) {
            return false;
        }

        if ( ! current_user_can( 'edit_user', $user_id ) ) {
            return false;
        }

        $posts = get_posts([
            'post_type' => 'wpap_reg_field',
            'order' => 'ASC',
            'orderby' => 'menu_order',
            'numberposts' => -1,
        ]);

        $multi = WPAPField::supported_fields( 'multi' );

        foreach ( $posts as $post ) {
            if ( in_array( $post->post_title, $multi ) ) {
                $field = unserialize( $post->post_content );

                if ( ! isset( $_POST[ $field['name'] ] ) ) {
                    delete_user_meta( $user_id, $field['meta_key'] );
                }

                if ( isset( $_POST[ $field['name'] ] ) ) {
                    if ( is_array( $_POST[ $field['name'] ] ) ) {
                        update_user_meta( $user_id, sanitize_text_field( $field['meta_key'] ), maybe_serialize( wpap_sanitize_array_fields( $_POST[ $field['name'] ] ) ) );
                    } else {
                        update_user_meta( $user_id, sanitize_text_field( $field['meta_key'] ), sanitize_text_field( $_POST[ $field['name'] ] ) );
                    }
                }
            }
        }

        $register = wpap_register_options();

        if ( $register['enable_agree'] ) {
            update_user_meta( $user_id, 'wpap_agree_to_terms', isset( $_POST['wpap_agree'] ) );
        }
    }

    static function wpap_access_prepare( $access ) {
        $roles = get_editable_roles();
        $allowed = [];
        $role_arr = [];

        foreach ( $roles as $role => $details ) $allowed[] = $role;

        if ( is_array( $access ) ) {
            for ( $i = 0; $i < count( $access ); $i++ ) {
                if ( in_array( $access[$i], $allowed ) ) {
                    $role_arr[] = sanitize_text_field( $access[$i] );
                }
            }
        }

        return $role_arr;
    }

    private static function phoneFields( $phone = null, $only_keys = false )
    {
        $meta_array = apply_filters(
            'wpap_user_meta_phone',
            [
                [ 'key' => 'wpap_user_phone_number', 'phone' => $phone ],
                [ 'key' => 'eh_user_phone', 'phone' => $phone ],
                [ 'key' => 'billing_phone', 'phone' => $phone ],
                [ 'key' => 'billing_phone', 'phone' => substr_replace( $phone, '98', 0, 1 ) ],
                [ 'key' => 'billing_phone', 'phone' => substr_replace( $phone, '+98', 0, 1 ) ],
                [ 'key' => 'billing_phone', 'phone' => substr_replace( $phone, '', 0, 1 ) ],
                [ 'key' => 'digits_phone', 'phone' => $phone ],
                [ 'key' => 'digits_phone', 'phone' => substr_replace( $phone, '98', 0, 1 ) ],
                [ 'key' => 'digits_phone', 'phone' => substr_replace( $phone, '+98', 0, 1 ) ],
                [ 'key' => 'digits_phone_no', 'phone' => substr_replace( $phone, '', 0, 1 ) ]
            ],
	        $phone
        );

        if ( $only_keys ) {
            $keys = [];

            foreach ( $meta_array as $meta ) {
	            $keys[] = $meta['key'];
            }

            return array_unique( $keys );
        }

        return $meta_array;
    }

    static function checkPhoneFields( $phone ) {
		$phone = apply_filters( 'wpap_sent_phone_number', $phone );
		$meta_array = self::phoneFields( $phone );

		foreach ( $meta_array as $meta ) {
			$user = self::getUserByPhone( $meta['phone'], $meta['key'] );

			if ( $user ) {
				return $user;
			}
		}

		return false;
	}

    static function userHasPhone( $user_id ) {
        $keys = self::phoneFields( null, true );

        foreach ( $keys as $key ) {
            $phone = self::getPhoneByUserId( $user_id, $key );

            if ( $phone ) {
                return $phone;
            }
        }

        return false;
    }

	static function getUserByPhone( $phone, $key ) {
		global $wpdb;
        $query = "SELECT user_id FROM $wpdb->usermeta WHERE meta_value = %s AND meta_key = %s LIMIT 1";
        $res = $wpdb->get_row( $wpdb->prepare( $query, $phone, $key ) );

		if ( ! $res ) {
			return false;
		}

		$user = get_user_by( 'id', $res->user_id );

		if ( ! $user ) {
			return false;
		}

		return $user;
	}

	static function getPhoneByUserId( $user_id, $key ) {
		global $wpdb;
		$query = "SELECT meta_value FROM $wpdb->usermeta WHERE user_id = %d AND meta_key = %s LIMIT 1";
		$res = $wpdb->get_row( $wpdb->prepare( $query, $user_id, $key ) );
		return $res ? $res->meta_value : false;
	}

    static function upload_pro_pic( $img_file ) {
        $allowed_ext = [ 'image/jpeg', 'image/jpg', 'image/png' ];
        $panel = wpap_panel_options();

        if ( ! in_array( $img_file['type'], $allowed_ext ) ) {
            return [ 'error' => __( 'Image format is not allowed.', 'arvand-panel' ) ];
        }

        if ( $img_file['size'] > ( 1204 * $panel['avatar_size'] ) ) {
            return [ 'error' => sprintf( __( 'Maximum avatar image size is %d KB.', 'arvand-panel' ), $panel['avatar_size'] ) ];
        }

        if ( ! function_exists( 'wp_handle_upload' ) ) {
            require_once( ABSPATH . 'wp-admin/includes/file.php' );
        }

        $upload = wp_handle_upload( $img_file, [ 'test_form' => false ] );

        if ( ! $upload or isset( $upload['error'] ) ) {
            return [ 'error' => __( 'There is a problem uploading avatar.', 'arvand-panel' ) ];
        }

        $user_id = get_current_user_id();
        $get_previous_path = get_user_meta( $user_id, 'wpap_profile_img_path', true );
        wp_delete_file( $get_previous_path );
        $img_path = wp_normalize_path( trailingslashit( wp_upload_dir()['path'] ) ) . basename( $upload['url'] );
        update_user_meta( $user_id, 'wpap_profile_img', $upload['url'] );
        update_user_meta( $user_id, 'wpap_profile_img_path', $img_path );
        return true;
    }

    static function deleteProPic()
    {
	    if ( wp_get_current_user()->user_login === WPAP_DEMO ) {
		    wp_send_json( [ 'status' => 'error', 'msg' => __( 'کاربر دمو قادر به حذف تصویر نیست.', 'arvand-panel' ) ] );
	    }

        if ( ! is_numeric( $_POST['user_id'] ) or ! get_user_by( 'id', absint( $_POST['user_id'] ) ) ) {
	        wp_send_json( [ 'status' => 'error', 'msg' => __( 'Invalid Request.', 'arvand-panel' ) ] );
        }

        $user_id = absint( $_POST['user_id'] );
        $img_path = get_user_meta( $user_id, 'wpap_profile_img_path', true );
        wp_delete_file( $img_path );

        if ( delete_user_meta( $user_id, 'wpap_profile_img' ) ) {
	        $url = get_avatar_url( $user_id );
	        wp_send_json( [ 'status' => 'success', 'msg' => __( 'Profile image deleted.', 'arvand-panel' ), 'url' => $url ] );
        }

	    wp_send_json( [ 'status' => 'error', 'msg' => __( 'An error occurred in deleting profile image.', 'arvand-panel' ) ] );
    }

    static function displayProfilePic( $avatar, $id_or_email, $size, $default, $alt, $args ) {
        $profile_img_url = '';

        if ( is_object( $id_or_email ) ) {
            $user = get_user_by( 'email', $id_or_email->comment_author_email );

            if ( $user ) {
                $profile_img_url = get_user_meta( $user->ID, 'wpap_profile_img', true );
            }
        } else {
            $profile_img_url = get_user_meta( $id_or_email, 'wpap_profile_img', true );
        }

        if ( $profile_img_url ) {
            $class = array( 'avatar', 'avatar-' . (int) $args['size'], 'photo' );

            if ( ! $args['found_avatar'] or $args['force_default'] ) {
                $class[] = 'avatar-default';
            }

            if ( $args['class'] ) {
                if ( is_array( $args['class'] ) ) {
                    $class = array_merge( $class, $args['class'] );
                } else {
                    $class[] = $args['class'];
                }
            }

            $class = esc_attr( implode( ' ', $class ) );

            $profile_img = "<img alt='$alt' src='$profile_img_url' class='$class' style='object-fit: cover' height='$size' width='$size'/>";
        } else {
            $profile_img = $avatar;
        }

        return $profile_img;
    }

    static function wpap_delete_role() {
        if ( ! empty( $_POST['role'] ) and ! empty( $_POST['nonce'] ) and wp_verify_nonce( $_POST['nonce'], 'del_role' ) ) {
            if ( substr( $_POST['role'], 0, 12 ) === 'arvand_panel' ) {
                $role = sanitize_text_field( $_POST['role'] );
                $new_role = sanitize_text_field( $_POST['new_role'] );

                $users = get_users( [ 'role' => $role ] );

                foreach ( $users as $user ) {
                    $roles = new WP_User( $user->ID );
                    $roles->set_role( $new_role );
                }

                remove_role( $role );
                echo 'success';
            }
        }

        wp_die();
    }

    static function deleteAvatarDataByDeleteUser( $user_id )
    {
        $path = get_user_meta( $user_id, 'wpap_profile_img_path', true );
        wp_delete_file( $path );
    }
}

WPAPUser::init();