<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class WPAPWoocommerce
{
    static function init()
    {
        add_filter( 'woocommerce_locate_template', [ __CLASS__, 'LocateTemplate' ], PHP_INT_MAX, 3 );
        add_filter( 'woocommerce_get_view_order_url', [ __CLASS__, 'ChangeViewOrderUrl' ], PHP_INT_MAX, 2 );
        add_filter( 'woocommerce_account_downloads_columns', [ __CLASS__, 'downloadsColumns' ], PHP_INT_MAX );
        add_action( 'parse_request', [ __CLASS__, 'parseAddressRequest' ], PHP_INT_MAX );
        add_action( 'woocommerce_after_save_address_validation', [ __CLASS__, 'afterSaveAddressValidation' ], PHP_INT_MAX, 4 );
        add_action( 'woocommerce_customer_save_address', [ __CLASS__, 'customerSaveAddress' ], PHP_INT_MAX, 2 );
    }

    static function LocateTemplate( $template, $template_name, $template_path )
    {
        global $woocommerce;
        $_template = $template;

        if ( ! $template_path ) {
            $template_path = $woocommerce->template_url;
        }

        $plugin_path  = WPAP_USER_PATH . 'woocommerce/';

        // Look within passed path within the theme - this is priority
        $template = locate_template( [ $template_path . $template_name, $template_name ] );

        // Modification: Get the template from this plugin, if it exists
        if ( ! $template && file_exists( $plugin_path . $template_name ) ) {
            $template = $plugin_path . $template_name;
        }

        // Use default template
        if ( ! $template ) {
            $template = $_template;
        }

        // Return what we found
        return $template;
    }

    static function ChangeViewOrderUrl( $url, $order )
    {
        $pages_opt = wpap_pages_options();
        $slug = 'wpap-panel';
	    $panel_page = get_post( $pages_opt['panel_page_id'] );

		if ( $panel_page ) {
			$slug = $panel_page->post_name;
        }

        if ( is_page( $slug ) ) {
            return add_query_arg( [ 'order_details' => '1', 'order' => $order->get_id() ] );
        }

        return $url;
    }

	static function downloadsColumns( $columns )
	{
		unset( $columns['download-product'] );
		return $columns;
	}

    static function parseAddressRequest()
    {
        global $wp;

        if ( empty( $_POST['action'] ) or $_POST['action'] !== 'edit_address' ) {
            unset( $wp->query_vars['edit-address'] );
        }
    }

    static function afterSaveAddressValidation( $user_id, $load_address, $address, $customer )
    {
        if ( function_exists( 'wc_notice_count' ) and 0 < wc_notice_count( 'error' ) ) {
            $section = ! empty( $_GET['section'] ) ? sanitize_text_field( $_GET['section'] ) : '';
            wp_safe_redirect( add_query_arg( [ 'section' => $section, 'edit-address' => $load_address ] ) );
            exit;
        }
    }

    static function customerSaveAddress( $user_id, $load_address )
    {
        $section = ! empty( $_GET['section'] ) ? sanitize_text_field( $_GET['section'] ) : '';
        wp_safe_redirect( add_query_arg( [ 'section' => $section, 'edit-address' => $load_address ] ) );
        exit;
    }
}

WPAPWoocommerce::init();