<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class WPAPAdminMenu {
	function init() {
        add_action( 'admin_menu', [ $this, 'adminMenus' ] );
    }

	function adminMenus() {
        add_menu_page(
            __( 'Arvand Panel', 'arvand-panel' ),
            __( 'Arvand Panel', 'arvand-panel' ),
            'manage_options',
            'arvand-panel',
            [ $this, 'settingsMenuPage' ],
            WPAP_ADMIN_URL . 'assets/images/icon.png'
        );

        add_submenu_page(
            'arvand-panel',
            __( 'Settings', 'arvand-panel' ),
            __( 'Settings', 'arvand-panel' ),
            'manage_options',
            'arvand-panel',
            [ $this, 'settingsMenuPage' ]
        );

        add_submenu_page(
            'arvand-panel',
            __( 'Notifications', 'arvand-panel' ),
            __( 'Notifications', 'arvand-panel' ),
            'manage_options',
            'edit.php?post_type=wpap_notifications',
            false
        );

        add_submenu_page(
        'arvand-panel',
            __( 'Tickets', 'arvand-panel' ),
            __( 'Tickets', 'arvand-panel' ),
            'manage_options',
            'wpap-tickets',
            [ $this, 'ticketsMenuPage' ]
        );

        add_submenu_page(
            'arvand-panel',
            __( 'Register Fields', 'arvand-panel' ),
            __( 'Register Fields', 'arvand-panel' ),
            'manage_options',
            'wpap-register-fields',
            [ $this, 'registerFormBuilderMenuPage' ]
        );

        add_submenu_page(
            'arvand-panel',
            __( 'Panel Menus', 'arvand-panel' ),
            __( 'Panel Menus', 'arvand-panel' ),
            'manage_options',
            'wpap-panel-menus',
            [ $this, 'panelMenus' ]
        );

        $count = WPAPPrivateMessage::msg_admin_unread_count( get_current_user_id() );

        add_submenu_page(
            'arvand-panel',
            __( 'Private Message', 'arvand-panel' ),
            $count ? __( 'Private Message', 'arvand-panel' ) . '<span class="awaiting-mod" style="margin: 0 5px">' . esc_html( $count ) . '</span>' : __( 'Private Message', 'arvand-panel' ),
            'manage_options',
            'wpap-private-message',
            [ $this, 'privateMessage' ]
        );

        add_submenu_page(
            'arvand-panel',
            __( 'Plugin Info', 'arvand-panel' ),
            __( 'Plugin Info', 'arvand-panel' ),
            'manage_options',
            'wpap-info',
            [ $this, 'info' ]
        );
    }

	function ticketsMenuPage() {
        $remove_args = [ 'section', 'new-ticket', 'ticket-status', 'open-ticket', 'del-ticket', 'ticket' ];
        $page = 'ticket-list';

        if ( isset( $_GET['single-ticket'] ) and ! empty( $_GET['single-ticket'] ) ) {
            $page = 'single-ticket';
        } elseif ( isset( $_GET['section'] ) and $_GET['section'] === 'users' ) {
            $page = 'users';
        } elseif ( isset( $_GET['new-ticket'] ) and ! empty( $_GET['new-ticket'] and is_numeric( $_GET['new-ticket'] ) ) ) {
            $user = get_user_by( 'id', intval( $_GET['new-ticket'] ) );

            if ( $user ) {
                $page = 'new-ticket';
            }
        }

        include_once WPAP_ADMIN_PATH . "templates/ticket/$page.php";
    }

	function settingsMenuPage() {
        include_once WPAP_ADMIN_PATH . '/templates/settings.php';
    }

	function registerFormBuilderMenuPage() {
        include_once WPAP_ADMIN_PATH . '/templates/form-builder.php';
    }

	function panelMenus() {
        include_once WPAP_ADMIN_PATH . '/templates/panel-menus.php';
    }

	function privateMessage() {
        include_once WPAP_ADMIN_PATH . '/templates/private-message/private-message.php';
    }

	function info() {
        include_once WPAP_ADMIN_PATH . '/templates/info.php';
    }
}

( new WPAPAdminMenu )->init();