<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class WPAPMetaBox
{
    static public function init()
    {
        add_action( 'add_meta_boxes', [ __CLASS__, 'meta_boxes' ] );
        add_action( 'save_post', [ __CLASS__, 'save_important_notice_meta_box' ], 10, 2 );
    }

    public static function meta_boxes()
    {
        add_meta_box(
            'wpap-important-notice',
            __( 'Important Notice', 'arvand-panel' ),
            [ __CLASS__, 'important_notice_meta_box_cb' ],
            'wpap_notifications',
            'side'
        );
    }

    public static function important_notice_meta_box_cb( $post )
    {
        wp_nonce_field( 'important_notice_nonce', 'important_notice_nonce' ); ?>

        <p>
            <span class="dashicons dashicons-info-outline"></span>

            <span>
                <?php _e( 'Important notice can be displayed in dashboard or all panel pages.', 'arvand-panel' ); ?>
            </span>
        </p>

        <p>
            <label>
                <?php $important_notice = get_post_meta( $post->ID, 'wpap_important_notice', true ); ?>
                <input type="checkbox" name="wpap_important_notice" <?php checked( $important_notice > 0 ); ?>/>
                <span><?php _e( 'Important notice?', 'arvand-panel' ); ?></span>
            </label>
        </p>

        <p>
            <label for="wpap-important-notice-display-plcae" style="display: block">
                <?php _e( 'Where to show it?', 'arvand-panel' ); ?>
            </label>

            <select id="wpap-important-notice-display-plcae" style="margin-top: 5px" name="important_notice_display_plcae">
                <?php $place = get_post_meta( $post->ID, 'wpap_important_notice_place', true ); ?>

                <option value="dashboard" <?php selected( $place === 'dashboard' ); ?>>
                    <?php _e( 'Dashboard', 'arvand-panel' ); ?>
                </option>

                <option value="all" <?php selected( $place === 'all' ); ?>>
                    <?php _e( 'All panel pages', 'arvand-panel' ); ?>
                </option>
            </select>
        </p>

        <p>
            <label for="wpap-important-notice-type" style="display: block">
                <?php _e( 'Notice type', 'arvand-panel' ); ?>
            </label>

            <select id="wpap-important-notice-type" style="margin-top: 5px" name="important_notice_type">
                <?php $place = get_post_meta( $post->ID, 'wpap_important_notice_type', true ); ?>

                <option value="info" <?php selected( $place === 'info' ); ?>>
                    <?php _e( 'Info', 'arvand-panel' ); ?>
                </option>

                <option value="error" <?php selected( $place === 'error' ); ?>>
                    <?php _e( 'Error', 'arvand-panel' ); ?>
                </option>

                <option value="success" <?php selected( $place === 'success' ); ?>>
                    <?php _e( 'Success', 'arvand-panel' ); ?>
                </option>

                <option value="warning" <?php selected( $place === 'warning' ); ?>>
                    <?php _e( 'Warning', 'arvand-panel' ); ?>
                </option>
            </select>
        </p>

        <?php
    }

    public static function save_important_notice_meta_box( $post_id, $post )
    {
        if ( ! isset( $_POST['important_notice_nonce'] ) or ! wp_verify_nonce( $_POST['important_notice_nonce'], 'important_notice_nonce' ) ) {
            return;
        }

        if ( ! current_user_can( 'edit_post', $post_id ) ) {
            return;
        }

        if ( wp_is_post_autosave( $post_id ) ) {
            return;
        }

        if ( wp_is_post_revision( $post_id ) ) {
            return;
        }

        if ( isset( $_POST['wpap_important_notice'] ) ) {
            update_post_meta( $post_id, 'wpap_important_notice', 1 );
            update_post_meta( $post_id, 'wpap_important_notice_place', $_POST['important_notice_display_plcae'] === 'all' ? 'all' : 'dashboard' );
            $allowed_types = [ 'info', 'error', 'success', 'warning' ];
            update_post_meta( $post_id, 'wpap_important_notice_type', in_array( $_POST['important_notice_type'], $allowed_types ) ? $_POST['important_notice_type'] : 'info' );
        } else {
            update_post_meta( $post_id, 'wpap_important_notice', 0 );
        }
    }
}

WPAPMetaBox::init();