<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class WPAPAdminAsset
{
    static function init()
    {
        add_action( 'admin_enqueue_scripts', [ __CLASS__, 'assets' ] );
        add_action( 'admin_head', [ __CLASS__, 'admin_box_icons_cdn_link' ] );
    }

    static function assets()
    {
        $pages = [ 'wpap-tickets', 'arvand-panel', 'wpap-panel-menus', 'wpap-register-fields', 'wpap-styles', 'wpap-sms-settings', 'wpap-private-message', 'wpap-info' ];

        if ( ! empty( $_GET['page'] ) and in_array( $_GET['page'], $pages ) ) {
            wp_enqueue_style( 'wpap_admin_styles', WPAP_ADMIN_URL . 'assets/css/main.css', [], current_time( 'timestamp' ) );
            wp_enqueue_script( 'wpap_main', WPAP_ADMIN_URL . 'assets/js/main.js', [ 'jquery' ], current_time( 'timestamp' ), true );
            wp_localize_script( 'wpap_main', 'wpapMain', self::mainJSData() );
            wp_enqueue_script( 'wpap_ajax', WPAP_ADMIN_URL . 'assets/js/ajax.js', [ 'jquery' ], current_time( 'timestamp' ), true );
            wp_localize_script( 'wpap_ajax', 'WPAPAjax', self::ajaxData() );

            if ( ! empty( $_GET['section'] ) and in_array(  $_GET['section'], [ 'panel', 'banner' ] ) ) {
                wp_enqueue_media();
                wp_enqueue_script( 'wpap_media', WPAP_ADMIN_URL . 'assets/js/media.js', [ 'jquery' ], current_time( 'timestamp' ), true );
            }

            if ( ! empty( $_GET['section'] ) and $_GET['section'] === 'styles' ) {
                wp_enqueue_style( 'wp-color-picker' );
                wp_enqueue_script( 'wp-color-picker' );
            }

            wp_enqueue_script( 'jquery-ui-sortable' );
        }

        if ( ! empty( $_GET['page'] ) and $_GET['page'] === 'wpap-register-fields' ) {
            wp_enqueue_script( 'wpap_register_fields', WPAP_ADMIN_URL . 'assets/js/register-fields.js', [ 'jquery' ], current_time( 'timestamp' ), true );
            wp_localize_script( 'wpap_register_fields', 'WPAPRegFields', self::registerFieldsJSData() );
        }

        if ( ! empty( $_GET['page'] ) and $_GET['page'] === 'wpap-panel-menus' ) {
            wp_enqueue_script( 'wpap_panel_menus', WPAP_ADMIN_URL . 'assets/js/panel-menus.js', [ 'jquery' ], current_time( 'timestamp' ), true );
            wp_localize_script( 'wpap_panel_menus', 'panelMenus', self::panelMenusJSData() );
        }
    }

    static function mainJSData()
    {
        return [
            'dash' => [
                'boxSettingsHtml' => WPAPPanel::dash_box_settings_html(),
                'boxHtml' => WPAPPanel::dash_box_html(),
            ],
            'ticketStatusPlaceholder' => __( 'Enter status name.', 'arvand-panel' ),
            'ticketDepPlaceholder' => __( 'Enter department name.', 'arvand-panel' ),
            'deleteText' => __( 'Delete', 'arvand-panel' ),
        ];
    }

    static function ajaxData()
    {
        return [
            'ajaxurl' => admin_url( 'admin-ajax.php' ),
            'notfoundSupporterMessage' => __( 'There is no supporter.', 'arvand-panel' ),
            'delTicketConfirm' => __( 'Are you sure to delete this ticket?', 'arvand-panel' ),
            'resetStylesConfirm' => __( 'Are you sure to reset all styles?', 'arvand-panel' ),
            'delRoleConfirm' => __( 'Are you sure to delete? new role for users who had the role deleted is: ', 'arvand-panel' ),
            'newRoleError' => __( 'Please select another new role. this role will be deleted.', 'arvand-panel' ),
            'newRoleText' => __( ' role is set for users who had previously deleted roles.', 'arvand-panel' ),
            'nothingRole' => __( 'There is no role.', 'arvand-panel' ),
            'deleteMenuMessage' => __( 'Aru you sure to delete?', 'arvand-panel' )
        ];
    }

    static public function registerFieldsJSData()
    {
        $settings_fields = new WPAPFieldSettingsHtml();

        return [
            'fields' => WPAPField::savedFields(),
            'first_name' => $settings_fields->field_settings( 'first_name' ),
            'last_name' => $settings_fields->field_settings('last_name'),
            'display_name' => $settings_fields->field_settings('display_name'),
            'user_login' => $settings_fields->field_settings('user_login'),
            'user_email' => $settings_fields->field_settings('user_email'),
            'user_pass' => $settings_fields->field_settings('user_pass'),
            'user_url' => $settings_fields->field_settings('user_url'),
            'text_field' => $settings_fields->field_settings('text_field'),
            'radio' => $settings_fields->field_settings('radio'),
            'checkbox' => $settings_fields->field_settings('checkbox'),
            'drop_down' => $settings_fields->field_settings('drop_down'),
            'number_field' => $settings_fields->field_settings('number_field'),
            'mobile' => $settings_fields->field_settings('mobile'),
            'texts' => [
                'option_text' => __( 'Option', 'arvand-panel' ),
                'field_exist' => __( 'This field already exist', 'arvand-panel' ),
            ]
        ];
    }

    static public function panelMenusJSData()
    {
        return [
            'field' => WPAPPanelMenus::menu_field(),
            'linkPlaceholder' => __( 'eg: https://google.com', 'arvand-panel' ),
            'shortCodePlaceholder' => __( 'Shortcode', 'arvand-panel' ),
            'deleteMenuConfirm' => __( 'Are you sure to completely delete this menu?', 'arvand-panel' ),
            'ajaxurl' => admin_url( 'admin-ajax.php' )
        ];
    }

    static public function admin_box_icons_cdn_link()
    {
        $pages = [ 'arvand-panel', 'wpap-tickets', 'wpap-settings', 'wpap-panel-menus', 'wpap-register-fields', 'wpap-styles', 'wpap-sms-settings', 'wpap-private-message', 'wpap-info' ];

        if ( ! empty( $_GET['page'] ) and in_array( $_GET['page'], $pages ) ) {
            echo '<link href="https://unpkg.com/boxicons@2.0.9/css/boxicons.min.css" rel="stylesheet">';
        }
    }
}

WPAPAdminAsset::init();