<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class WPAPUserAsset
{
    function init()
    {
        add_action( 'wp_enqueue_scripts', [ $this, 'assets' ], PHP_INT_MAX );
        add_action( 'wp_head', [ $this, 'boxIconsCDNlink' ] );
        add_action( 'wp_head', [ $this, 'googleClientAPI' ] );
	    add_filter( 'script_loader_tag', [ $this, 'addModuleType' ], 10, 3 );
    }

    function assets()
    {
        wp_enqueue_style( 'wpap_front_style', WPAP_USER_URL . 'assets/css/main.css', $this->bootstrap(), current_time( 'timestamp' ) );
        wp_enqueue_script( 'wpap_main', WPAP_USER_URL . 'assets/js/main.js', [ 'jquery' ], current_time( 'timestamp' ), true );
        wp_localize_script( 'wpap_main', 'WPAPMain', $this->mainData() );
        wp_enqueue_script( 'wpap_ajax', WPAP_USER_URL . 'assets/js/ajax.js', [ 'jquery' ], current_time( 'timestamp' ), true );
        wp_localize_script( 'wpap_ajax', 'WPAPAjax', $this->ajaxData() );
	    wp_register_script( 'wpap_panel_form_handler', WPAP_USER_URL . 'assets/js/panel-form-handler.js', [ 'jquery' ], current_time( 'timestamp' ), true );
	    wp_localize_script( 'wpap_panel_form_handler', 'WPAPPanelFormHandler', $this->panelFormHandlerData() );
        wp_register_script( 'wpap_password_strength', WPAP_USER_URL . 'assets/js/password-strength.js', [ 'password-strength-meter' ], current_time( 'timestamp' ), true );

        $login = wpap_login_options();

        if ( $login['enable_g_login'] ) {
            wp_register_script( 'wpap_google_login', WPAP_USER_URL . 'assets/js/google-login.js', [ 'jquery' ], current_time( 'timestamp' ), true );
            wp_localize_script( 'wpap_google_login', 'googleLogin', $this->googleLoginJSData() );
        }
    }

    function bootstrap()
    {
        global $post;
        $deps = [];

        if ( is_a( $post, 'WP_Post' ) and has_shortcode( $post->post_content, 'wpap_user_panel' ) ) {
            wp_register_style( 'wpap_bootstrap', WPAP_USER_URL . 'assets/css/bootstrap-grid.min.css' );
            $deps[] = 'wpap_bootstrap';
        }

        return $deps;
    }

	function addModuleType( $tag, $handle, $src )
	{
		if ( 'wpap_ajax' === $handle ) {
			$tag = '<script type="module" src="' . esc_url( $src ) . '"></script>';
		}

		if ( 'wpap_panel_form_handler' === $handle ) {
			$tag = '<script type="module" src="' . esc_url( $src ) . '"></script>';
		}

		return $tag;
	}

	function mainData()
	{
		return [
			'ajaxURL' => admin_url( 'admin-ajax.php' ),
			'uploadAvatarBtnText' => __( 'Change Avatar', 'arvand-panel' )
		];
	}

    function boxIconsCDNlink()
    {
        echo '<link href="https://unpkg.com/boxicons@2.0.9/css/boxicons.min.css" rel="stylesheet">';
    }

    function ajaxData()
    {
        $pass_setting = WPAPFiledSettings::user_pass_settings( WPAPField::user_pass_setting() );

        return [
            'ajaxUrl' => admin_url( 'admin-ajax.php' ),
            'panelUrl' => WPAPPanel::panel_url(),
            'invalidMobileText' => __( 'Invalid mobile number.', 'arvand-panel' ),
            'emptyMobileText' => __( 'Mobile number must not be empty', 'arvand-panel' ),
            'emptyVerifyCodeText' => __( 'Verification code must not be empty', 'arvand-panel' ),
            'agreeErrorText' => __( 'You must agree to the terms.', 'arvand-panel' ),
            'sendAgainText' => __( 'Send Again', 'arvand-panel' ),
            'emptyPass' => __( 'Password must not be empty.', 'arvand-panel' ),
            'passMin' => $pass_setting['min'],
            'passMinText' => sprintf( __( 'Minimum password letters must be %d', 'arvand-panel' ), $pass_setting['min'] ),
            'passMismatch' => __( 'Two passwords do not match.', 'arvand-panel' ),
        ];
    }

	function panelFormHandlerData()
	{
		return [
            'ajaxUrl' => admin_url( 'admin-ajax.php' ),
            'closeMessageBtnText' => __( 'Close', 'arvand-panel' )
        ];
	}

    function googleClientAPI()
    {
        global $post;
        $login = wpap_login_options();

        if ( $login['enable_g_login'] and is_a( $post, 'WP_Post' ) and ( has_shortcode( $post->post_content, 'wpap_login_form' ) or has_shortcode( $post->post_content, 'wpap_user_panel' ) ) ): ?>
            <script src="https://apis.google.com/js/api:client.js"></script>
        <?php endif;
    }

    function googleLoginJSData()
    {
        $login = wpap_login_options();

        return [
            'ajaxUrl' =>  admin_url( 'admin-ajax.php' ),
            'adminUrl' => admin_url(),
            'panelUrl' => WPAPPanel::panel_url(),
            'gLoginClientID' => $login['g_login_client_id'],
        ];
    }
}

( new WPAPUserAsset )->init();