<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class WPAPLogin
{
    static function init()
    {
        add_filter( 'login_redirect', [ __CLASS__, 'RedirectDefaultLogin' ], 10, 3 );

        $login = wpap_login_options();

        if ( $login['enable_g_login'] ) {
            add_action( 'wp_ajax_nopriv_google_login', [ __CLASS__, 'HandleGoogleLogin' ] );
        }

        add_filter( 'logout_redirect', [ __CLASS__, 'afterLogoutPage' ] );
    }

    static public function RedirectDefaultLogin( $redirect_to, $request, $user )
    {
        $login = wpap_login_options();
        $pages_opt = wpap_pages_options();
		$login_url = get_permalink( $pages_opt['login_page_id'] );

        if ( $login['default_login'] and $login_url ) {
            global $pagenow;

            if ( 'wp-login.php' === $pagenow ) {
                wp_safe_redirect( $login_url );
                exit;
            }

            $action = [ 'register', 'logout', 'lostpassword', 'resetpass' ];

            if ( isset( $_GET['action'] ) and ! in_array( $_GET['action'], $action ) ) {
                wp_safe_redirect( $login_url );
                exit;
            }
        }

        return $redirect_to;
    }

    static public function HandleGoogleLogin()
    {
		if ( empty( $_POST['email'] ) ) {
			wp_send_json( [ 'status' => 'error' ] );
		}

        $email = sanitize_email( $_POST['email'] );

        if ( email_exists( $email ) ) {
            $user = get_user_by('email', $email );

            if ( ! $user ) {
	            wp_send_json( [ 'status' => 'error' ] );
			}

            wp_clear_auth_cookie();
            wp_set_current_user( $user->ID );
            wp_set_auth_cookie( $user->ID );
            wp_send_json( [ 'status' => 'success', 'action' => 'login', 'cap' => current_user_can( 'manage_options' ) ] );
		}

        $user_id = wp_insert_user([
			'first_name' => sanitize_text_field( $_POST['first_name'] ),
			'last_name' => sanitize_text_field( $_POST['last_name'] ),
			'display_name' => sanitize_text_field( $_POST['display_name'] ),
			'user_login' => $email,
			'user_email' => $email,
	        'user_pass' => wp_generate_password(),
        ]);

        if ( is_wp_error( $user_id ) ) {
	        wp_send_json( [ 'status' => $user_id->get_error_code() ] );
        }

	    update_user_meta( $user_id, 'wpap_profile_img', sanitize_url( $_POST['image_url'] ) );
        wp_clear_auth_cookie();
        wp_set_current_user( $user_id );
        wp_set_auth_cookie( $user_id );
	    wp_send_json(  [ 'status' => 'success', 'action' => 'register', 'cap' => false ] );
	}

    static public function afterLogoutPage( $redirect_to )
    {
	    $pages_opt = wpap_pages_options();
		$after_logout_url = get_permalink( $pages_opt['after_logout_page_id'] );

		if ( $after_logout_url ) {
            return esc_url( $after_logout_url );
        }

        return $redirect_to;
    }
}

WPAPLogin::init();