<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class WPAPResetPass
{
    static function init()
    {
        add_filter( 'retrieve_password_message', [ __CLASS__, 'wpap_retrieve_password_message' ], 10, 4 );
        add_action( 'login_form_rp', [ __CLASS__, 'wpap_redirect_password_reset' ] );
        add_action( 'login_form_resetpass', [ __CLASS__, 'wpap_redirect_password_reset' ] );
    }

    static public function wpap_retrieve_password_email_content_type()
    {
        return 'text/html';
    }

    static public function wpap_retrieve_password_message( $message, $key, $user_login, $user_data )
    {
        add_filter( 'wp_mail_content_type', [ __CLASS__, 'wpap_retrieve_password_email_content_type' ] );

        $msg  = __( 'Hello!', 'arvand-panel' ) . "\r\n\r\n";
        $msg .= sprintf( __( 'You asked us to reset your password for your account using the user name %s.', 'arvand-panel' ), $user_login ) . "\r\n\r\n";
        $msg .= __( "If this was a mistake, or you didn't ask for a password reset, just ignore this email and nothing will happen.", 'arvand-panel' ) . "\r\n\r\n";
        $msg .= __( 'To reset your password, visit the following address:', 'arvand-panel' ) . "\r\n\r\n";

	    $login = wpap_login_options();
	    $pages_opt = wpap_pages_options();
	    $reset_pass_page = get_post( $pages_opt['reset_pass_page_id'] );

        if ( $login['default_login'] and $reset_pass_page ) {
            $msg .= site_url( "$reset_pass_page->post_name?action=rp&key=$key&login=" . rawurlencode( $user_login ), 'login' ) . "\r\n\r\n";
        } else {
            $msg .= site_url( "wp-login.php?action=rp&key=$key&login=" . rawurlencode( $user_login ), 'login' ) . "\r\n\r\n";
        }

        $msg .= __( 'Thanks!', 'arvand-panel' ) . "\r\n";

        return wpap_email_template( $msg );
    }

    static public function wpap_redirect_password_reset()
    {
        if ( 'GET' == $_SERVER['REQUEST_METHOD'] ) {
            $key = sanitize_text_field( $_REQUEST['key'] );
            $login = sanitize_text_field( $_REQUEST['login'] );
            $user = check_password_reset_key( $key, $login );
	        $pages_opt = wpap_pages_options();
            $login_page_url = get_permalink( $pages_opt['login_page_id'] );

            if ( ! $user or is_wp_error( $user ) ) {
                if ( $user and $user->get_error_code() === 'expired_key' ) {
                    wp_redirect( esc_url( "$login_page_url/?login=expiredkey" ) );
                } else {
                    wp_redirect( esc_url( "$login_page_url/?login=invalidkey" ) );
                }

                exit;
            }

	        $reset_pass_page_url = get_permalink( $pages_opt['reset_pass_page_id'] );
            $redirect_url = esc_url( $reset_pass_page_url );
            $redirect_url = add_query_arg( 'key', $key, $redirect_url );
            $redirect_url = add_query_arg( 'login', $login, $redirect_url );

            wp_redirect( $redirect_url );
            exit;
        }
    }
}

WPAPResetPass::init();