<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class WPAPFieldHtml {
    static function first_name( $settings, $value = false ) {
        $settings = unserialize( $settings );
        $value = $value ? 'value="' . esc_attr( $value ) . '"' : '';
        ?>

        <p>
            <input type='text' name="first_name" placeholder="<?php echo esc_attr( $settings['placeholder'] ); ?>" <?php echo $value; ?>/>

            <?php if ( ! empty( $settings['info'] ) ): ?>
                <span class='wpap-input-info'><?php echo esc_html( $settings['info'] ); ?></span>
            <?php endif; ?>
        </p>

        <?php
    }

    static function last_name( $settings, $value = '' ) {
        $settings = unserialize( $settings );
        $value = ! empty( $value ) ? 'value="' . esc_attr( $value ) . '"' : '';
        ?>

        <p>
            <input type='text' name="last_name" placeholder="<?php echo esc_attr( $settings['placeholder'] ); ?>" <?php echo $value; ?>/>

            <?php if ( ! empty( $settings['info'] ) ): ?>
                <span class='wpap-input-info'><?php esc_html_e( $settings['info'] ); ?></span>
            <?php endif; ?>
        </p>

        <?php
    }

    static function display_name( $settings, $value = ''  ) {
        $settings = unserialize( $settings );
        $value = ! empty( $value ) ? 'value="' . $value . '"' : '';
        ?>

        <p>
            <input type='text' name="display_name" placeholder="<?php echo esc_attr( $settings['placeholder'] ); ?>" <?php echo $value; ?>/>

            <?php if ( ! empty( $settings['info'] ) ): ?>
                <span class='wpap-input-info'><?php esc_html_e( $settings['info'] ); ?></span>
            <?php endif; ?>
        </p>

        <?php
    }

    static function user_login( $settings, $value = ''  ) {
        $settings = unserialize( $settings );
        $attrs = ! empty( $value ) ? 'value="' . esc_attr( $value ) . '" readonly' : '';
        ?>

        <p>
            <input type='text' name="user_login" placeholder="<?php echo esc_attr( $settings['placeholder'] ); ?>" <?php echo $attrs; ?>/>

            <span class='wpap-input-info'>
                <?php echo ! empty( $value ) ? __( 'username can not be changed.', 'arvand-panel' ) : esc_html( $settings['info'] ); ?>
            </span>
        </p>

        <?php
    }

    static function user_email( $settings, $value = '' ) {
        $settings = unserialize( $settings );
        $value = ! empty( $value ) ? $value : '';
        $user = get_user_by( 'id', get_current_user_id() );
        $readonly = ( ! empty( $user->user_email ) and ! empty( $value ) ) ? 'readonly' : '';
        ?>

        <p>
            <input type='email' name="user_email" placeholder="<?php echo esc_attr( $settings['placeholder'] ); ?>" value="<?php echo esc_attr( $value ); ?>" <?php echo $readonly; ?>/>

            <?php if ( ! empty( $settings['info'] ) ): ?>
                <span class='wpap-input-info'><?php esc_html_e( $settings['info'] ); ?></span>
            <?php endif; ?>
        </p>

        <?php
    }

    static function user_pass( $settings ) {
        $settings = unserialize( $settings );
        $register = wpap_register_options();
        ?>

        <p>
            <input type='password' name="user_pass" placeholder="<?php echo esc_attr( $settings['placeholder'] ); ?>"/>

            <?php if ( ! empty( $settings['info'] ) ): ?>
                <span class='wpap-input-info'><?php esc_html_e( $settings['info'] ); ?></span>
            <?php endif; ?>
        </p>

        <p>
            <input type='password' name="user_pass_confirm" placeholder="<?php echo esc_attr( $settings['conf_placeholder'] ); ?>"/>
        </p>

        <?php if ( $register['pass_strength'] ): ?>
            <p><span id="wpap-password-strength"></span></p>
        <?php endif;
    }

    static function user_url( $settings, $value = '' ) {
        $settings = unserialize( $settings );
        $value = ! empty( $value ) ? 'value="' . esc_attr( $value ) . '"' : '';
        ?>

        <p>
            <input type='url' name="user_url" placeholder="<?php echo esc_attr( $settings['placeholder'] ); ?>" <?php echo $value; ?>/>

            <?php if ( ! empty( $settings['info'] ) ): ?>
                <span class='wpap-input-info'><?php esc_html_e( $settings['info'] ); ?></span>
            <?php endif; ?>
        </p>

        <?php
    }

    static function text_field( $settings, $user_id = 0 ) {
        $settings = unserialize( $settings );
        $placeholder = ! empty( $settings['placeholder'] ) ? $settings['placeholder'] : __( 'Text Field', 'arvand-panel' );

        if ( is_admin() ) {
            echo "<tr><th>$placeholder</th><td>";
        }
        ?>

        <p>
            <?php
            $user_id = $user_id > 0 ? $user_id : get_current_user_id();
            $meta = get_user_meta( $user_id, $settings['meta_key'], true );
            ?>

            <input type='text' name="text_field_<?php echo esc_attr( $settings['num'] ); ?>" placeholder="<?php echo esc_attr( $placeholder ); ?>" value="<?php esc_attr_e( $meta );?>"/>

            <?php if ( ! empty( $settings['info'] ) and ! is_admin() ): ?>
                <span class='wpap-input-info'><?php echo esc_html( $settings['info'] ); ?></span>
            <?php endif; ?>
        </p>

        <?php
        if ( is_admin() ) {
            echo '</p></td></tr>';
	    }
    }

    static function radio( $settings, $user_id = 0 ) {
        $settings = unserialize( $settings );
        $label = ! empty( $settings['label'] ) ? $settings['label'] : __( 'Radio button', 'arvand-panel' );

        if ( is_admin() ) {
            echo "<tr><th>$label</th><td>";
        }
        ?>

        <div class="wpap-input-wrap">
            <div class="wpap-options-sets">
                <?php if ( ! is_admin() ): ?>
                    <span class="wpap-radio-title"><?php esc_html_e( $settings['label'] ); ?></span>
                <?php endif; ?>

                <?php
                $user_id = $user_id > 0 ? $user_id : get_current_user_id();
                $meta = get_user_meta( $user_id, $settings['meta_key'], true );
                ?>

                <span class="wpap-radio-button-wrap wpap-options-wrap">
                    <?php for ( $i = 0; $i < count( $settings['options'] ); $i++ ): ?>
                        <label for="wpap-radio-<?php esc_attr_e( $settings['num'] . "_$i" ); ?>">
                            <input id="wpap-radio-<?php esc_attr_e( $settings['num'] . "_$i" ); ?>" type="radio" name="radio_<?php esc_attr_e( $settings['num'] ); ?>" value="<?php esc_attr_e( $settings['options'][$i] ); ?>" <?php checked( $meta, $settings['options'][$i] ); ?>>
                            <span class="wpap-radio-button"></span>
                            <span><?php esc_html_e( $settings['options'][$i] ); ?></span>
                        </label>
                    <?php endfor; ?>
                </span>
            </div>

            <?php if ( ! empty( $settings['info'] ) and ! is_admin() ): ?>
                <span class='wpap-input-info'><?php esc_html_e( $settings['info'] ); ?></span>
            <?php endif; ?>
        </div>

        <?php
        if ( is_admin() ) {
            echo '</p></td></tr>';
	    }
    }

    static function checkbox( $settings, $user_id = 0 ) {
        $settings = unserialize( $settings );
        $label = ! empty( $settings['label'] ) ? $settings['label'] : __( 'Checkbox', 'arvand-panel' );

        if ( is_admin() ) {
            echo "<tr><th>$label</th><td>";
        }
        ?>

        <div class="wpap-input-wrap">
            <div class="wpap-options-sets">
                <?php if ( ! is_admin() ): ?>
                    <span class="wpap-checkbox-title"><?php echo esc_html( $settings['label'] ); ?></span>
                <?php endif; ?>

                <?php
                $user_id = $user_id > 0 ? $user_id : get_current_user_id();
                $meta = get_user_meta( $user_id, $settings['meta_key'], true );
                ?>

                <div class="wpap-options-wrap">
                    <?php for ( $i = 0; $i < count( $settings['options'] ); $i++ ): ?>
                        <span class="wpap-checkbox-wrap">
                            <label for="wpap-checkbox-<?php echo esc_attr( $settings['num'] . "_$i" ); ?>">
                                <input id="wpap-checkbox-<?php echo esc_attr( $settings['num'] . "_$i" ); ?>" type="checkbox" name="checkbox_<?php echo esc_attr( $settings['num'] ); ?>[]" value="<?php echo esc_attr( $settings['options'][$i] ); ?>" <?php checked( $meta and in_array( $settings['options'][$i], unserialize( $meta ) ) ); ?>>
                                <span class="wpap-checkbox"></span>
                                <span><?php echo esc_html( $settings['options'][$i] ); ?></span>
                            </label>
                        </span>
                    <?php endfor; ?>
                </div>
            </div>

            <?php if ( ! empty( $settings['info'] ) and ! is_admin() ): ?>
                <span class='wpap-input-info'><?php echo esc_html( $settings['info'] ); ?></span>
            <?php endif; ?>
        </div>

        <?php
        if ( is_admin() ) {
            echo '</p></td></tr>';
        }
    }

    static function drop_down( $settings, $user_id = 0  ) {
        $settings = unserialize( $settings );
        $label = ! empty( $settings['label'] ) ? $settings['label'] : __( 'Dropdown', 'arvand-panel' );

        if ( is_admin() ) {
            echo "<tr><th>$label</th><td>";
        }
        ?>

        <p>
            <select name="<?php esc_attr_e( $settings['name'] ); ?>">
                <?php if ( ! empty( $settings['select_text'] ) ): ?>
                    <option value="-1"><?php echo esc_html( $settings['select_text'] ); ?></option>
                <?php endif; ?>

                <?php
                $user_id = $user_id > 0 ? $user_id : get_current_user_id();
                $meta = get_user_meta( $user_id, $settings['meta_key'], true );
                ?>

                <?php foreach ( $settings['options'] as $option ): ?>
                    <option value="<?php echo esc_attr( $option ); ?>" <?php selected( $meta, $option ); ?>>
                        <?php echo esc_html( $option ); ?>
                    </option>
                <?php endforeach; ?>
            </select>

            <?php if ( ! empty( $settings['info'] ) and ! is_admin() ): ?>
                <span class='wpap-input-info'><?php echo esc_html( $settings['info'] ); ?></span>
            <?php endif; ?>
        </p>

        <?php
        if ( is_admin() ) {
            echo '</p></td></tr>';
	    }
    }

    static function number_field( $settings, $user_id = 0  ) {
        $settings = unserialize( $settings );

        if ( is_admin() ) {
            echo "<tr><th>{$settings['placeholder']}</th><td>";
        }
        ?>

        <p>
            <?php
            $user_id = $user_id > 0 ? $user_id : get_current_user_id();
            $meta = get_user_meta( $user_id, $settings['meta_key'], true );
            ?>

            <input
                type='number'
                name="number_field_<?php echo esc_attr( $settings['num'] ); ?>"
                placeholder="<?php echo esc_attr( $settings['placeholder'] ); ?>"
                value="<?php echo esc_attr( $meta ); ?>"
                min="<?php echo esc_attr( $settings['min_attr'] ); ?>"

                <?php if ( $settings['max_attr'] > 0 ): ?>
                    max="<?php echo esc_attr( $settings['max_attr'] ); ?>"
                <?php endif; ?>
            />

            <?php if ( ! empty( $settings['info'] ) and ! is_admin() ): ?>
                <span class='wpap-input-info'><?php echo esc_html( $settings['info'] ); ?></span>
            <?php endif; ?>
        </p>

        <?php
        if ( is_admin() ) {
            echo '</p></td></tr>';
	    }
    }

    static function mobile( $settings, $user_id = 0 ) {
        $settings = unserialize( $settings );
        $attrs = '';

	    echo is_admin() ? "<tr><th>{$settings['placeholder']}</th><td>" : '<p>';

        if ( $user_id ) {
            $mobile = get_user_meta( $user_id, 'wpap_user_phone_number', true );
            $attrs = $mobile ? 'value="' . esc_html( $mobile ) . '" readonly' : '';
        }

        if ( is_admin() and empty( $attrs ) ):
            _e( 'No mobile number', 'arvand-panel' );
        else: ?>
            <input type='text' name="mobile" placeholder="<?php echo esc_attr( $settings['placeholder'] ); ?>" <?php echo $attrs ?> />

            <?php if ( ! empty( $settings['info'] ) and ! is_admin() ): ?>
                <span class='wpap-input-info'><?php echo esc_html( $settings['info'] ); ?></span>
            <?php endif; ?>

            <?php if ( is_admin() ): ?>
                <p class='description'>
                    <?php _e( 'Number registered with Arvand Panel', 'arvand-panel' ); ?>
                </p>
            <?php endif;
        endif;

        echo is_admin() ?  '</td></tr>' : '</p>';
    }
}