<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class WPAPFieldSettingsHtml {
    public function field_settings( $name, $settings = '', $id = '' )
    {
        $method_name = "{$name}_settings";
        $opt = ! empty( $settings ) ? WPAPFiledSettings::$method_name( $settings ) : WPAPFiledSettings::$method_name();
        $multi = in_array( $name, WPAPField::supported_fields( 'multi' ) );
        ob_start(); ?>

        <div class="wpap-reg-field-wrap">
            <div>
                <?php if ( ! empty( $id ) ): ?>
                    <input type="hidden" name="field_id[]" value="<?php esc_html_e( $id ); ?>"/>
                    <input type="hidden" name="<?php echo $multi ? "{$name}_id[]" : "{$name}_id"; ?>" value="<?php esc_attr_e( $id ); ?>"/>
                <?php endif; ?>

                <input class="wpap-field-name" type="hidden" name="<?php echo $multi ? "{$name}[]" : $name; ?>"/>

                <?php
                echo $this->preview( $name, $opt );
                echo $this->actions( $name );
                ?>
            </div>

            <?php echo $this->settings( $name, $multi, $opt, $id ); ?>
        </div>

        <?php return ob_get_clean();
    }

    private function preview( $name, $opt )
    {
        ob_start(); ?>

        <?php if ( $name === 'radio' ): ?>
            <label>
                <input type="radio" disabled checked>
                <?php echo ! empty( $opt['label'] ) ? esc_attr( $opt['label'] ) : esc_attr( $opt['title'] ); ?>
            </label>
        <?php elseif ( $name === 'checkbox' ): ?>
            <label>
                <input type="checkbox" disabled checked>
                <?php echo ! empty( $opt['label'] ) ? esc_attr( $opt['label'] ) : esc_attr( $opt['title'] ); ?>
            </label>
        <?php elseif ( $name === 'drop_down' ): ?>
            <select>
                <option><?php echo ! empty( $opt['label'] ) ? esc_attr( $opt['label'] ) : esc_attr( $opt['title'] ); ?></option>
            </select>
        <?php else: ?>
            <input type="text" placeholder="<?php echo ! empty( $opt['placeholder'] ) ? esc_attr( $opt['placeholder'] ) : esc_attr( $opt['title'] ); ?>" disabled/>
        <?php endif; ?>

        <?php return ob_get_clean();
    }

    private function actions( $name )
    {
        ob_start(); ?>

        <div class="wpap-field-actions">
            <a href="" class="wpap-show-field-settings"><i class="bx bx-cog"></i></a>

            <?php if ( ! in_array( $name, [ 'user_login', 'user_email', 'user_pass' ] ) ): ?>
                <a href="" class="wpap-delete-field"><i class="bx bx-trash"></i></a>
            <?php endif; ?>
        </div>

        <?php return ob_get_clean();
    }

    private function settings( $name, $multi, $opt, $id )
    {
        ob_start(); ?>

        <div class="wpap-field-settings">
            <?php if ( in_array( $name, WPAPField::supported_fields( 'multi' ) ) ): ?>
                <p>
                    <label><?php _e( 'Meta Key', 'arvand-panel' ); ?></label>
                    <input class="wpap-<?php esc_attr_e( $name ); ?>-meta-key" type="text" name="<?php echo $multi ? "{$name}_meta_key[]" : "{$name}_meta_key"; ?>" placeholder="<?php _e( 'Meta Key', 'arvand-panel' ); ?>" value="<?php esc_attr_e( $opt['meta_key'] ); ?>">
                </p>
            <?php endif; ?>

            <?php if ( in_array( $name, [ 'radio', 'checkbox', 'drop_down' ] ) ): ?>
                <p>
                    <label><?php _e( 'Label', 'arvand-panel' ); ?></label>
                    <input type="text" name="<?php esc_attr_e( $name ); ?>_label[]" value="<?php esc_attr_e( $opt['label'] ); ?>" placeholder="<?php _e( 'Label', 'arvand-panel' ); ?>">
                </p>
            <?php endif; ?>

            <?php if ( ! in_array( $name, [ 'radio', 'checkbox', 'drop_down' ] ) ): ?>
                <p>
                    <label for="wpap-<?php esc_attr_e( $name ); ?>-placeholder">
                        <?php _e( 'Placeholder', 'arvand-panel' ); ?>
                    </label>

                    <input for="wpap-<?php esc_attr_e( $name ); ?>-placeholder" type="text" name="<?php echo $multi ? "{$name}_placeholder[]" : "{$name}_placeholder"; ?>" value="<?php esc_attr_e( $opt['placeholder'] ); ?>"/>
                </p>
            <?php endif; ?>

            <?php if ( $name === 'user_pass' ): ?>
                <p>
                    <label for="wpap-<?php esc_attr_e( $name ); ?>-placeholder">
                        <?php _e( 'Confirm password placeholder', 'arvand-panel' ); ?>
                    </label>

                    <input id="wpap-<?php esc_attr_e( $name ); ?>-placeholder" type="text" name="conf_<?php esc_attr_e( $name ); ?>_placeholder" value="<?php esc_attr_e( $opt['conf_placeholder'] ); ?>"/>
                </p>
            <?php endif; ?>

            <?php
            if ( $name === 'radio' ) {
                echo $this->radio_options( $opt, $id );
            }

            if ( $name === 'checkbox' ) {
                echo $this->checkbox_options( $opt, $id );
            }

            if ( $name === 'drop_down' ) {
                echo $this->drop_down_setting_fields( $opt, $id );
            }
            ?>

            <p>
                <label for="wpap-<?php esc_attr_e( $name ); ?>-info">
                    <?php _e( 'Field Info', 'arvand-panel' ); ?>
                </label>

                <input id="wpap-<?php esc_attr_e( $name ); ?>-info" type="text" name="<?php echo $multi ? "{$name}_info[]" : "{$name}_info"; ?>" value="<?php esc_attr_e( $opt['info'] ); ?>"/>
            </p>

            <?php if ( ! in_array( $name, [ 'user_email', 'user_url', 'radio', 'checkbox', 'drop_down', 'mobile' ] ) ): ?>
                <p>
                    <label for="wpap-<?php esc_attr_e( $name ); ?>-min">
                        <?php _e( 'Minimum Letter', 'arvand-panel' ); ?>
                    </label>

                    <input id="wpap-<?php esc_attr_e( $name ); ?>-min" type="number" name="<?php echo $multi ? "{$name}_min[]" : "{$name}_min"; ?>" value="<?php esc_attr_e( $opt['min'] ); ?>" min="0"/>
                </p>
            <?php endif; ?>

            <?php if ( $name === 'number_field' ): ?>
                <p>
                    <label for="wpap-<?php esc_attr_e( $name ); ?>-min-attr">
                        <?php _e( 'Min Attribute', 'arvand-panel' ); ?>
                    </label>

                    <input id="wpap-<?php esc_attr_e( $name ); ?>-min-attr" type="number" name="<?php esc_attr_e( $name ); ?>_min_attr[]" value="<?php esc_attr_e( $opt['min_attr'] ); ?>" min="0"/>
                </p>

                <p>
                    <label for="wpap-<?php esc_attr_e( $name ); ?>-max-attr">
                        <?php _e( 'Max Attribute', 'arvand-panel' ); ?>
                    </label>

                    <input id="wpap-<?php esc_attr_e( $name ); ?>-max-attr" type="number" name="<?php esc_attr_e( $name ); ?>_max_attr[]" value="<?php esc_attr_e( $opt['max_attr'] ); ?>" min="0"/>
                </p>
            <?php endif; ?>

            <p>
                <?php if ( ! in_array( $name, [ 'user_login', 'user_email', 'user_pass' ] ) ): ?>
                    <label for="wpap-<?php esc_attr_e( $name ); ?>-required"><?php _e( 'Required?', 'arvand-panel' ); ?></label>

                    <select id="wpap-<?php esc_attr_e( $name ); ?>-required" name="<?php echo $multi ? "{$name}_required[]" : "{$name}_required"; ?>">
                        <option value="optional" <?php selected( $opt['required'], 'optional' ); ?>>
                            <?php _e( 'optional', 'arvand-panel' ); ?>
                        </option>

                        <option value="required" <?php selected( $opt['required'], 'required' ); ?>>
                            <?php _e( 'required', 'arvand-panel' ); ?>
                        </option>
                    </select>
                <?php endif; ?>
            </p>

            <?php if ( $name !== 'user_pass' ): ?>
                <p>
                    <label for="wpap-<?php esc_attr_e( $name ); ?>-user-edit-display">
                        <?php _e( 'Show in profile edit form?', 'arvand-panel' ); ?>
                    </label>

                    <select id="wpap-<?php esc_attr_e( $name ); ?>-user-edit-display" name="<?php echo $multi ? "{$name}_user_edit_display[]" : "{$name}_user_edit_display"; ?>">
                        <option value="show" <?php selected( $opt['user_edit_display'], 'show' ); ?>>
                            <?php _e( 'Show', 'arvand-panel' ); ?>
                        </option>

                        <option value="hide" <?php selected( $opt['user_edit_display'], 'hide' ); ?>>
                            <?php _e( 'Hide', 'arvand-panel' ); ?>
                        </option>
                    </select>
                </p>
            <?php endif; ?>
        </div>

        <?php return ob_get_clean();
    }

    private function radio_options( $opt, $id = '' ) {
        $name = 'radio';
        ob_start(); ?>

        <div class="wpap-multi-field-wrap wpap-<?php esc_attr_e( $name ); ?>-setting-wrap">
            <label><?php _e( 'Radio Buttons', 'arvand-panel' ); ?></label>

            <?php if ( ! empty( $id ) ): ?>
                <?php for ( $i = 0; $i < count( $opt['options'] ); $i++ ): ?>
                    <p>
                        <input class="wpap-radio-label" type="text" value="<?php esc_attr_e( $opt['options'][$i] ); ?>"/>

                        <?php
                        if ( $i > 0 ) {
                            echo '<i class="wpap-multi-fields-delete-field bx bx-trash"></i>';
                        }
                        ?>
                    </p>
                <?php endfor; ?>
            <?php else: ?>
                <p>
                    <input class="wpap-<?php esc_attr_e( $name ); ?>-label" type="text" value="<?php _e( 'option', 'arvand-panel' ); ?>"/>
                </p>
            <?php endif; ?>
        </div>

        <p>
            <button class="wpap-add-new-<?php esc_attr_e( $name ); ?> button-primary">
                <?php _e( 'Add New', 'arvand-panel' ) ?>
            </button>
        </p>

        <?php return ob_get_clean();
    }

    private function checkbox_options( $opt, $id = '' ) {
        $name = 'checkbox';
        ob_start(); ?>

        <div class="wpap-multi-field-wrap wpap-<?php esc_attr_e( $name ); ?>-setting-wrap">
            <label><?php _e( 'Checkbox', 'arvand-panel' ); ?></label>

            <?php if ( ! empty( $id ) ): ?>
                <?php for ( $i = 0; $i < count( $opt['options'] ); $i++ ): ?>
                    <p>
                        <input class="wpap-checkbox-label" type="text" value="<?php esc_attr_e( $opt['options'][$i] ); ?>"/>

                        <?php
                        if ( $i > 0 ) {
                            echo '<i class="wpap-multi-fields-delete-field bx bx-trash"></i>';
                        }
                        ?>
                    </p>
                <?php endfor; ?>
            <?php else: ?>
                <p>
                    <input class="wpap-<?php esc_attr_e( $name ); ?>-label" type="text" value="<?php _e( 'option', 'arvand-panel' ); ?>"/>
                </p>
            <?php endif; ?>
        </div>

        <p>
            <button class="wpap-add-new-<?php esc_attr_e( $name ); ?> button-primary">
                <?php _e( 'Add New', 'arvand-panel' ) ?>
            </button>
        </p>

        <?php return ob_get_clean();
    }

    private function drop_down_setting_fields( $opt, $id = '' ) {
        $name = 'drop_down';
        ob_start(); ?>

        <p>
            <label><?php _e( 'Select Text', 'arvand-panel' ); ?></label>
            <input class="wpap-<?php esc_attr_e( $name ); ?>-select-text" type="text" name="<?php esc_attr_e( $name ); ?>_select_text[]" placeholder="<?php _e( 'Select Text', 'arvand-panel' ); ?>" value="<?php esc_attr_e( $opt['select_text'] ); ?>">
        </p>

        <div class="wpap-multi-field-wrap wpap-<?php esc_attr_e( $name ); ?>-setting-wrap">
            <label><?php _e( 'Dropdown', 'arvand-panel' ); ?></label>

            <?php if ( ! empty( $id ) ): ?>
                <?php for ( $i = 0; $i < count( $opt['options'] ); $i++ ): ?>
                    <p>
                        <input class="wpap-<?php esc_attr_e( $name ); ?>-label" type="text" value="<?php esc_attr_e( $opt['options'][$i] ); ?>"/>
                        <?php if ( $i > 0 ) echo '<a class="wpap-multi-fields-delete-field" href="#"></a>'; ?>
                    </p>
                <?php endfor; ?>
            <?php else: ?>
                <p>
                    <input class="wpap-<?php esc_attr_e( $name ); ?>-label" type="text" value="<?php _e( 'Option', 'arvand-panel' ); ?>"/>
                </p>
            <?php endif; ?>
        </div>

        <p>
            <button class="wpap-add-new-<?php esc_attr_e( $name ); ?> button-primary">
                <?php _e( 'Add New', 'arvand-panel' ) ?>
            </button>
        </p>

        <?php return ob_get_clean();
    }
}