<?php


class WPAPAdminFormHandler
{
    static function init()
    {
        add_action( 'wp_ajax_wpap_styles', [ __CLASS__, 'styles' ] );
        add_action( 'wp_ajax_wpap_reset_styles', [ __CLASS__, 'resetStyles' ] );
        add_action( 'wp_ajax_wpap_new_ticket', [ __CLASS__, 'newTicket' ] );
        add_action( 'wp_ajax_wpap_new_message', [ __CLASS__, 'newPrivateMessage' ] );
    }

    static function styles()
    {
        if ( ! isset( $_POST['styles_nonce'] ) and ! wp_verify_nonce( 'styles_nonce', 'styles_nonce' ) ) {
            wp_send_json( 'error' );
        }

        $data = [
            'panel_bg' => sanitize_hex_color( $_POST['panel_bg'] ),
            'buttons_bg_color' => sanitize_hex_color( $_POST['buttons_bg_color'] ),
            'buttons_text_color' => sanitize_hex_color( $_POST['buttons_text_color'] ),
            'buttons_hover_bg_color' => sanitize_hex_color( $_POST['buttons_hover_bg_color'] ),
            'buttons_hover_text_color' => sanitize_hex_color( $_POST['buttons_hover_text_color'] ),

            'sidebar_bg' => sanitize_hex_color( $_POST['sidebar_bg'] ),
            'top_sidebar_bg' => sanitize_hex_color( $_POST['top_sidebar_bg'] ),
            'top_sidebar_text_color' => sanitize_hex_color( $_POST['top_sidebar_text_color'] ),
            'menus_style' => in_array( $_POST['menus_style'], [ 'primary', 'secondary' ] ) ? $_POST['menus_style'] : 'primary',
            'menus_icon_bg_color' => sanitize_hex_color( $_POST['menus_icon_bg_color'] ),
            'menus_icon_color' => sanitize_hex_color( $_POST['menus_icon_color'] ),
            'menus_icon_bg_hover_color' => sanitize_hex_color( $_POST['menus_icon_bg_hover_color'] ),
            'menus_icon_hover_color' => sanitize_hex_color( $_POST['menus_icon_hover_color'] ),
            'menus_back_btn_icon_bg_color' => sanitize_hex_color( $_POST['menus_back_btn_icon_bg_color'] ),
            'menus_back_btn_icon_color' => sanitize_hex_color( $_POST['menus_back_btn_icon_color'] ),
            'menus_color' => sanitize_hex_color( $_POST['menus_color'] ),
            'menus_hover_bg' => sanitize_hex_color( $_POST['menus_hover_bg'] ),
            'menus_hover_color' => sanitize_hex_color( $_POST['menus_hover_color'] ),
            'sidebar_notice_color' => sanitize_hex_color( $_POST['sidebar_notice_color'] ),

            'header_bg' => sanitize_hex_color( $_POST['header_bg'] ),
            'header_buttons_bg_color' => sanitize_hex_color( $_POST['header_buttons_bg_color'] ),
            'header_buttons_text_color' => sanitize_hex_color( $_POST['header_buttons_text_color'] ),
            'header_buttons_hover_bg_color' => sanitize_hex_color( $_POST['header_buttons_hover_bg_color'] ),
            'header_buttons_hover_text_color' => sanitize_hex_color( $_POST['header_buttons_hover_text_color'] ),

            'dashboard_user_info_bg' => sanitize_hex_color( $_POST['dashboard_user_info_bg'] ),
            'dashboard_user_info_color' => sanitize_hex_color( $_POST['dashboard_user_info_color'] ),
            'dashboard_date_info_bg' => sanitize_hex_color( $_POST['dashboard_date_info_bg'] ),
            'dashboard_date_info_color' => sanitize_hex_color( $_POST['dashboard_date_info_color'] ),
        ];

        update_option( 'wpap_styles', $data );
        wp_send_json( 'success' );
    }

    static function resetStyles()
    {
        if ( ! isset( $_POST['nonce'] ) or ! wp_verify_nonce( $_POST['nonce'], 'reset_styles_nonce' ) ) {
            wp_send_json( 'error' );
        }

        delete_option( 'wpap_styles' );
        wp_send_json( 'success' );
    }

    static function newTicket()
    {
        if ( ! get_user_by( 'id', is_numeric( $_POST['recipient'] ) ? intval( $_POST['recipient'] ) : -1 ) ) {
            wp_send_json( [ 'status' => 'error', 'msg' => __( 'User not exists.', 'arvand-panel' ) ] );
        }

        if ( ! isset( $_POST['new_ticket_nonce'] ) or ! wp_verify_nonce( $_POST['new_ticket_nonce'], 'new_ticket_nonce' ) ) {
            wp_send_json( [ 'status' => 'error', 'msg' => __( 'Invalid Request.', 'arvand-panel' ) ] );
        }

        if ( empty( $_POST['ticket_title'] ) ) {
            wp_send_json( [ 'status' => 'error', 'msg' => __( 'Title must not be empty.', 'arvand-panel' ) ] );
        }

        if ( empty( $_POST['ticket_content'] ) ) {
            wp_send_json( [ 'status' => 'error', 'msg' => __( 'Ticket content must not be empty.', 'arvand-panel' ) ] );
        }

        $ticket_opt = wpap_ticket_options();

        if ( ! empty( $_FILES['wpap_attachment']['name'] ) ) {
            $allowed_ext = [ 'image/jpeg', 'image/jpg', 'image/png', 'application/zip', 'application/x-zip-compressed', 'application/pdf' ];

            if ( ! in_array( $_FILES['wpap_attachment']['type'], $allowed_ext ) ) {
                wp_send_json( [ 'status' => 'error', 'msg' => __( 'Attachment file format is not allowed.', 'arvand-panel' ) ] );
            }

            if ( $_FILES['wpap_attachment']['size'] > ( 1204 * $ticket_opt['ticket_attachment_size'] ) ) {
                wp_send_json( [ 'status' => 'error', 'msg' => sprintf( __( 'Maximum attachment size is %d KB.', 'arvand-panel' ), $ticket_opt['ticket_attachment_size'] ) ] );
            }
        }

        $insert = wp_insert_post([
            'post_type' => 'wpap_ticket',
            'post_title' => wp_strip_all_tags( $_POST['ticket_title'] ),
            'post_content' =>  wpautop( wp_kses( $_POST['ticket_content'], 'post' ) ),
            'post_status' => 'publish',
            'meta_input' => [
                'wpap_from_admin' => get_current_user_id(),
                'wpap_ticket_creator' => get_current_user_id(),
                'wpap_ticket_recipient' => $_POST['recipient'],
                'wpap_ticket_department' => sanitize_text_field( $_POST['ticket_department'] ),
                'wpap_ticket_status' => 'open'
            ]
        ]);

        if ( is_wp_error( $insert ) ) {
            wp_send_json( [ 'status' => 'error', 'msg' => __( 'An error occurred in creating ticket.', 'arvand-panel' ) ] );
        }

        $ticket = new WPAPTicket();

        if ( ! empty( $_FILES['wpap_attachment']['name'] ) ) {
            $ticket->upload_attachment( $_FILES['wpap_attachment'], $insert );
        }

        $user_email = get_the_author_meta( 'email', $_POST['recipient'] );
        $headers = [ 'Content-Type: text/html; charset=UTF-8' ];
        $search = [ '[site_name]', '[site_url]', '[ticket_title]' ];
        $replace = [ get_bloginfo('name'), site_url(), sanitize_text_field( $_POST['ticket_title'] ) ];
        $email_opt = wpap_email_options();
        $email_subject = sanitize_text_field( $email_opt['new_ticket_email_subject'] );
        $email_content = str_replace( $search, $replace, $email_opt['new_ticket_email_content'] );
        wp_mail( $user_email, $email_subject, wpap_email_template( $email_content ), $headers );

        if ( $ticket_opt['enable_ticket_sms'] ) {
            $sms = new WPAPSMSDB();
            $user_mobile = $sms->get_user_mobile( $_POST['recipient'] );

            if ( $user_mobile ) {
                $sms_text = str_replace( $search, $replace, $ticket_opt['new_ticket_sms_text'] );
                WPAPSendMessage::send( $user_mobile, $sms_text );
            }
        }

        wp_send_json( [ 'status' => 'success', 'msg' => __( 'Ticket created.', 'arvand-panel' ) ] );
    }

    static function newPrivateMessage()
    {
        if ( ! isset( $_POST['new_message_nonce'] ) or ! wp_verify_nonce( $_POST['new_message_nonce'], 'new_message_nonce' ) ) {
            wp_send_json( [ 'status' => 'error', 'msg' => __( 'Invalid request.', 'arvand-panel' ) ] );
        }

        if ( ! get_user_by( 'id', is_numeric( $_POST['user'] ) ? intval( $_POST['user'] ) : -1 ) ) {
            wp_send_json( [ 'status' => 'error', 'msg' => __( 'User not exists.', 'arvand-panel' ) ] );
        }

        $allowed_ext = [ 'image/jpeg', 'image/jpg', 'image/png', 'application/zip', 'application/x-zip-compressed', 'application/pdf' ];

        if ( empty( $_POST['message_content'] ) ) {
            wp_send_json( [ 'status' => 'error', 'msg' => __( 'Message must not be empty.', 'arvand-panel' ) ] );
        }

        if ( ! empty( $_FILES['wpap_attachment']['name'] ) and ! in_array( $_FILES['wpap_attachment']['type'], $allowed_ext ) ) {
            wp_send_json( [ 'status' => 'error', 'msg' => __( 'Attachment file format is not allowed.', 'arvand-panel' ) ] );
        }

        $general = wpap_general_options();

        if ( ! empty( $_FILES['wpap_attachment']['name'] ) and $_FILES['wpap_attachment']['size'] > ( 1204 * $general['private_msg_attachment_size'] ) ) {
            wp_send_json( [ 'status' => 'success', 'msg' => sprintf( __( 'Maximum attachment size is %d KB.', 'arvand-panel' ), $general['private_msg_attachment_size'] ) ] );
        }

        $user_id = $_POST['user'];

        $insert = wp_insert_post([
            'post_title' => sanitize_text_field( $_POST['message_title'] ),
            'post_content' => wpautop( wp_kses( $_POST['message_content'], 'post' ) ),
            'post_type' => 'wpap_private_message',
            'meta_input' => [ 'wpap_private_msg_recipient' => $user_id, 'wpap_read' => 'unread' ],
            'post_status' => 'publish'
        ]);

        if ( is_wp_error( $insert ) ) {
            wp_send_json( [ 'status' => 'error', 'msg' => __( 'An error occurred in sending message.', 'arvand-panel' ) ] );
        }

        if ( ! empty( $_FILES['wpap_attachment']['name'] ) ) {
            WPAPPrivateMessage::upload_msg_attachment( $_FILES['wpap_attachment'], $insert );
        }

        wp_send_json( [ 'status' => 'success', 'msg' => __( 'Message sent.', 'arvand-panel' ) ] );
    }
}

WPAPAdminFormHandler::init();