<?php


class WPAPSettingsFormHandler
{
    static function init()
    {
        add_action( 'wp_ajax_wpap_general', [ __CLASS__, 'general' ] );
        add_action( 'wp_ajax_wpap_register', [ __CLASS__, 'register' ] );
        add_action( 'wp_ajax_wpap_login', [ __CLASS__, 'login' ] );
        add_action( 'wp_ajax_wpap_account_menu', [ __CLASS__, 'accountMenu' ] );
        add_action( 'wp_ajax_wpap_panel', [ __CLASS__, 'panel' ] );
        add_action( 'wp_ajax_wpap_dashboard', [ __CLASS__, 'dashboard' ] );
        add_action( 'wp_ajax_wpap_dash_boxes', [ __CLASS__, 'dashBoxes' ] );
        add_action( 'wp_ajax_wpap_ticket', [ __CLASS__, 'ticket' ] );
        add_action( 'wp_ajax_wpap_ticket_department', [ __CLASS__, 'ticket_department' ] );
        add_action( 'wp_ajax_wpap_post', [ __CLASS__, 'post' ] );
        add_action( 'wp_ajax_wpap_add_supporter', [ __CLASS__, 'add_supporter' ] );
        add_action( 'wp_ajax_wpap_edit_supporter', [ __CLASS__, 'edit_supporter' ] );
        add_action( 'wp_ajax_wpap_shortcode', [ __CLASS__, 'shortcode' ] );
        add_action( 'wp_ajax_wpap_email', [ __CLASS__, 'email' ] );
        add_action( 'wp_ajax_wpap_pages', [ __CLASS__, 'pages' ] );
        add_action( 'wp_ajax_wpap_banner', [ __CLASS__, 'banner' ] );
        add_action( 'wp_ajax_wpap_roles', [ __CLASS__, 'roles' ] );
    }

    static function general()
    {
        if ( ! isset( $_POST['general_nonce'] ) or ! wp_verify_nonce( $_POST['general_nonce'], 'general_nonce' ) ) {
            wp_send_json( 'error' );
        }

        if ( isset( $_POST['admin_bar_access'] ) ) {
            $general_data['admin_bar_access'] = WPAPUser::wpap_access_prepare( $_POST['admin_bar_access'] );
        }

        if ( isset( $_POST['admin_area_access'] ) ) {
            $general_data['admin_area_access'] = WPAPUser::wpap_access_prepare( $_POST['admin_area_access'] );
        }

        $general_data['private_msg_attachment_size'] = ( is_numeric( $_POST['private_msg_attachment_size'] ) and $_POST['private_msg_attachment_size'] >= 100 ) ? intval( $_POST['private_msg_attachment_size'] ) : 1000;
        update_option( 'wpap_general', $general_data );
        wp_send_json( 'success' );
    }

    static function register()
    {
        if ( ! isset( $_POST['register_nonce'] ) or ! wp_verify_nonce( $_POST['register_nonce'], 'register_nonce' ) ) {
            wp_send_json( 'error' );
        }

        $register_data['enable_def_reg'] = isset( $_POST['enable_def_reg'] );
        $register_data['default_register'] = isset( $_POST['default_register'] );
        $register_data['pass_strength'] = isset( $_POST['pass_strength'] );
        $register_data['enable_recaptcha'] = isset( $_POST['enable_recaptcha'] );
        $register_data['recaptcha_site_key'] = sanitize_text_field( $_POST['recaptcha_site_key'] );
        $register_data['recaptcha_secret_key'] = sanitize_text_field( $_POST['recaptcha_secret_key'] );
        $register_data['register_activation'] = isset( $_POST['register_activation'] );
        $register_data['sms_reg_password'] = isset( $_POST['sms_reg_password'] );
        $register_data['enable_admin_approval'] = isset( $_POST['enable_admin_approval'] );
        $register_data['enable_agree'] = isset( $_POST['enable_agree'] );
        $register_data['agree_required'] = isset( $_POST['agree_required'] );
        $register_data['agree_text'] = wp_kses( $_POST['agree_text'], 'post' );
        update_option( 'wpap_register', $register_data );
        wp_send_json( 'success' );

//        if ( isset( $_POST['register_activation'] ) ) {
//            $users = get_users();
//
//            foreach ( $users as $user ) {
//                update_user_meta( $user->ID, 'wpap_user_status', 1 );
//            }
//        }
    }

    static function login()
    {
        if ( ! isset( $_POST['login_nonce'] ) or ! wp_verify_nonce( $_POST['login_nonce'], 'login_nonce' ) ) {
            wp_send_json( 'error' );
        }

        $login_data['enable_def_login'] = isset( $_POST['enable_def_login'] );
        $login_data['default_login'] = isset( $_POST['default_login'] );
        $login_data['enable_recaptcha'] = isset( $_POST['enable_recaptcha'] );
        $login_data['recaptcha_site_key'] = sanitize_text_field( $_POST['recaptcha_site_key'] );
        $login_data['recaptcha_secret_key'] = sanitize_text_field( $_POST['recaptcha_secret_key'] );
        $login_data['enable_sms_register_login'] = isset( $_POST['enable_sms_register_login'] );
        $login_data['force_to_add_mobile'] = isset( $_POST['force_to_add_mobile'] );
        $login_data['enable_g_login'] = isset( $_POST['enable_g_login'] );
        $login_data['g_login_client_id'] = sanitize_text_field( $_POST['g_login_client_id'] );
        $login_data['reset_pass_method'] = in_array( $_POST['reset_pass_method'], [ 'both', 'mobile', 'email' ] ) ? sanitize_text_field( $_POST['reset_pass_method'] ) : 'both';
        update_option( 'wpap_login', $login_data );
        wp_send_json( 'success' );
    }

    static function accountMenu()
    {
        if ( ! isset( $_POST['account_menu_nonce'] ) or ! wp_verify_nonce( $_POST['account_menu_nonce'], 'account_menu_nonce' ) ) {
            wp_send_json( 'error' );
        }

        $login_data['non_logged_in_btn'] = sanitize_text_field( $_POST['non_logged_in_btn'] );
        $login_data['logged_in_btn'] = sanitize_text_field( $_POST['logged_in_btn'] );
        $login_data['logged_in_btn_icon'] = sanitize_text_field( $_POST['logged_in_btn_icon'] );
        $login_data['logged_in_btn_text'] = sanitize_text_field( $_POST['logged_in_btn_text'] );
        update_option( 'wpap_account_menu', $login_data );
        wp_send_json( 'success' );
    }

    static function panel()
    {
        if ( ! isset( $_POST['panel_nonce'] ) or ! wp_verify_nonce( $_POST['panel_nonce'], 'panel_nonce' ) ) {
            wp_send_json( 'error' );
        }

        $panel_data['fullscreen_compatibility'] = isset( $_POST['fullscreen_compatibility'] );
        $panel_data['display_top_sidebar'] = isset( $_POST['display_top_sidebar'] );
        $panel_data['display_sidebar_links'] = isset( $_POST['display_sidebar_links'] );
        $panel_data['logo_url'] = sanitize_text_field( $_POST['logo_url'] );
        $panel_data['logo_width'] = ( is_numeric( $_POST['logo_width'] ) and $_POST['logo_width'] > 0 ) ? intval( $_POST['logo_width'] ) : '';
        $panel_data['logo_height'] = ( is_numeric( $_POST['logo_height'] ) and $_POST['logo_height'] > 0 ) ? intval( $_POST['logo_height'] ) : 40;
        $panel_data['upload_avatar'] = isset( $_POST['enable_upload_avatar'] );
        $panel_data['avatar_size'] = ( is_numeric( $_POST['avatar_size'] ) and $_POST['avatar_size'] >= 100 ) ? intval( $_POST['avatar_size'] ) : 100;
        $panel_data['notifications_per_page'] = intval( $_POST['notifications_per_page'] );
        $panel_data['comments_per_page'] = intval( $_POST['comments_per_page'] );
        update_option( 'wpap_panel', $panel_data );
        wp_send_json( 'success' );
    }

    static function dashboard()
    {
        if ( ! isset( $_POST['dash_nonce'] ) or ! wp_verify_nonce( $_POST['dash_nonce'], 'dash_nonce' ) ) {
            wp_send_json( 'error' );
        }

        $dash_data = [
            'user_details_display' => $_POST['user_details_display'] === 'show' ? 'show' : 'hide',
            'date_info_display' => $_POST['date_info_display'] === 'show' ? 'show' : 'hide',
            'latest_tickets_display' => $_POST['latest_tickets_display'] === 'show' ? 'show' : 'hide',
            'dash_top_shortcode' => stripslashes( wp_kses( $_POST['dash_top_shortcode'], 'post' ) ),
            'dash_bottom_shortcode' => stripslashes( wp_kses( $_POST['dash_bottom_shortcode'], 'post' ) ),
        ];

        update_option( 'wpap_dash', $dash_data );
        wp_send_json( 'success' );
    }

    static function dashBoxes()
    {
        if ( ! isset( $_POST['dash_box_nonce'] ) or ! wp_verify_nonce( $_POST['dash_box_nonce'], 'dash_box_nonce' ) ) {
            wp_send_json( 'error' );
        }

        $box_data = [];

        for ( $i = 0; $i < count( $_POST['box_id'] ); $i++ ) {
            $id = wp_unique_id( 'dash-box-' );

            $box_data[ "dash-box-$i" ] = [
                'box_id' => $id,
                'name' => ( $_POST['name'][$i] !== 'new_box' ) ? sanitize_text_field( $_POST['name'][$i] ) : $id,
                'bg_color' => ! empty( $_POST['bg_color'][$i] ) ? sanitize_text_field( $_POST['bg_color'][$i] ) : '#ffffff',
                'icon' => ! empty( $_POST['icon'][$i] ) ? sanitize_text_field( $_POST['icon'][$i] ) : 'bx bxs-star',
                'icon_color' => ! empty( $_POST['icon_color'][$i] ) ? sanitize_text_field( $_POST['icon_color'][$i] ) : '#ffffff',
                'icon_bg' => ! empty( $_POST['icon_bg'][$i] ) ? sanitize_text_field( $_POST['icon_bg'][$i] ) : '#0078ff',
                'title' => ! empty( $_POST['title'][$i] ) ? sanitize_text_field( $_POST['title'][$i] ) : __( 'Custom box', 'arvand-panel' ),
                'title_color' => ! empty( $_POST['title_color'][$i] ) ? sanitize_text_field( $_POST['title_color'][$i] ) : '#333333',
                'content' => stripslashes( sanitize_text_field( $_POST['content'][$i] ) ),
                'content_color' => ! empty( $_POST['content_color'][$i] ) ? sanitize_text_field( $_POST['content_color'][$i] ) : '#808080',
                'link' => sanitize_text_field( $_POST['link'][$i] ),
                'box_type' => ( isset( $_POST['box_type'][$i] ) and ! empty( $_POST['box_type'][$i] ) ) ? sanitize_text_field( $_POST['box_type'][$i] ) : 'custom',
                'content_type' => $_POST['content_type'][$i] === 'text' ? 'text' : 'shortcode',
                'display' => $_POST['display'][$i] === 'show' ? 'show' : 'hide',
            ];
        }

        update_option( 'wpap_dash_box', $box_data );
        wp_send_json( 'success' );
    }

    static function ticket()
    {
        if ( ! isset( $_POST['ticket_nonce'] ) or ! wp_verify_nonce( $_POST['ticket_nonce'], 'ticket_nonce' ) ) {
            wp_send_json( 'error' );
        }

        $ticket_attachment_size = intval( $_POST['ticket_attachment_size'] ) >= 100 ? $_POST['ticket_attachment_size'] : 1000;

        if ( isset( $_POST['ticket_status_name'] ) and isset( $_POST['ticket_status_color'] ) and isset( $_POST['ticket_status_text_color'] ) ) {
            $ticket_data['ticket_status'] = [
                'name' => wpap_sanitize_array_fields( $_POST['ticket_status_name'], false ),
                'color' => wpap_sanitize_array_fields( $_POST['ticket_status_color'], false ),
                'text_color' => wpap_sanitize_array_fields( $_POST['ticket_status_text_color'], false ),
            ];
        }

        $ticket_data['ticket_attachment_size'] = $ticket_attachment_size;
        $ticket_data['tickets_per_page'] = intval( $_POST['tickets_per_page'] );
        $ticket_data['ticket_replies_per_page'] = intval( $_POST['ticket_replies_per_page'] );
        $ticket_data['close_ticket_cap'] = isset( $_POST['close_ticket_cap'] );
        $ticket_data['enable_ticket_sms'] = isset( $_POST['enable_ticket_sms'] );
        $ticket_data['ticket_sms_text'] = sanitize_textarea_field( $_POST['ticket_sms_text'] );
        $ticket_data['new_ticket_sms_text'] = sanitize_textarea_field( $_POST['ticket_sms_text'] );
        update_option( 'wpap_ticket', $ticket_data );
        wp_send_json( 'success' );
    }

    static function ticket_department()
    {
        if ( ! isset( $_POST['ticket_department_nonce'] ) or ! wp_verify_nonce( $_POST['ticket_department_nonce'], 'ticket_department_nonce' ) ) {
            wp_send_json( 'error' );
        }

        $ticket_data['enable_department'] = isset( $_POST['enable_department'] );

        $deps = [];

        foreach ( $_POST['departments'] as $dep ) {
            if ( ! empty( $dep ) ) {
                $deps[] = $dep;
            }
        }

        if ( ! count( $deps ) ) {
            $ticket_data['departments'] = [ 0 => __( 'Admin', 'arvand-panel' ) ];
        } else {
            $ticket_data['departments'] = wpap_sanitize_array_fields( $deps, false );
        }

        $update = update_option( 'wpap_ticket_department', $ticket_data );

        if ( $update ) {
            $users = get_users( [ 'meta_key' => 'wpap_user_ticket_department' ] );

            foreach ( $users as $user ) {
                $user_dep = unserialize( get_user_meta( $user->ID, 'wpap_user_ticket_department', true ) );
                $new_user_department = array_intersect( $user_dep, $ticket_data['departments'] );
                update_user_meta( $user->ID, 'wpap_user_ticket_department', maybe_serialize( $new_user_department ) );
            }

            $posts = get_posts([
                'post_type' => 'wpap_ticket',
                'meta_key' => 'wpap_ticket_department',
                'numberposts' => -1,
            ]);

            foreach ( $posts as $post ) {
                $ticket_department = get_post_meta( $post->ID, 'wpap_ticket_department', true );

                if ( ! in_array( $ticket_department, $ticket_data['departments'] ) ) {
                    delete_post_meta( $post->ID, 'wpap_ticket_department' );
                }
            }
        }

        wp_send_json( 'success' );
    }

    static function add_supporter()
    {
        if ( ! isset( $_POST['ticket_department_nonce'] ) or ! wp_verify_nonce( $_POST['ticket_department_nonce'], 'ticket_department_nonce' ) ) {
            wp_send_json( 'error' );
        }

        if ( empty( $_POST['responsible'] ) ) {
            wp_send_json( [ 'status' => 'error', 'msg' => __( 'Username must not be empty.', 'arvand-panel' ) ] );
        }

        if ( ! username_exists( $_POST['responsible'] ) ) {
            wp_send_json( [ 'status' => 'error', 'msg' => __( 'This user does not exist.', 'arvand-panel' ) ] );
        }

        $user_login = sanitize_text_field( $_POST['responsible'] );

        if ( ! isset( $_POST['responsible_for'] ) ) {
            wp_send_json( [ 'status' => 'error', 'msg' => __( 'Choose at least one department.', 'arvand-panel' ) ] );
        }

        $user = get_user_by( 'login', $user_login );
        $td = wpap_ticket_department_options();
        $departments = array_intersect( $_POST['responsible_for'], $td['departments'] );
        update_user_meta( $user->ID, 'wpap_user_ticket_department', maybe_serialize( $departments ) );
        wp_send_json( 'success' );
    }

    static function edit_supporter()
    {
        if ( ! isset( $_POST['ticket_department_nonce'] ) or ! wp_verify_nonce( $_POST['ticket_department_nonce'], 'ticket_department_nonce' ) ) {
            wp_send_json( 'error' );
        }

        $user_login = sanitize_user( $_POST['responsible'] );

        if ( username_exists( $user_login ) and isset( $_POST['responsible_for'] ) ) {
            $user = get_user_by( 'login', $user_login );
            $td = wpap_ticket_department_options();
            $departments = array_intersect( $_POST['responsible_for'], $td['departments'] );
            update_user_meta( $user->ID, 'wpap_user_ticket_department', maybe_serialize( $departments ) );
            wp_send_json( 'success' );
        }

        wp_send_json( 'error' );
    }

	static function shortcode()
	{
		if ( ! isset( $_POST['shortcode_nonce'] ) or ! wp_verify_nonce( $_POST['shortcode_nonce'], 'shortcode_nonce' ) ) {
			wp_send_json( 'error' );
		}

		$dash_data = [
			'before_sidebar_user_info' => stripslashes( wp_kses( $_POST['before_sidebar_user_info'], 'post' ) ),
			'after_sidebar_user_info' => stripslashes( wp_kses( $_POST['after_sidebar_user_info'], 'post' ) ),
			'before_sidebar_nav' => stripslashes( wp_kses( $_POST['before_sidebar_nav'], 'post' ) ),
			'after_sidebar_nav' => stripslashes( wp_kses( $_POST['after_sidebar_nav'], 'post' ) ),
			'panel_header' => stripslashes( wp_kses( $_POST['panel_header'], 'post' ) ),
			'after_logo' => stripslashes( wp_kses( $_POST['after_logo'], 'post' ) ),
			'dash_top_shortcode' => stripslashes( wp_kses( $_POST['dash_top_shortcode'], 'post' ) ),
			'before_dash_info_boxes' => stripslashes( wp_kses( $_POST['before_dash_info_boxes'], 'post' ) ),
			'after_dash_info_boxes' => stripslashes( wp_kses( $_POST['after_dash_info_boxes'], 'post' ) ),
			'dash_bottom_shortcode' => stripslashes( wp_kses( $_POST['dash_bottom_shortcode'], 'post' ) )
		];

		update_option( 'wpap_shortcode', $dash_data );
		wp_send_json( 'success' );
	}

	static function email()
	{
		if ( ! isset( $_POST['email_nonce'] ) or ! wp_verify_nonce( $_POST['email_nonce'], 'email_nonce' ) ) {
			wp_send_json( 'error' );
		}

		$data = [
			'reg_email_subject' => sanitize_text_field( $_POST['reg_email_subject'] ),
			'reg_email_content' => wp_kses( $_POST['reg_email_content'], 'post' ),
			'activation_email_subject' => sanitize_text_field( $_POST['activation_email_subject'] ),
			'activation_email' => wp_kses( $_POST['activation_email'], 'post' ),
			'admin_approval_email_subject' => sanitize_text_field( $_POST['admin_approval_email_subject'] ),
			'admin_approval_email' => wp_kses( $_POST['admin_approval_email'], 'post' ),
			'enable_ticket_email' => isset( $_POST['enable_ticket_email'] ),
			'ticket_email_subject' => wp_strip_all_tags( $_POST['ticket_email_subject'] ),
			'ticket_email_content' => wp_kses( $_POST['ticket_email_content'], 'post' ),
			'new_ticket_email_subject' => wp_strip_all_tags( $_POST['new_ticket_email_subject'] ),
			'new_ticket_email_content' => wp_kses( $_POST['new_ticket_email_content'], 'post' )
		];

		update_option( 'wpap_email', $data );
		wp_send_json( 'success' );
	}

	static function pages()
    {
        if ( ! isset( $_POST['pages_nonce'] ) or ! wp_verify_nonce( $_POST['pages_nonce'], 'pages_nonce' ) ) {
            wp_send_json( 'error' );
        }

        $data = [
            'register_page_id' => is_numeric( $_POST['register_page'] ) ? absint( $_POST['register_page'] ) : false,
            'login_page_id' => is_numeric( $_POST['login_page'] ) ? absint( $_POST['login_page'] ) : false,
            'sms_register_login_page_id' => is_numeric( $_POST['sms_register_login_page'] ) ? absint( $_POST['sms_register_login_page'] ) : false,
            'after_register_page_id' => is_numeric( $_POST['after_register_page'] ) ? absint( $_POST['after_register_page'] ) : false,
            'after_login_page_id' => is_numeric( $_POST['after_login'] ) ? absint( $_POST['after_login'] ) : false,
            'after_sms_register_login_page_id' => is_numeric( $_POST['after_sms_register_login_page'] ) ? absint( $_POST['after_sms_register_login_page'] ) : false,
            'lost_pass_page_id' => is_numeric( $_POST['lost_pass_page'] ) ? absint( $_POST['lost_pass_page'] ) : false,
            'reset_pass_page_id' => is_numeric( $_POST['reset_pass_page'] ) ? absint( $_POST['reset_pass_page'] ) : false,
            'after_logout_page_id' => is_numeric( $_POST['after_logout'] ) ? absint( $_POST['after_logout'] ) : false,
	        'panel_page_id' => is_numeric( $_POST['panel_page'] ) ? absint( $_POST['panel_page'] ) : false
        ];

        update_option( 'wpap_plugin_pages', $data );
        wp_send_json( 'success' );
    }

    static function banner()
    {
        if ( ! isset( $_POST['banner_nonce'] ) or ! wp_verify_nonce( $_POST['banner_nonce'], 'banner_nonce' ) ) {
            wp_send_json( 'error' );
        }

        $allowed_position = [ 'top-panel', 'top-header', 'top-content', 'in-content' ];

        $banner_data = [
            'show' => isset( $_POST['show_banner'] ),
            'large_id' => intval( $_POST['large_banner_id'] ),
            'medium_id' => intval( $_POST['medium_banner_id'] ),
            'small_id' => intval( $_POST['small_banner_id'] ),
            'large_place' => in_array( $_POST['large_banner_position'], $allowed_position ) ? sanitize_text_field( $_POST['large_banner_position'] ) : 'in-content',
            'medium_place' => in_array( $_POST['medium_banner_position'], $allowed_position ) ? sanitize_text_field( $_POST['medium_banner_position'] ) : 'in-content',
            'small_place' => in_array( $_POST['small_banner_position'], $allowed_position ) ? sanitize_text_field( $_POST['small_banner_position'] ) : 'in-content',
            'link' => sanitize_text_field( $_POST['banner_link'] ),
        ];

        update_option( 'wpap_banner', $banner_data );
        wp_send_json( 'success' );
    }

    static function roles()
    {
        if ( ! isset( $_POST['roles_nonce'] ) or ! wp_verify_nonce( $_POST['roles_nonce'], 'roles_nonce' ) ) {
            wp_send_json( 'error' );
        }

        $replace = str_replace( ' ', '_', $_POST['new_role'] );
        $role = 'arvand_panel_' . strtolower( sanitize_text_field( $replace ) );
        $roles = get_editable_roles();

        if ( in_array( $_POST['new_role_after_delete'], array_keys( $roles ) ) ) {
            $data['new_role'] = sanitize_text_field( $_POST['new_role_after_delete'] );
        }

        $update = update_option( 'wpap_roles', $data );

        if ( ! empty( $_POST['new_role'] ) and ! empty( $_POST['role_display_name'] ) ) {
            $add = add_role( $role, sanitize_text_field( $_POST['new_role'] ) );
        }

        if ( ( isset( $update ) and $update ) or ( isset( $add ) and $add ) ) {
            wp_send_json([
				'status' => 'success',
				'role_name' => sanitize_text_field( $_POST['new_role'] ),
				'role' => 'arvand_panel_' . sanitize_text_field( $_POST['new_role'] ),
				'role_nonce' => wp_create_nonce( 'del_role' ),
            ]);
        }

        wp_send_json( 'error' );
    }
}

WPAPSettingsFormHandler::init();