<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class WPAPPanelFormHandler {
    static function init()
    {
		add_action( 'wp_ajax_wpap_change_pass', [ __CLASS__, 'changePassword' ] );
	    add_action( 'wp_ajax_wpap_email_send', [ __CLASS__, 'changeEmail' ] );
	    add_action( 'wp_ajax_wpap_email_verify', [ __CLASS__, 'changeEmailVerify' ] );
	    add_action( 'wp_ajax_wpap_send_ticket', [ __CLASS__, 'newTicket' ] );
	    add_action( 'wp_ajax_wpap_send_ticket_reply', [ __CLASS__, 'ticketReply' ] );
	    add_action( 'wp_ajax_wpap_send_msg_reply', [ __CLASS__, 'privateMessageReply' ] );
    }

    static function changePassword()
    {
	    $user = wp_get_current_user();

		if ( $user->user_login === WPAP_DEMO ) {
			wp_send_json( [ 'status' => 'error', 'msg' => __( 'کاربر دمو قادر به ذخیره سازی نیست.', 'arvand-panel' ) ] );
        }

        if ( empty( $_POST['change_password_nonce'] ) or ! wp_verify_nonce( $_POST['change_password_nonce'], 'change_password_nonce' ) ) {
	        wp_send_json( [ 'status' => 'error', 'msg' => __( 'Invalid Request.', 'arvand-panel' ) ] );
        }

        if ( empty( $_POST['user_pass'] ) ) {
	        wp_send_json( [ 'status' => 'error', 'msg' => __( 'Password must not be empty.', 'arvand-panel' ) ] );
        }

        if ( $_POST['user_pass'] !== $_POST['confirm_user_pass'] ) {
	        wp_send_json( [ 'status' => 'error', 'msg' => __( 'Two passwords do not match.', 'arvand-panel' ) ] );
        }

        $pass_set = WPAPFiledSettings::user_pass_settings( WPAPField::user_pass_setting() );

        if ( strlen( $_POST['user_pass'] ) < $pass_set['min'] ) {
	        wp_send_json( [ 'status' => 'error', 'msg' => sprintf( __( 'Minimum password letters must be %d', 'arvand-panel' ), $pass_set['min'] ) ] );
        }

        $user_update = wp_update_user( [ 'ID' => $user->ID, 'user_pass' => wpap_en_num( $_POST['user_pass'] ) ] );

        if ( is_wp_error( $user_update ) ) {
	        wp_send_json( [ 'status' => 'error', 'msg' => $user_update->get_error_message() ] );
        }

	    wp_send_json( [ 'status' => 'success', 'msg' => __( 'Password changed.', 'arvand-panel' ) ] );
    }

    static function changeEmail()
    {
	    $current_user = wp_get_current_user();

        if ( WPAP_DEMO === $current_user->user_login ) {
	        wp_send_json( [ 'status' => 'error', 'msg' => __( 'کاربر دمو قادر به ذخیره سازی نیست.', 'arvand-panel' ) ] );
        }

        if ( ! isset( $_POST['send_email_verification_code_nonce'] ) or ! wp_verify_nonce( $_POST['send_email_verification_code_nonce'], 'send_email_verification_code_nonce' ) ) {
	        wp_send_json( [ 'status' => 'error', 'msg' => __( 'Invalid request.', 'arvand-panel' ) ] );
        }

        if ( ! is_email( $_POST['email'] ) ) {
	        wp_send_json( [ 'status' => 'error', 'msg' => __( 'Invalid email.', 'arvand-panel' ) ] );
        }

	    $email = sanitize_email( $_POST['email'] );
	    $code = rand( 100000, 999999 );;
        $message = '<h3 style="color: #0078ff">' . __( 'Email Verification Code', 'arvnad-panel' ) . '</h3>';
        $message .= '<p>' . __( 'Your email verification code is:', 'arvnad-panel' ) . '</p>';
        $message .= '<p style="font-size: 22px">' . $code . '</p>';
        $message .= '<p style="color: #0078ff">' . site_url() . '</p>';
        $headers = [ 'Content-Type: text/html; charset=UTF-8' ];

        if ( email_exists( $email ) ) {
            $status = get_user_meta( $current_user->ID, 'wpap_user_status', true );

            if ( $_POST['user_email'] === $current_user->user_email and ! $status ) {
                wp_update_user( [ 'ID' => $current_user->ID, 'user_activation_key' => $code ] );
                update_user_meta( $current_user->ID, 'wpap_user_status', 0 );
                wp_mail( $email, __( "Change Email", 'arvand-panel' ), wpap_email_template( $message ), $headers );
	            wp_send_json( [ 'status' => 'success', 'msg' => __( 'Email verification code sent again to your email.', 'arvand-panel' ) ] );
            }

	        wp_send_json( [ 'status' => 'error', 'msg' => __( 'Email already exist.', 'arvand-panel' ) ] );
        }

        wp_update_user( [ 'ID' => $current_user->ID, 'user_activation_key' => $code ] );
        update_user_meta( $current_user->ID, 'wpap_user_status', 0 );
        wp_mail( $email, __( "Change Email", 'arvand-panel' ), wpap_email_template( $message ), $headers );
	    wp_send_json( [ 'status' => 'success', 'msg' => __( 'Email verification code sent again to your email.', 'arvand-panel' ) ] );
    }

    static function changeEmailVerify()
    {
	    $current_user = wp_get_current_user();

	    if ( WPAP_DEMO === $current_user->user_login ) {
		    wp_send_json( [ 'status' => 'error', 'msg' => __( 'کاربر دمو قادر به ذخیره سازی نیست.', 'arvand-panel' ) ] );
	    }

		if ( empty( $_POST['verify_email_nonce'] ) or ! wp_verify_nonce( $_POST['verify_email_nonce'], 'verify_email_nonce' ) ) {
		    wp_send_json( [ 'status' => 'error', 'msg' => __( 'Invalid request.', 'arvand-panel' ) ] );
	    }

	    if ( empty( $_POST['session_email'] ) or ! is_email( $_POST['session_email'] ) or email_exists( $_POST['session_email'] ) ) {
		    wp_send_json( [ 'status' => 'error', 'msg' => __( 'Invalid request.', 'arvand-panel' ) ] );
	    }

        if ( trim( wpap_en_num( $_POST['verification_code'] ) ) !== $current_user->user_activation_key ) {
	        wp_send_json( [ 'status' => 'error', 'msg' => __( 'Invalid code.', 'arvand-panel' ) ] );
        }

	    $admin = get_user_by( 'email', get_bloginfo( 'admin_email' ) );
	    $update_email = wp_update_user( [ 'ID' => $current_user->ID, 'user_email' => sanitize_email( wpap_en_num( $_POST['session_email'] ) ) ] );

        if ( is_wp_error( $update_email ) ) {
	        wp_send_json( [ 'status' => 'error', 'msg' => __( 'An error occurred in email verification.', 'arvand-panel' ) ] );
        }

	    if ( $admin and $current_user->ID == $admin->ID ) {
		    update_option( 'admin_email', sanitize_email( wpap_en_num( $_POST['email'] ) ) );
	    }

	    wp_update_user( [ 'ID' => $current_user->ID, 'user_activation_key' => '' ] );
        update_user_meta( $current_user->ID, 'wpap_user_status', 1 );
	    wp_send_json( [ 'status' => 'success', 'msg' => __( 'Your email successfully verified.', 'arvand-panel' ) ] );
    }

    static function newTicket()
    {
	    $current_user = wp_get_current_user();

        if ( $current_user->user_login === WPAP_DEMO ) {
	        wp_send_json( [ 'status' => 'error', 'msg' => __( 'کاربر دمو قادر به ذخیره سازی نیست.', 'arvand-panel' ) ] );
        }

        if ( empty( $_POST['new_ticket_nonce'] ) or ! wp_verify_nonce( $_POST['new_ticket_nonce'], 'new_ticket' ) ) {
	        wp_send_json( [ 'status' => 'error', 'msg' => __( 'Invalid Request.', 'arvand-panel' ) ] );
        }

        if ( empty( $_POST['ticket_subject'] ) ) {
			wp_send_json( [ 'status' => 'error', 'msg' => __( 'Title must not be empty.', 'arvand-panel' ) ] );
        }

        if ( empty( $_POST['ticket_content'] ) ) {
			wp_send_json( [ 'status' => 'error', 'msg' => __( 'Message must not be empty.', 'arvand-panel' ) ] );
        }

        $opt = wpap_ticket_options();

        if ( ! empty( $_FILES['wpap_attachment']['name'] ) ) {
            $allowed_ext = [ 'image/jpeg', 'image/jpg', 'image/png', 'application/zip', 'application/x-zip-compressed', 'application/pdf' ];

            if ( ! in_array( $_FILES['wpap_attachment']['type'], $allowed_ext ) ) {
	            wp_send_json( [ 'status' => 'error', 'msg' => __( 'Attachment file format is not allowed.', 'arvand-panel' ) ] );
            }

            if ( $_FILES['wpap_attachment']['size'] > ( 1204 * $opt['ticket_attachment_size'] ) ) {
	            wp_send_json( [ 'status' => 'error', 'msg' => sprintf( __( 'Maximum ticket attachment size size is %d KB.', 'arvand-panel' ), $opt['ticket_attachment_size'] ) ] );
			}
        }

        $meta_data = [
            'wpap_ticket_priority' => sanitize_text_field( $_POST['ticket_priority'] ),
            'wpap_ticket_status' => 'open',
            'wpap_ticket_creator' => $current_user->ID,
        ];

        $ticket_department_opt = wpap_ticket_department_options();

        if ( $ticket_department_opt['enable_department'] and in_array( $_POST['ticket_department'], $ticket_department_opt['departments'] ) ) {
            $meta_data['wpap_ticket_department'] = sanitize_text_field( $_POST['ticket_department'] );
        } else {
            $meta_data['wpap_ticket_department'] = __( 'Admin', 'arvand-panel' );
        }

        $subject = sanitize_text_field( wp_strip_all_tags( $_POST['ticket_subject'] ) );

        $insert = wp_insert_post([
            'post_type' => 'wpap_ticket',
            'post_status' => 'publish',
            'post_title'=> $subject,
            'post_content' => wp_kses( $_POST['ticket_content'], 'post' ),
            'meta_input' => $meta_data,
        ]);

        if ( is_wp_error( $insert ) ) {
	        wp_send_json( [ 'status' => 'error', 'msg' => __( 'An error occurred in creating ticket.', 'arvand-panel' ) ] );
        }

        if ( ! empty( $_FILES['wpap_attachment']['name'] ) ) {
            $ticket = new WPAPTicket();
            $ticket->upload_attachment( $_FILES['wpap_attachment'], $insert );
        }

        $ticket_dep = get_post_meta( $insert, 'wpap_ticket_department', true );

        $users = get_users([
            'meta_query' => [
                [ 'key' => 'wpap_user_ticket_department', 'value' => '"' . $ticket_dep . '"', 'compare' => 'LIKE' ]
            ]
        ]);

        $headers = [ 'Content-Type: text/html; charset=UTF-8' ];
        $search = [ '[site_name]', '[site_url]', '[ticket_title]' ];
        $replace = [ get_bloginfo( 'name' ), site_url(), $subject ];
        $email_opt = wpap_email_options();
        $email_content = str_replace( $search, $replace, $email_opt['new_ticket_email_content'] );

		if ( $email_opt['enable_ticket_email'] ) {
			foreach ( $users as $user ) {
				wp_mail( $user->user_email, sanitize_text_field( $email_opt['new_ticket_email_subject'] ), wpap_email_template( $email_content ), $headers );
			}
		}

        $sms_text = str_replace( $search, $replace, $opt['new_ticket_sms_text'] );

        if ( $opt['enable_ticket_sms'] ) {
            foreach ( $users as $user ) {
                $user_mobile = get_user_meta( $user->ID, 'wpap_user_phone_number', true );

                if ( $user_mobile ) {
                    WPAPSendMessage::send( $user_mobile, $sms_text );
                }
            }
        }

	    wp_send_json( [ 'status' => 'success', 'msg' => __( 'Ticket created. To view the ticket, go to the "Tickets" section.', 'arvand-panel' ) ] );
    }

    static function ticketReply()
    {
	    $current_user = wp_get_current_user();

	    if ( $current_user->user_login === WPAP_DEMO ) {
		    wp_send_json( [ 'status' => 'error', 'msg' => __( 'کاربر دمو قادر به ذخیره سازی نیست.', 'arvand-panel' ) ] );
	    }

        if ( empty( $_POST['ticket_reply_nonce'] ) or ! wp_verify_nonce( $_POST['ticket_reply_nonce'], 'ticket_reply' ) ) {
	        wp_send_json( [ 'status' => 'error', 'msg' => __( 'Invalid Request.', 'arvand-panel' ) ] );
        }

        $opt = wpap_ticket_options();

        if ( ! empty( $_FILES['wpap_attachment']['name'] ) ) {
            $allowed_ext = [ 'image/jpeg', 'image/jpg', 'image/png', 'application/zip', 'application/x-zip-compressed', 'application/pdf' ];

            if ( ! in_array( $_FILES['wpap_attachment']['type'], $allowed_ext ) ) {
	            wp_send_json( [ 'status' => 'error', 'msg' => __( 'Attachment file format is not allowed.', 'arvand-panel' ) ] );
            }

            if ( $_FILES['wpap_attachment']['size'] > ( 1204 * $opt['ticket_attachment_size'] ) ) {
	            wp_send_json( [ 'status' => 'error', 'msg' => sprintf( __( 'Maximum ticket attachment size size is %d KB.', 'arvand-panel' ), $opt['ticket_attachment_size'] ) ] );
			}
        }

        if ( empty( $_POST['ticket_content'] ) ) {
	        wp_send_json( [ 'status' => 'error', 'msg' => __( 'Reply must not be empty.', 'arvand-panel' ) ] );
        }

	    if ( empty( $_POST['post'] ) or ! is_numeric( $_POST['post'] ) ) {
		    wp_send_json( [ 'status' => 'error', 'msg' => __( 'Invalid Request.', 'arvand-panel' ) ] );
	    }

		$post = get_post( absint( $_POST['post'] ) );

	    if ( ! $post or $post->post_type !== 'wpap_ticket' ) {
		    wp_send_json( [ 'status' => 'error', 'msg' => __( 'Invalid Request.', 'arvand-panel' ) ] );
	    }

	    if ( ! empty( $_POST['recipient'] ) and ! is_numeric( $_POST['recipient'] ) ) {
		    wp_send_json( [ 'status' => 'error', 'msg' => __( 'Invalid Request.', 'arvand-panel' ) ] );
	    }

	    if ( $_POST['recipient'] and ! get_user_by( 'id', absint( $_POST['recipient'] ) ) ) {
		    wp_send_json( [ 'status' => 'error', 'msg' => __( 'Invalid Request.', 'arvand-panel' ) ] );
	    }

        $post_data = [
            'post_type' => 'wpap_ticket',
            'post_content' => wpautop( wp_kses( $_POST['ticket_content'], 'post' ) ),
            'post_parent' => $post->ID,
            'post_status' => 'publish',
        ];

        $post_data['meta_input']['wpap_ticket_creator'] = $post->post_author;

		if ( $_POST['recipient'] ) {
			$post_data['meta_input']['wpap_ticket_recipient'] = $_POST['recipient'];
		}

        $insert = wp_insert_post( $post_data );

        if ( is_wp_error( $insert ) ) {
	        wp_send_json( [ 'status' => 'error', 'msg' => __( 'An error occurred in sending reply.', 'arvand-panel' ) ] );
        }

        $pre_status = get_post_meta( $post->ID, 'wpap_ticket_status', true );
        $status = ( in_array( $_POST['ticket_status'], [ 'open', 'solved', 'closed' ] ) or in_array( $_POST['ticket_status'], $opt['ticket_status']['name'] ) ) ? $_POST['ticket_status'] : $pre_status;
        update_post_meta( $post->ID, 'wpap_ticket_status', $status );

		if ( in_array( $_POST['ticket_status'], $opt['ticket_status']['name'] ) ) {
			$key = array_search( $_POST['ticket_status'], $opt['ticket_status']['name'] );
			update_post_meta( $post->ID, 'wpap_ticket_status_color', $opt['ticket_status']['color'][ $key ] );
			update_post_meta( $post->ID, 'wpap_ticket_status_text_color', $opt['ticket_status']['text_color'][ $key ] );
        }

        if ( ! empty( $_FILES['wpap_attachment']['name'] ) ) {
            $ticket = new WPAPTicket();
            $ticket->upload_attachment( $_FILES['wpap_attachment'], $insert );
        }

        $time = current_time( 'mysql' );
        wp_update_post( [ 'ID' => $post->ID, 'post_modified' => $time, 'post_modified_gmt' => get_gmt_from_date( $time ) ] );

        $headers = [ 'Content-Type: text/html; charset=UTF-8' ];
        $search = [ '[site_name]', '[site_url]', '[ticket_title]' ];
        $replace = [ get_bloginfo( 'name' ), site_url(), $post->post_title ];
        $email_opt = wpap_email_options();
        $email_content = str_replace( $search, $replace, $email_opt['ticket_email_content'] );
        $sms_text = str_replace( $search, $replace, $opt['ticket_sms_text'] );
        $ticket_dep = get_post_meta( $post->ID, 'wpap_ticket_department', true );

        $users = get_users([
            'meta_query' => [
                [ 'key' => 'wpap_user_ticket_department', 'value' => '"' . $ticket_dep . '"', 'compare' => 'LIKE' ]
            ]
        ]);

        if ( $post->post_author == $current_user->ID ) {
	        if ( $email_opt['enable_ticket_email'] ) {
		        foreach ( $users as $user ) {
			        wp_mail( $user->user_email, sanitize_text_field( $email_opt['ticket_email_subject'] ), wpap_email_template( $email_content ), $headers );
		        }
	        }

            if ( $opt['enable_ticket_sms'] ) {
                foreach ( $users as $user ) {
                    $user_mobile = get_user_meta( $user->ID, 'wpap_user_phone_number', true );

                    if ( $user_mobile ) {
                        WPAPSendMessage::send( $user_mobile, $sms_text );
                    }
                }
            }
        } else {
	        $user = get_user_by( 'id', $post->post_author );

	        if ( $email_opt['enable_ticket_email'] ) {
		        wp_mail( $user->user_email, sanitize_text_field( $email_opt['ticket_email_subject'] ), wpap_email_template( $email_content ), $headers );
	        }

	        if ( $opt['enable_ticket_sms'] ) {
		        $user_mobile = get_user_meta( $user->ID, 'wpap_user_phone_number', true );

		        if ( $user_mobile ) {
			        WPAPSendMessage::send( $user_mobile, $sms_text );
		        }
	        }
        }

	    wp_send_json( [ 'status' => 'success', 'msg' => __( 'Reply Sent.', 'arvand-panel' ), 'reload' => 'reload' ] );
    }
    
    static function privateMessageReply()
    {
	    $current_user = wp_get_current_user();

        if ( $current_user->user_login === WPAP_DEMO ) {
	        wp_send_json( [ 'status' => 'error', 'msg' => __( 'کاربر دمو قادر به ذخیره سازی نیست.', 'arvand-panel' ) ] );
        }

        if ( empty( $_POST['private_msg_nonce'] ) or ! wp_verify_nonce( $_POST['private_msg_nonce'], 'private_msg_nonce' ) ) {
	        wp_send_json( [ 'status' => 'error', 'msg' => __( 'Invalid Request.', 'arvand-panel' ) ] );
        }

		if ( empty( $_POST['message'] ) or ! is_numeric( $_POST['message'] ) ) {
			wp_send_json( [ 'status' => 'error', 'msg' => __( 'Invalid Request.', 'arvand-panel' ) ] );
		}

		$message = get_post( $_POST['message'] );

	    if ( ! $message or $message->post_type !== 'wpap_private_message' ) {
		    wp_send_json( [ 'status' => 'error', 'msg' => __( 'Invalid Request.', 'arvand-panel' ) ] );
	    }

        if ( empty( $_POST['private_message_content'] ) ) {
	        wp_send_json( [ 'status' => 'error', 'msg' => __( 'Message content must not be empty.', 'arvand-panel' ) ] );
        }

        $allowed_ext = [ 'image/jpeg', 'image/jpg', 'image/png', 'application/zip', 'application/x-zip-compressed', 'application/pdf' ];

        if ( ! empty( $_FILES['wpap_attachment']['name'] ) and ! in_array( $_FILES['wpap_attachment']['type'], $allowed_ext ) ) {
	        wp_send_json( [ 'status' => 'error', 'msg' => __( 'Attachment file format is not allowed.', 'arvand-panel' ) ] );
        }

	    $general = wpap_general_options();

        if ( ! empty( $_FILES['wpap_attachment']['name'] ) and $_FILES['wpap_attachment']['size'] > ( 1204 * $general['private_msg_attachment_size'] ) ) {
	        wp_send_json( [ 'status' => 'error', 'msg' => sprintf( __( 'Maximum attachment size is %d KB.', 'arvand-panel' ), $general['private_msg_attachment_size'] ) ] );
		}

        $insert = wp_insert_post([
            'post_content' => wpautop( wp_kses( $_POST['private_message_content'], 'post' ) ),
            'post_type' => 'wpap_private_message',
            'meta_input' => [ 'wpap_private_msg_recipient' => $message->post_author ],
            'post_status' => 'publish',
            'post_parent' => $message->ID
        ]);

        if ( is_wp_error( $insert ) ) {
	        wp_send_json( [ 'status' => 'error', 'msg' => __( 'An error occurred in sending reply.', 'arvand-panel' ) ] );
        }

        if ( ! empty( $_FILES['wpap_attachment']['name'] ) ) {
            WPAPPrivateMessage::upload_msg_attachment( $_FILES['wpap_attachment'], $insert );
        }

	    wp_send_json( [ 'status' => 'success', 'msg' => __( 'Message sent.', 'arvand-panel' ), 'reload' => 'reload' ] );
    }
}

WPAPPanelFormHandler::init();