<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class WPAPSendMessage
{
    static function send( $number, $message )
    {
        $sms_opt = wpap_sms_options();

        if ( in_array( $sms_opt['provider'], array_keys( WPAPSMS::supportedProviders() ) ) ) {
            $provider_send_function = esc_html( $sms_opt['provider'] ) . '_send_message';
        } else {
            $provider_send_function = 'melipayamak_send_code';
        }

        return self::$provider_send_function( $number, $message );
    }

    static function melipayamak_send_message( $number, $message )
    {
        try {
            ini_set( "soap.wsdl_cache_enabled",0 );
            $sms = new SoapClient('http://api.payamak-panel.com/post/Send.asmx?wsdl', [ 'encoding' => 'UTF-8' ] );
            $opt = wpap_sms_provider_options( 'melipayamak' );

            $data = [
                'username' => $opt['username'],
                'password' => $opt['password'],
                'to' => [ $number ],
                'from' => $opt['from'],
                'text' => $message,
                'isflash' => false
            ];

            return $sms->SendSimpleSMS( $data )->SendSimpleSMSResult;
        } catch (Exception $error ) {
            return $error->getMessage();
        }
    }

    static function farapayamak_send_message( $number, $message )
    {
        try {
            ini_set( "soap.wsdl_cache_enabled",0 );
            $sms = new SoapClient('http://api.payamak-panel.com/post/Send.asmx?wsdl', [ 'encoding' => 'UTF-8' ] );
            $opt = wpap_sms_provider_options( 'farapayamak' );
    
            $data = [
                'username' => $opt['username'],
                'password' => $opt['password'],
                'to' => [ $number ],
                'from' => $opt['from'],
                'text' => $message,
                'isflash' => false
            ];
    
            return $sms->SendSimpleSMS( $data )->SendSimpleSMSResult;
        } catch (Exception $error ) {
            return $error->getMessage();
        }
    }

    static function sms_ir_send_message( $number, $message )
    {
        try {
            include WPAP_INC_PATH . 'classes/sms-providers/sms.ir/SmsIR_SendMessage.php';
            date_default_timezone_set("Asia/Tehran");
            $opt = wpap_sms_provider_options( 'sms_ir' );
            $APIKey = $opt['api_key'];
            $SecretKey = $opt['secret_key'];
            $LineNumber = $opt['from'];
            $MobileNumbers = [ $number ];
            $Messages = [ $message ];
            @$SendDateTime = date( 'Y-m-d' ) . 'T' . date( 'H:i:s' );
            $SmsIR_SendMessage = new SmsIR_SendMessage( $APIKey, $SecretKey, $LineNumber );
            return $SmsIR_SendMessage->SendMessage( $MobileNumbers, $Messages, $SendDateTime );
        } catch ( Exception $error ) {
            return $error->getMessage();
        }
    }

    static function farazsms_send_message( $number, $message )
    {
        $url = "https://ippanel.com/services.jspd";
        $rcpt_nm = [ $number ];
        $opt = wpap_sms_provider_options( 'farazsms' );

        $param = [
            'uname' => $opt['username'],
            'pass' => $opt['password'],
            'from' => $opt['from'],
            'message' => $message,
            'to' => json_encode( $rcpt_nm ),
            'op' => 'send'
        ];

        $handler = curl_init( $url );
        curl_setopt( $handler, CURLOPT_CUSTOMREQUEST, "POST" );
        curl_setopt( $handler, CURLOPT_POSTFIELDS, $param );
        curl_setopt( $handler, CURLOPT_RETURNTRANSFER, true );
        $res = curl_exec( $handler );
        $res = json_decode( $res );
        return $res[0] == 0;
    }

    static function parsgreen_send_message( $number, $message )
    {
        $apiMainurl ='http://sms.parsgreen.ir';
        $opt = wpap_sms_provider_options( 'parsgreen' );
        $apiKey = $opt['api_key'];

        $req = [
            'SmsBody' => $message,
            'Mobiles' => [ $number ],
        ];

        $url = $apiMainurl . '/Apiv2/Message/SendSms';
        $ch = curl_init( $url );
        $jsonDataEncoded = json_encode( $req );
        curl_setopt( $ch, CURLOPT_CUSTOMREQUEST, 'POST' );
        curl_setopt( $ch, CURLOPT_POSTFIELDS, $jsonDataEncoded );
        curl_setopt( $ch, CURLOPT_RETURNTRANSFER, true );
        curl_setopt( $ch, CURLOPT_SSL_VERIFYHOST, 0 );
        curl_setopt( $ch, CURLOPT_SSL_VERIFYPEER, 0 );
        $header = [ 'authorization: BASIC APIKEY:' . $apiKey, 'Content-Type: application/json;charset=utf-8' ];
        curl_setopt( $ch, CURLOPT_HTTPHEADER, $header );
        $result = curl_exec( $ch );
        $res = json_decode( $result );
        curl_close( $ch );
        return $res->R_Success;
    }

    static function modirpayamak_send_message( $number, $message )
    {
        $opt = wpap_sms_provider_options( 'modirpayamak' );
        $url = "https://ippanel.com/services.jspd";
        $rcpt_nm = [ $number ];

        $param = [
            'uname' => $opt['username'],
            'pass' => $opt['password'],
            'from' => $opt['from'],
            'message' => $message,
            'to' => json_encode( $rcpt_nm ),
            'op' => 'send'
        ];

        $handler = curl_init( $url );
        curl_setopt ($handler, CURLOPT_CUSTOMREQUEST, "POST" );
        curl_setopt( $handler, CURLOPT_POSTFIELDS, $param );
        curl_setopt( $handler, CURLOPT_RETURNTRANSFER, true );
        $response2 = curl_exec( $handler );
        $response2 = json_decode( $response2 );
        return $response2;
    }

    static function raygansms_send_message( $number, $message )
    {
        $opt = wpap_sms_provider_options( 'raygansms' );
        $Url= 'http://smspanel.Trez.ir/SendMessageWithPost.ashx';
        $ch = curl_init();
        curl_setopt( $ch, CURLOPT_URL,$Url );
        curl_setopt( $ch, CURLOPT_POST, 1 );

        curl_setopt( $ch, CURLOPT_POSTFIELDS, http_build_query([
            'Username' => $opt['username'],
            'Password' => $opt['password'],
            'PhoneNumber' => $opt['from'],
            'MessageBody' => $message,
            'RecNumber' => $number,
            'Smsclass' => '1'
        ]));

        curl_setopt( $ch, CURLOPT_RETURNTRANSFER, true );
        $server_output = curl_exec( $ch );
        curl_close( $ch );
        return $server_output >= 2000;
    }

    static function webone_sms_send_message( $number, $message )
    {
        $opt = wpap_sms_provider_options( 'webone_sms' );

        try {
            ini_set( 'soap.wsdl_cache_enabled', '0' );
            $sms_client = new SoapClient( 'http://payamakapi.ir/SendService.svc?wsdl', [ 'encoding'=>'UTF-8' ] );
            $parameters['userName'] = $opt['username'];
            $parameters['password'] = $opt['password'];
            $parameters['fromNumber'] = $opt['from'];
            $parameters['toNumbers'] = [ $number ];
            $parameters['messageContent'] = $message;
            $parameters['isFlash'] = false;
            $recId = [ 0 ];
            $status = 0x0;
            $parameters['recId'] = &$recId ;
            $parameters['status'] = &$status ;
            return $sms_client->SendSMS( $parameters )->SendSMSResult;
        } catch ( Exception $e ) {
            return $e->getMessage();
        }
    }
}