<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

function wpap_disable_admin_bar() {
    $general = wpap_general_options();

    if ( ! current_user_can( 'administrator' ) and ! is_admin() ) {
        $user = get_user_by( 'ID', get_current_user_id() );

        if ( $user and isset( $user->roles[0] ) and in_array( $user->roles[0], $general['admin_bar_access'] ) ) {
            show_admin_bar( false );
        }
    }
}

add_action( 'after_setup_theme', 'wpap_disable_admin_bar' );

function wpap_redirect_admin_area() {
    $general = wpap_general_options();

    if ( ! current_user_can( 'manage_options' ) and ! wp_doing_ajax() ) {
        $user = get_user_by( 'ID', get_current_user_id() );

        if ( in_array( $user->roles[0], $general['admin_area_access'] ) ) {
            wp_safe_redirect( home_url() );
            exit;
        }
    }
}

add_action( 'admin_init', 'wpap_redirect_admin_area' );

function wpap_allowed_pages( $page_id ) {
    $page_id = intval( $page_id );
    $pages = get_pages( [ 'post_status' => [ 'publish', 'draft' ] ] );
    $allowed = [];

    foreach ( $pages as $page ) {
        $allowed[] = $page->ID;
    }

    return in_array( $page_id, $allowed ) ? $page_id : false;
}

function wpap_sanitize_array_fields( $arr, $allowed_empty = true ) {
    $fields = [];

    if ( is_array( $arr ) ) {
        for ( $i = 0; $i < count( $arr ); $i++ ) {
            if ( ! $allowed_empty and empty( $arr[$i] ) ) continue;
            $fields[] =  sanitize_text_field( $arr[$i] );
        }
    }

    return $fields;
}

function wpap_en_num( $input ) {
    $persian = [ '۰', '۱', '۲', '۳', '۴', '۵', '۶', '۷', '۸', '۹' ];
    $english = [ '0', '1', '2', '3', '4', '5', '6', '7', '8', '9' ];

    return str_replace( $persian, $english, $input );
}

function wpap_mail_from_name( $original_email_from )
{
    return get_bloginfo( 'name' );
}

add_filter( 'wp_mail_from_name', 'wpap_mail_from_name' );

function wpap_email_template( $content ) {
    ob_start(); ?>

    <div style="
        background-color: #fff;
        max-width: 600px;
        margin: auto;
        padding: 20px;
        <?php echo is_rtl() ? 'direction: rtl;' : ''; ?>
        font-family: Tahoma;
        font-size: 16px;
        border: 1px solid #e6e6e6;
        border-radius: 5px;
    ">
        <?php echo wpautop( $content ); ?>
    </div>

    <?php return ob_get_clean();
}

function wpap_show_message( $text, $type, $dismissible = true, $margin = true )
{
    ob_start();

    switch ( $type ) {
        case 'error':
            $icon = 'bx bx-x-circle';
            break;
        case 'success':
            $icon = 'bx bx-check-circle';
            break;
        default:
            $icon = 'bx bx-info-circle';
    }
    ?>

    <div class="wpap-msg wpap-<?php echo esc_attr( $type ); ?>-msg" <?php echo ! $margin ? 'style="margin: 0"' : '' ?>>
        <i class="<?php esc_attr_e( $icon ); ?>"></i>

        <?php if ( ! is_array( $text ) ): ?>
            <span class="wpap-msg-text"><?php echo esc_html( $text ); ?></span>
        <?php else: ?>
            <ul>
                <?php
                foreach ( $text as $message ) {
                    echo '<li>' . esc_html( $message ) . '</li>';
                }
                ?>
            </ul>
        <?php endif; ?>

        <?php if ( $dismissible ): ?>
            <i class="bx bx-x wpap-dismiss-msg"></i>
        <?php endif; ?>
    </div>

    <?php echo ob_get_clean();
}