<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

function wpap_general_options()
{
    $default = [
        'lost_pass_slug' => false,
        'reset_pass_slug' => false,
        'admin_bar_access' => [],
        'admin_area_access' => [],
        'private_msg_attachment_size' => 1000,
    ];

    return wp_parse_args( get_option( 'wpap_general' ), $default );
}

function wpap_register_options()
{
    $default = [
        'enable_def_reg' => true,
        'register_slug' => false,
        'default_register' => false,
        'pass_strength' => true,
        'enable_recaptcha' => false,
        'recaptcha_site_key' => '',
        'recaptcha_secret_key' => '',
        'register_activation' => true,
        'enable_admin_approval' => false,
        'sms_reg_password' => true,
        'enable_agree' => false,
        'agree_text' => sprintf( __( 'I agree to terms', 'arvand-panel' ), '<a href="#">' . __( 'terms', 'arvand-panel' ) . '</a>'),
        'agree_required' => true,
    ];

    return wp_parse_args( get_option( 'wpap_register' ), $default );
}

function wpap_login_options()
{
    $default = [
        'enable_def_login' => true,
        'login_slug' => false,
        'default_login' => false,
        'after_login' => false,
        'enable_recaptcha' => false,
        'recaptcha_site_key' => '',
        'recaptcha_secret_key' => '',
        'enable_sms_register_login' => false,
        'force_to_add_mobile' => false,
        'enable_g_login' => false,
        'g_login_client_id' => '',
        'reset_pass_slug' => false,
        'reset_pass_method' => 'email',
        'after_logout' => false,
    ];

    return wp_parse_args( get_option( 'wpap_login' ), $default );
}

function wpap_account_menu()
{
    $default = [
        'non_logged_in_btn' => 'signup_login',
        'logged_in_btn' => 'avatar',
        'logged_in_btn_icon' => 'bx bx-user-circle',
        'logged_in_btn_text' => __( 'My Account', 'arvand-panel' ),
    ];

    return wp_parse_args( get_option( 'wpap_account_menu' ), $default );
}

function wpap_panel_options()
{
    $default = [
        'panel_slug' => false,
        'fullscreen_compatibility' => false,
        'display_top_sidebar' => true,
        'display_sidebar_links' => true,
        'logo_url' => '',
        'logo_width' => '',
        'logo_height' => '40',
        'upload_avatar' => true,
        'avatar_size' => 100,
        'notifications_per_page' => 8,
        'comments_per_page' => 8,
    ];

    return wp_parse_args( get_option( 'wpap_panel' ), $default );
}

function wpap_dash_options()
{
    $default = [
        'user_details_display' => 'show',
        'date_info_display' => 'show',
        'latest_tickets_display' => 'show',
    ];

    return wp_parse_args( get_option( 'wpap_dash' ), $default );
}

function wpap_dash_box_options()
{
    $default = [
        'dash-box-0' => [
            'box_id' => 'dash-box-0',
            'name' => 'notifications',
            'bg_color' => '#ffffff',
            'icon' => 'bx bxs-bell',
            'icon_color' => '#0062f5',
            'icon_bg' => '#d6e9ff',
            'title' => __( 'Notifications', 'arvand-panel' ),
            'title_color' => '#333333',
            'content' => __( 'Default content', 'arvand-panel' ),
            'content_color' => '#808080',
            'link' => '',
            'box_type' => 'default',
            'content_type' => __( 'Default content', 'arvand-panel' ),
            'display' => 'show',
        ],
        'dash-box-1' => [
            'box_id' => 'dash-box-2',
            'name' => 'comments',
            'bg_color' => '#ffffff',
            'icon' => 'bx bxs-comment-detail',
            'icon_color' => '#f6743e',
            'icon_bg' => '#fdddd0',
            'title' => __( 'Comments', 'arvand-panel' ),
            'title_color' => '#333333',
            'content' => __( 'Default content', 'arvand-panel' ),
            'content_color' => '#808080',
            'link' => '',
            'box_type' => 'default',
            'content_type' => 'default',
            'display' => 'show',
        ],
        'dash-box-2' => [
            'box_id' => 'dash-box-3',
            'name' => 'private_msg',
            'bg_color' => '#ffffff',
            'icon' => 'bx bxs-message-square-detail',
            'icon_color' => '#4eceaa',
            'icon_bg' => '#d0fff2',
            'title' => __( 'Private Message', 'arvand-panel' ),
            'title_color' => '#333333',
            'content' => __( 'Default content', 'arvand-panel' ),
            'content_color' => '#808080',
            'link' => '',
            'box_type' => 'default',
            'content_type' => 'default',
            'display' => 'show',
        ],
    ];

    return wp_parse_args( get_option( 'wpap_dash_box' ), $default );
}

function wpap_ticket_options()
{
    $default = [
        'ticket_status' => [ 'name' => [], 'color' => [], 'text_color' => [] ],
        'ticket_attachment_size' => 1000,
        'tickets_per_page' => 8,
        'ticket_replies_per_page' => 8,
        'close_ticket_cap' => true,
        'enable_ticket_sms' => false,
        'ticket_sms_text' => __( 'A ticket reply was sent to you on [site_name].', 'arvand-panel' ),
        'new_ticket_sms_text' => __( 'New ticket was sent to you on [site_name].', 'arvand-panel' ),
    ];

    return wp_parse_args( get_option( 'wpap_ticket' ), $default );
}

function wpap_ticket_department_options()
{
    $default = [
        'enable_department' => true,
        'departments' => [ 0 => __( 'Admin', 'arvand-panel' ) ],
    ];

    return wp_parse_args( get_option( 'wpap_ticket_department' ), $default );
}

function wpap_roles_options()
{
    $default = [ 'new_role' => 'subscriber' ];
    return wp_parse_args( get_option( 'wpap_roles' ), $default );
}

function wpap_sms_options()
{
    $default = [ 'provider' => 'melipayamak' ];
    return wp_parse_args( get_option( 'wpap_sms' ), $default );
}

function wpap_sms_provider_options( $provider_name )
{
    $default = [
        'username' => '',
        'password' => '',
        'from' => '',
        'pattern_code' => ''
    ];

    $provider['melipayamak'] = wp_parse_args( get_option( 'wpap_sms_melipayamak' ), $default );
    $provider['farapayamak'] = wp_parse_args( get_option( 'wpap_sms_farapayamak' ), $default );

    $default = [
        'api_key' => '',
        'secret_key' => '',
        'from' => '',
        'template_id' => '',
    ];

    $provider['sms_ir'] = wp_parse_args( get_option( 'wpap_sms_sms_ir' ), $default );

    $default = [
        'username' => '',
        'password' => '',
        'from' => '',
        'pattern_code' => '',
    ];

    $provider['farazsms'] = wp_parse_args( get_option( 'wpap_sms_farazsms' ), $default );

    $default = [ 'api_key' => '' ];
    $provider['parsgreen'] = wp_parse_args( get_option( 'wpap_sms_parsgreen' ), $default );

    $default = [
        'username' => '',
        'password' => '',
        'from' => '',
        'pattern_code' => '',
    ];

    $provider['modirpayamak'] = wp_parse_args( get_option( 'wpap_sms_modirpayamak' ), $default );

    $default = [
        'username' => '',
        'password' => '',
        'from' => '',
        'text' => "کاربر گرامی [site_name] از شما سپاسگذاریم.\nکد تایید: [verification_code]",
    ];

    $provider['raygansms'] = wp_parse_args( get_option( 'wpap_sms_raygansms' ), $default );
    $provider['webone_sms'] = wp_parse_args( get_option( 'wpap_sms_webone_sms' ), $default );

    return $provider[ $provider_name ];
}

function wpap_pages_options()
{
	$default = [
		'register_page_id' =>  false,
		'login_page_id' =>  false,
		'sms_register_login_page_id' =>  false,
		'after_register_page_id' =>  false,
		'after_login_page_id' =>  false,
		'after_sms_register_login_page_id' =>  false,
		'lost_pass_page_id' =>  false,
		'reset_pass_page_id' =>  false,
		'after_logout_page_id' =>  false,
		'panel_page_id' =>  false
	];

	return wp_parse_args( get_option( 'wpap_plugin_pages' ), $default );
}

function wpap_shortcode_options()
{
	$default = [
		'before_sidebar_user_info' => '',
		'after_sidebar_user_info' => '',
		'before_sidebar_nav' => '',
		'after_sidebar_nav' => '',
		'panel_header' => '',
		'after_logo' => '',
		'dash_top_shortcode' => '',
		'before_dash_info_boxes' => '',
		'after_dash_info_boxes' => '',
		'dash_bottom_shortcode' => ''
	];

	return wp_parse_args( get_option( 'wpap_shortcode' ), $default );
}

function wpap_email_options()
{
    $default_reg_email = '<p>' . __( 'New user with this email:', 'arvand-panel' ) . '</p>';
    $default_reg_email .= '<p>[user_email]</p>';
    $default_reg_email .= '<p>' . __( 'registered on your site.', 'arvand-panel' ) . '</p>';
    $default_reg_email .= '<p style="font-size: 12px"><a href="' . site_url() . '">' . get_bloginfo( 'name' ) . '</a></p>';
    $activation_email = '<p>' . __( 'Click on the account activation link below.', 'arvand-panel' ) . '</p>';
    $activation_email .= '<p>[activation_link]</p>';
    $admin_approval_email = '<p>' . __( 'Your user account has been approved by admin.', 'arvand-panel' ) . '</p>';
    $admin_approval_email .= '<p><a href="' . esc_url( site_url() ) . '" style="font-size: 14px">' . get_bloginfo( 'name' ) . '</a></p>';

    $default = [
        'reg_email_subject' => __( 'New user registration', 'arvand-panel' ),
        'reg_email_content' => $default_reg_email,
        'activation_email_subject' => __( 'Account Activation', 'arvand-panel' ),
        'activation_email' => $activation_email,
        'admin_approval_email_subject' => __( 'Account Approval', 'arvand-panel' ),
        'admin_approval_email' => $admin_approval_email,
	    'enable_ticket_email' => true,
        'ticket_email_subject' => __( 'Ticket Reply', 'arvand-panel' ),
        'ticket_email_content' => __( 'A ticket reply was sent to you on [site_name].', 'arvand-panel' ),
        'new_ticket_email_subject' => __( 'New Ticket', 'arvand-panel' ),
        'new_ticket_email_content' => __( 'New ticket was sent to you on [site_name].', 'arvand-panel' )
    ];

    return wp_parse_args( get_option( 'wpap_email' ), $default );
}

function wpap_styles()
{
    $default = [
        'panel_bg' => '#ecf1f7',
        'buttons_bg_color' => '#0062f5',
        'buttons_text_color' => '#ffffff',
        'buttons_hover_bg_color' => '#0054d1',
        'buttons_hover_text_color' => '#ffffff',

        'sidebar_bg' => '#0062f5',
        'top_sidebar_bg' => '#005adf',
        'top_sidebar_text_color' => '#ffffff',
        'menus_style' => 'primary',
        'menus_icon_bg_color' => '#297fff',
        'menus_icon_color' => '#ffffff',
        'menus_icon_bg_hover_color' => '#ffffff',
        'menus_icon_hover_color' => '#333333',
        'menus_back_btn_icon_bg_color' => '#fff200',
        'menus_back_btn_icon_color' => '#333333',
        'menus_color' => '#ffffff',
        'menus_hover_bg' => '#0062f5',
        'menus_hover_color' => '#ffffff',
        'sidebar_notice_color' => '#ff006c',

        'header_bg' => '#ffffff',
        'header_buttons_bg_color' => '#ededed',
        'header_buttons_text_color' => '#666666',
        'header_buttons_hover_bg_color' => '#0062f5',
        'header_buttons_hover_text_color' => '#ffffff',

        'dashboard_user_info_bg' => '#ffffff',
        'dashboard_user_info_color' => '#666666',
        'dashboard_date_info_bg' => '#0062f5',
        'dashboard_date_info_color' => '#ffffff',
    ];

    return wp_parse_args( get_option( 'wpap_styles' ), $default );
}