<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

$recipient = get_post_meta( $message->ID, 'wpap_private_msg_recipient', true );

if ( $message->post_parent > 0 or $recipient != $current_user->ID ) {
    echo '<script>window.location.href = "?section=private-msg";</script>';
}
?>

<article id="wpap-single-msg" class="wpap-card">
    <header>
        <?php if ( $unread = get_post_meta( $message->ID, 'wpap_read', true ) ): ?>
            <strong class="wpap-unread wpap-badge-error">
                <?php _e( 'New', 'arvand-panel' ); ?>
            </strong>

            <?php
            if ( $current_user->user_login !== WPAP_DEMO ) {
                delete_post_meta( $message->ID, 'wpap_read', 'unread' );
            }
            ?>
        <?php endif; ?>

        <?php echo get_avatar( $message->post_author ); ?>
        
        <span class="wpap-sender-name">
            <?php echo get_the_author_meta( 'display_name', $message->post_author ); ?>
        </span>
    </header>

    <div>
        <div class="wpap-card-content">
            <?php
            if ( ! empty( get_the_title( $message->ID ) ) ) {
                echo '<h3>' . get_the_title( $message->ID ) . '</h3>';
            }

            echo get_the_content( '', '', $message->ID );
            $attachment = get_post_meta( $message->ID, 'wpap_msg_attachment', true );
            ?>

            <?php if ( $attachment ): ?>
                <a class="wpap-msg-attachment-file" href="<?php echo esc_url( $attachment ); ?>" download>
                    <i class="bx bx-upload"></i>
                    <?php _e( 'Attachment File', 'arvand-panel' ); ?>
                </a>
            <?php endif; ?>
        </div>

        <footer>
            <span>
                <i class="bx bx-time"></i>
                <?php echo sprintf( __( '%s at %s', 'arvand-panel' ), get_the_date( '', $message->ID ), get_the_time( '', $post->ID ) ); ?>
            </span>
        </footer>
    </div>
</article>

<div id="wpap-msg-replies">
    <?php
    $posts = get_posts([
        'post_type' => 'wpap_private_message',
        'post_parent' => $message->ID,
        'numberposts' => -1,
        'post_status' => 'publish'
    ]);
    ?>

    <?php if ( count( $posts ) ): ?>
        <?php foreach ( $posts as $post ): ?>
            <?php $admin_reply = ( $current_user->ID != $post->post_author ) ? 'wpap-admin-reply' : null; ?>
            
            <article class="wpap-message-reply wpap-card <?php echo $admin_reply; ?>">
                <header>
                    <?php if ( $unread = get_post_meta( $post->ID, 'wpap_read', true ) ): ?>
                        <strong class="wpap-unread wpap-badge-error">
                            <?php _e( 'New', 'arvand-panel' ); ?>
                        </strong>

                        <?php
                        if ( $current_user->user_login !== WPAP_DEMO ) {
                            delete_post_meta( $post->ID, 'wpap_read', 'unread' );
                        }
                        ?>
                    <?php endif; ?>

                    <?php echo get_avatar( $post->post_author ); ?>
                    <span><?php echo get_the_author_meta( 'display_name', $post->post_author ); ?></span>
                </header>
                
                <div>
                    <div class="wpap-card-content">
                        <?php
                        if ( ! empty( get_the_title( $post->ID ) ) ) {
                            echo '<h3>' . get_the_title( $post->ID ) . '</h3>';
                        }

                        echo get_the_content( '', '', $post->ID );
                        $attachment = get_post_meta( $post->ID, 'wpap_msg_attachment', true );
                        ?>

                        <?php if ( $attachment ): ?>
                            <a class="wpap-msg-attachment-file" href="<?php echo esc_url( $attachment ); ?>" download>
                                <i class="bx bx-paperclip"></i>
                                <?php _e( 'Attachment File', 'arvand-panel' ); ?>
                            </a>
                        <?php endif; ?>
                    </div>

                    <footer>
                        <span>
                            <i class="bx bx-time"></i>
                            <?php echo sprintf( __( '%s at %s', 'arvand-panel' ), get_the_date( '', $post->ID ), get_the_time( '', $post->ID ) ); ?>
                        </span>
                    </footer>
                </div>
            </article>
        <?php endforeach; ?>
    <?php endif; ?>
</div>

<div class="wpap-form-wrap">
    <form id="wpap-message-reply-form" method="post" enctype="multipart/form-data">
        <?php wp_nonce_field( 'private_msg_nonce', 'private_msg_nonce' ); ?>
        <input type="hidden" name="action" value="send_msg_reply"/>
        <input type="hidden" name="message" value="<?php echo esc_attr( $message->ID ); ?>"/>
        <label><?php _e( 'Your Message', 'arvand-panel' ); ?></label>

        <?php
        $args = [
            'media_buttons' => false,
            'textarea_name' => 'private_message_content',
            'textarea_rows' => 5,
            'quicktags' => false,
            'tinymce' => [
                'toolbar1' => 'bold,italic,underline,separator,alignleft,aligncenter,alignright,separator,link,unlink,undo,redo',
                'toolbar2' => '',
                'toolbar3' => '',
            ],
        ];

        wp_editor( '', 'wpap-private-message-content', $args );
        ?>

        <p>
            <label id="wpap-upload-attachment">
                <input type="file" name="wpap_attachment" hidden/>
                <i class="bx bx-upload"></i>
                <span><?php _e( 'Upload Attachment', 'arvand-panel' ); ?></span>
            </label>

            <span class="wpap-input-info">
                <?php
                $general = wpap_general_options();
                echo sprintf( __( 'Maximum size is %d KB and allowed extensions: jpg - jpeg - png - pdf - zip', 'arvand-panel' ), $general['private_msg_attachment_size'] );
                ?>
            </span>
        </p>

        <button class="wpap-btn-1" type="submit">
            <span class="wpap-btn-text"><?php esc_attr_e( 'Send Message', 'arvand-panel' ); ?></span>
            <div class="wpap-loading"></div>
        </button>
    </form>
</div>