<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

$recipient = get_post_meta( $main_ticket->ID, 'wpap_ticket_recipient', true );
$creator = intval( get_post_meta( $main_ticket->ID, 'wpap_ticket_creator', true ) );
$department = get_post_meta( $main_ticket->ID, 'wpap_ticket_department', true );
$user_dep = WPAPTicket::userDepartment( $current_user->ID );

if ( ! in_array( $current_user->ID, [ $creator, $recipient ] ) and ( ! $user_dep or ! in_array( $department, $user_dep ) ) ) {
    echo "<script>window.location.href = '?section=tickets';</script>";
}

$ticket_opt = wpap_ticket_options();

if ( $current_user->user_login !== WPAP_DEMO and $ticket_opt['close_ticket_cap'] and isset( $_GET['close-ticket'] ) and wp_verify_nonce( $_GET['close-ticket'], 'close_ticket' ) ) {
    if ( update_post_meta( $main_ticket->ID, 'wpap_ticket_status', 'closed' ) ) {
        $success = __( 'Ticket Closed.', 'arvand-panel' );
    }
}

if ( $current_user->user_login !== WPAP_DEMO and isset( $_GET['solved-ticket'] ) and wp_verify_nonce( $_GET['solved-ticket'], 'solved_ticket' ) ) {
    if ( update_post_meta( $main_ticket->ID, 'wpap_ticket_status', 'solved' ) ) {
        $success = __( 'Ticket Solved.', 'arvand-panel' );
    }
}
?>

<div id="wpap-single-ticket">
    <?php
    if ( isset( $success ) ) {
        wpap_show_message( $success, 'success' );
    }
    ?>

    <?php if ( in_array( 'new-ticket', $sections ) ): ?>
        <a id="wpap-new-ticket-btn" class="wpap-btn-1" href="<?php echo esc_url( add_query_arg( [ 'section' => 'new-ticket' ], remove_query_arg( $remove_args ) ) ); ?>">
            <i class='bx bx-plus-circle'></i>
            <?php _e( 'New Ticket', 'arvand-panel' ); ?>
        </a>
    <?php endif ?>

    <?php $status = get_post_meta( $main_ticket->ID, 'wpap_ticket_status', true ); ?>

    <?php if ( ! in_array( $status, [ 'closed', 'solved' ] ) ): ?>
        <?php if ( $ticket_opt['close_ticket_cap'] ): ?>
            <?php $args = [ 'close-ticket' => wp_create_nonce( 'close_ticket' ) ]; ?>

            <a id="wpap-close-ticket" class="wpap-btn-1" href="<?php echo esc_url( add_query_arg( $args, remove_query_arg( [ 'solved-ticket' ] ) ) ); ?>"
               onclick="return confirm('<?php _e( 'Are you sure you want to close this ticket?', 'arvand-panel' ); ?>')">
                <i class='bx bx-x-circle'></i>
                <?php _e( 'Close Ticket', 'arvand-panel' ); ?>
            </a>
        <?php endif; ?>

        <?php $args = [ 'solved-ticket' => wp_create_nonce( 'solved_ticket' ) ]; ?>

        <a id="wpap-solved-ticket" class="wpap-btn-1" href="<?php echo esc_url( add_query_arg( $args, remove_query_arg( [ 'close-ticket' ] ) ) ); ?>">
            <i class='bx bx-check-circle'></i>
            <?php _e( 'Solved', 'arvand-panel' ); ?>
        </a>
    <?php endif; ?>

    <article id="wpap-ticket" class="wpap-card">
        <header>
            <?php echo get_avatar( $main_ticket->post_author, '50' ); ?>

            <span class="wpap-sender-name">
                <?php echo get_the_author_meta( 'display_name', $main_ticket->post_author ); ?>
            </span>
        </header>
        
        <div>
            <div id="wpap-ticket-badges">
                <span>
                    <?php
                    if ( $status ) {
                        if ( $status === 'closed' ) {
                            echo '<strong class="wpap-badge-success">' . __( 'Closed', 'arvand-panel' ) . '</strong>';
                        } elseif ( $status === 'solved' ) {
                            echo '<strong class="wpap-badge-success">' . __( 'Solved', 'arvand-panel' ) . '</strong>';
                        } elseif ( $status === 'open' ) {
                            echo '<strong class="wpap-badge-error">' . __( 'Open', 'arvand-panel' ) . '</strong>';
                        } else {
                            $status_color = get_post_meta( $main_ticket->ID, 'wpap_ticket_status_color', true );
                            $status_text_color = get_post_meta( $main_ticket->ID, 'wpap_ticket_status_text_color', true );
                            echo "<span class='wpap-badge' style='background-color: $status_color; color: $status_text_color;'>$status</span>";
                        }
                    } else {
                        echo '---';
                    }
                    ?>
                </span>

                <span>
                    <?php
                    $priority = get_post_meta( get_the_ID(), 'wpap_ticket_priority', true );

                    if ( $priority === 'low' ) {
                        echo '<strong class="wpap-badge-info">' . __( 'Low priority', 'arvand-panel' ) . '</strong>';
                    } elseif ( $priority === 'normal' ) {
                        echo '<strong class="wpap-badge-info">' . __( 'Normal priority', 'arvand-panel' ) . '</strong>';
                    } else {
                        echo '<strong class="wpap-badge-info">' . __( 'High priority', 'arvand-panel' ) . '</strong>';
                    }
                    ?>
                </span>

                <span>
                    <?php
                    $attachment = get_post_meta( $main_ticket->ID, 'wpap_ticket_attachment', true );

                    if ( $attachment ) {
                        echo '<strong class="wpap-badge-info">' . __( 'With attachment', 'arvand-panel' ) . '</strong>';
                    } else {
                        echo '<strong class="wpap-badge-warning">' . __( 'No attachment', 'arvand-panel' ) . '</strong>';
                    }
                    ?>
                </span>
            </div>

            <div id="wpap-single-ticket-content" class="wpap-card-content">
                <h3><?php echo get_the_title( $main_ticket->ID ); ?></h3>

                <?php
                echo wpautop( get_the_content( null, false, $main_ticket->ID ) );
                $attachment = get_post_meta( $main_ticket->ID, 'wpap_ticket_attachment', true );
                ?>

                <?php if ( $attachment ): ?>
                    <a class="wpap-ticket-attachment-file" href="<?php echo esc_url( $attachment ); ?>" download>
                        <i class="bx bx-paperclip"></i>
                        <?php _e( 'Attachment File', 'arvand-panel' ); ?>
                    </a>
                <?php endif; ?>
            </div>

            <footer>
                <span>
                    <i class="bx bx-time"></i>
                    <?php echo sprintf( __( '%s at %s', 'arvand-panel' ), get_the_date( '', $main_ticket->ID ), get_the_time( '', $main_ticket->ID ) ); ?>
                </span>
            </footer>
        </div>
    </article>

    <div id="wpap-ticket-replies">
        <?php
        $paged = ( get_query_var( 'paged' ) ) ? absint( get_query_var( 'paged' ) ) : 1;

        $query = new WP_Query([
            'post_type' => 'wpap_ticket',
            'post_parent' => $main_ticket->ID,
            'posts_per_page' => $ticket_opt['ticket_replies_per_page'],
            'paged' => $paged,
        ]);
        ?>

        <?php if ( $query->have_posts() ): ?>
            <?php while ( $query->have_posts() ): $query->the_post(); ?>
                <?php
                $author = get_the_author_meta( 'ID' );
                $class = ( $author != $current_user->ID ) ? 'wpap-ticket-admin-reply' : '';
                ?>

                <article class="wpap-reply-ticket wpap-card <?php echo esc_attr( $class ); ?>">
                    <header>
                        <?php echo get_avatar( get_the_author_meta( 'id' ), '50' ); ?>

                        <span class="wpap-sender-name">
                            <?php echo get_the_author_meta( 'display_name' ); ?>
                        </span>
                    </header>

                    <div>
                        <div class="wpap-card-content">
                            <?php
                            the_content();
                            $attachment = get_post_meta( get_the_ID(), 'wpap_ticket_attachment', true );
                            ?>

                            <?php if ( $attachment ): ?>
                                <a class="wpap-ticket-attachment-file" href="<?php echo esc_url( $attachment ); ?>" download>
                                    <i class="bx bx-paperclip"></i>
                                    <?php _e( 'Attachment File', 'arvand-panel' ); ?>
                                </a>
                            <?php endif; ?>
                        </div>

                        <footer>
                            <span>
                                <i class="bx bx-time"></i>
                                <?php echo sprintf( __( '%s at %s', 'arvand-panel' ), get_the_date(), get_the_time() ); ?>
                            </span>
                        </footer>
                    </div>
                </article>
            <?php endwhile; ?>

            <?php include_once WPAP_USER_PATH . '/parts/pagination.php'; ?>
        <?php endif; ?>

	    <?php wp_reset_postdata(); ?>
    </div>

    <?php if ( ! in_array( $status, [ 'closed', 'solved' ] ) ): ?>
        <div class="wpap-form-wrap">
            <form id="wpap-reply-ticket-form" method="post" enctype="multipart/form-data">
                <?php wp_nonce_field( 'ticket_reply', 'ticket_reply_nonce' ); ?>
                <input type="hidden" name="action" value="send_ticket_reply"/>
                <input type="hidden" name="post" value="<?php echo esc_attr( $main_ticket->ID ); ?>"/>
                <input type="hidden" name="recipient" value="<?php echo esc_attr( $recipient ); ?>"/>

                <?php if ( $user_dep ) : ?>
                    <p>
                        <select name="ticket_status">
                            <option value="-1" selected>
                                <?php _e( 'Select ticket status', 'arvand-panel' ); ?>
                            </option>

                            <option value="open">
                                <?php _e( 'Open', 'arvand-panel' ); ?>
                            </option>

                            <?php
                            $ticket_opt = wpap_ticket_options();
                            $ticket_status = $ticket_opt['ticket_status'];
                            ?>

                            <?php for ( $i = 0; $i < count( $ticket_status['name'] ); $i++ ): ?>
                                <option value="<?php esc_attr_e( $ticket_status['name'][ $i ] ); ?>">
                                    <?php esc_html_e( $ticket_status['name'][ $i ] ); ?>
                                </option>
                            <?php endfor; ?>

                            <option value="solved">
                                <?php _e( 'Solved', 'arvand-panel' ); ?>
                            </option>

                            <option value="closed">
                                <?php _e( 'Closed', 'arvand-panel' ); ?>
                            </option>
                        </select>

                        <span class="wpap-input-info">
                            <?php _e( 'Select a status for this ticket.', 'arvand-panel' ); ?>
                        </span>
                    </p>
                <?php else: ?>
                    <p>
                        <select name="ticket_status">
                            <option value="-1" selected>
                                <?php _e( 'Select ticket status', 'arvand-panel' ); ?>
                            </option>

                            <option value="open">
                                <?php _e( 'I\'m waiting for replay.', 'arvand-panel' ); ?>
                            </option>

                            <option value="solved">
                                <?php _e( 'Ticket solved.', 'arvand-panel' ); ?>
                            </option>

                            <option value="closed">
                                <?php _e( 'Close the ticket.', 'arvand-panel' ); ?>
                            </option>
                        </select>

                        <span class="wpap-input-info">
                            <?php _e( 'Select a status for the ticket you created.', 'arvand-panel' ); ?>
                        </span>
                    </p>
                <?php endif; ?>

                <?php
                $args = [
                    'media_buttons' => false,
                    'textarea_name' => 'ticket_content',
                    'textarea_rows' => 8,
                    'quicktags' => false,
                    'tinymce' => [
                        'toolbar1' => 'bold,italic,underline,separator,alignleft,aligncenter,alignright,separator,link,unlink,undo,redo',
                        'toolbar2' => '',
                        'toolbar3' => '',
                    ],
                ];

                wp_editor( __( 'Your Message', 'arvand-panel' ), 'wpap-ticket-content', $args );
                ?>

                <p>
                    <label id="wpap-upload-attachment">
                        <input type="file" name="wpap_attachment" hidden/>
                        <i class="bx bx-upload"></i>
                        <span><?php _e( 'Upload Attachment', 'arvand-panel' ); ?></span>
                    </label>

                    <span class="wpap-input-info">
                        <?php echo sprintf( __( 'Maximum size is %d KB and allowed extensions: jpg - jpeg - png - pdf - zip', 'arvand-panel' ), $ticket_opt['ticket_attachment_size'] ); ?>
                    </span>
                </p>

                <button class="wpap-btn-1" type="submit">
                    <span class="wpap-btn-text"><?php esc_attr_e( 'Send Reply', 'arvand-panel' ); ?></span>
                    <div class="wpap-loading"></div>
                </button>
            </form>
        </div>
    <?php endif; ?>
</div>