<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

$paged = ( get_query_var( 'paged' ) ) ? absint( get_query_var( 'paged' ) ) : 1;
$ticket_opt = wpap_ticket_options();

$args = [
    'post_type' => 'wpap_ticket',
    'publish' => true,
    'post_parent' => 0,
    'posts_per_page' => $ticket_opt['tickets_per_page'],
    'paged' => $paged,
    'order' => 'desc',
];

$args['meta_query'] = [];
$user_dep = WPAPTicket::userDepartment( $current_user->ID );

if ( ! $user_dep ) {
    $args['meta_query'] = [
        [
            [ 'key' => 'wpap_ticket_recipient', 'value' => $current_user->ID ],
            [ 'key' => 'wpap_ticket_creator' , 'value' => $current_user->ID ],
            'relation' => 'OR'
        ]
    ];
} else {
    $args['meta_query'] = [
        [
            [ 'key' => 'wpap_ticket_department', 'value' => $user_dep, 'compare' => 'IN' ],
            [ 'key' => 'wpap_ticket_recipient', 'value' => $current_user->ID ],
            [ 'key' => 'wpap_ticket_creator' , 'value' => $current_user->ID ],
            'relation' => 'OR'
        ]
    ];
}

if ( isset( $_GET['ticket-status'] ) and ! empty( $_GET['ticket-status'] ) ) {
    $status = sanitize_text_field( $_GET['ticket-status'] );
    $args['meta_query'][] = [ 'key' => 'wpap_ticket_status', 'value' => $status ];
}

$query = new WP_Query( $args );
?>

<div id="wpap-ticket-list">
    <div id="wpap-ticket-statues-wrap">
        <div class="row">
            <div class="col-sm-6 col-lg-3 col-xl-2">
                <a href="<?php echo esc_url( add_query_arg( [ 'ticket-status' => 'open' ] ) ); ?>">
                    <div id="wpap-open-tickets">
                        <i class="bx bx-support"></i>
                        <span><?php _e( 'Open', 'arvand-panel' ); ?></span>

                        <span>
                            <?php
                            $ticket_dep_count = $user_dep ?: [];
                            esc_html_e( $ticket::count( 'open', $ticket_dep_count, true ) );
                            ?>
                        </span>
                    </div>
                </a>
            </div>

            <?php $ticket_status = $ticket_opt['ticket_status'];?>

            <?php if ( count( $ticket_status['name'] ) ): ?>
                <?php for ( $i = 0; $i < count( $ticket_status['name'] ); $i++ ): ?>
                    <div class="col-sm-6 col-lg-3 col-xl-2">
                        <a href="<?php echo esc_url( add_query_arg( [ 'ticket-status' => $ticket_status['name'][ $i ] ] ) ); ?>">
                            <div>
                                <i class="bx bx-support" style="color: <?php esc_attr_e( $ticket_status['color'][ $i ] ); ?>"></i>
                                <span><?php esc_html_e( $ticket_status['name'][$i] ); ?></span>
                                <span><?php esc_html_e( $ticket::count( $ticket_status['name'][ $i ], $ticket_dep_count, true ) ); ?></span>
                            </div>
                        </a>
                    </div>
                <?php endfor; ?>
            <?php endif; ?>

            <div class="col-sm-6 col-lg-3 col-xl-2">
                <a href="<?php echo esc_url( add_query_arg( [ 'ticket-status' => 'solved' ] ) ); ?>">
                    <div id="wpap-solved-tickets">
                        <i class="bx bx-support"></i>
                        <span><?php _e( 'Solved', 'arvand-panel' ); ?></span>
                        <span><?php esc_html_e( $ticket::count( 'solved', $ticket_dep_count, true ) ); ?></span>
                    </div>
                </a>
            </div>

            <div class="col-sm-6 col-lg-3 col-xl-2">
                <a href="<?php echo esc_url( add_query_arg( [ 'ticket-status' => 'closed' ] ) ); ?>">
                    <div id="wpap-closed-tickets">
                        <i class="bx bx-support"></i>
                        <span><?php _e( 'Closed', 'arvand-panel' ); ?></span>
                        <span><?php esc_html_e( $ticket::count( 'closed', $ticket_dep_count, true ) ); ?></span>
                    </div>
                </a>
            </div>

            <div class="col-sm-6 col-lg-3 col-xl-2">
                <a href="<?php echo esc_url( add_query_arg( [ 'section' => 'tickets' ], remove_query_arg( $remove_args ) ) ); ?>">
                    <div id="wpap-all-tickets">
                        <i class="bx bx-support"></i>
                        <span><?php _e( 'All', 'arvand-panel' ); ?></span>
                        <span><?php esc_html_e( $ticket::count( '', $ticket_dep_count, true ) ); ?></span>
                    </div>
                </a>
            </div>
        </div>
    </div>

    <?php if ( in_array( 'new-ticket', $sections ) ): ?>
        <a id="wpap-new-ticket-btn" href="<?php echo esc_url( add_query_arg( [ 'section' => 'new-ticket' ], remove_query_arg( $remove_args ) ) ); ?>">
            <i class="bx bx-plus-circle"></i>
            <?php _e( 'New Ticket', 'arvand-panel' ); ?>
        </a>
    <?php endif ?>

    <?php do_action( 'wpap_before_ticket_list' ); ?>

    <div class="wpap-table-wrap">
        <table>
<!--            <thead>-->
<!--                --><?php
//                if ( get_option( 'show_avatars' ) ) {
//                    echo '<th>' . __( 'Creator', 'arvand-panel' ) . '</th>';
//                }
//                ?>
<!---->
<!--                <th>--><?php //_e('Title', 'arvand-panel'); ?><!--</th>-->
<!---->
<!--                --><?php
                $dep_opt = wpap_ticket_department_options();
//
//                if ( $dep_opt['enable_department'] ) {
//                    echo '<th>' . __( 'Department', 'arvand-panel' ) . '</th>';
//                }
//                ?>
<!---->
<!--                <th>--><?php //_e('Status', 'arvand-panel'); ?><!--</th>-->
<!--                <th>--><?php //_e('Date', 'arvand-panel'); ?><!--</th>-->
<!--                <th colspan="2"></th>-->
<!--            </thead>-->

            <?php if ( $query->have_posts() ): ?>
                <?php $ticket_num = 0;?>

                <?php while ( $query->have_posts() ): $query->the_post(); ?>
                    <tr>
                        <td>
                            <div class="wpap-ticket-list-ticket-creator">
	                            <?php
	                            if ( get_option( 'show_avatars' ) ) {
		                            echo get_avatar( get_the_author_meta( 'id' ) );
	                            }

                                echo '<span>' . get_the_author_meta( 'display_name' ) . '</span>';
	                            ?>
                            </div>
                        </td>

                        <td><strong><?php echo wp_trim_words( get_the_title(), 7 ); ?></strong></td>

                        <?php if ( $dep_opt['enable_department'] ): ?>
                            <td>
                                <?php
                                $department = get_post_meta( get_the_ID(), 'wpap_ticket_department', true );
                                echo $department ? esc_html( $department ) : '---';
                                ?>
                            </td>
                        <?php endif; ?>

                        <td>
                            <?php
                            $status = get_post_meta( get_the_ID(), 'wpap_ticket_status', true );

                            if ( $status ) {
                                if ( $status === 'closed' ) {
                                    echo '<strong class="wpap-badge-success">' . __( 'Closed', 'arvand-panel' ) . '</strong>';
                                } elseif ( $status === 'solved' ) {
                                    echo '<strong class="wpap-badge-success">' . __( 'Solved', 'arvand-panel' ) . '</strong>';
                                } elseif ( $status === 'open' ) {
                                    echo '<strong class="wpap-badge-error">' . __( 'Open', 'arvand-panel' ) . '</strong>';
                                } else {
                                    $status_color = get_post_meta( get_the_ID(), 'wpap_ticket_status_color', true );
                                    $status_text_color = get_post_meta( get_the_ID(), 'wpap_ticket_status_text_color', true );
                                    echo "<span class='wpap-badge' style='background-color: $status_color; color: $status_text_color;'>$status</span>";
                                }
                            } else {
                                echo '---';
                            }
                            ?>
                        </td>

                        <td><?php echo get_the_date(); ?></td>

                        <td>
                            <?php $args = [ 'ticket' => get_the_ID() ]; ?>

                            <a class="wpap-view-ticket wpap-btn-1" href="<?php echo esc_url( add_query_arg( $args , remove_query_arg( $remove_args ) ) ); ?>">
                                <?php _e( 'View', 'arvand-panel' ); ?>
                            </a>
                        </td>
                    </tr>
                <?php endwhile; ?>
            <?php else: ?>
                <td colspan="7"><?php _e( 'There is no ticket.', 'arvand-panel' ); ?></td>
            <?php endif; ?>
        </table>
    </div>

    <?php do_action( 'wpap_after_ticket_list' ); ?>

    <?php include WPAP_USER_PATH . '/parts/pagination.php'; ?>
</div>
